@@ -1,9 +1,9 @@
 #!/bin/bash
 #		GMT EXAMPLE 07
-#		$Id: example_07.sh 12321 2013-10-13 23:26:34Z pwessel $
+#		$Id: example_07.sh 16751 2016-07-09 08:04:10Z pwessel $
 #
 # Purpose:	Make a basemap with earthquakes and isochrons etc
-# GMT progs:	pscoast, pstext, psxy
+# GMT modules:	pscoast, pslegend, pstext, psxy
 # Unix progs:	echo, rm
 #
 ps=example_07.ps
@@ -13,20 +13,9 @@ gmt psxy -R -J -O -K fz.xy -Wthinner,- >> $ps
 gmt psxy quakes.xym -R -J -O -K -h1 -Sci -i0,1,2s0.01 -Gred -Wthinnest >> $ps
 gmt psxy -R -J -O -K isochron.xy -Wthin,blue >> $ps
 gmt psxy -R -J -O -K ridge.xy -Wthicker,orange >> $ps
-gmt psxy -R -J -O -K -Gwhite -Wthick -A >> $ps << END
--14.5	15.2
- -2	15.2
- -2	17.8
--14.5	17.8
-END
-gmt psxy -R -J -O -K -Gwhite -Wthinner -A >> $ps << END
--14.35	15.35
- -2.15	15.35
- -2.15	17.65
--14.35	17.65
-END
-echo "-13.5 16.5" | gmt psxy -R -J -O -K -Sc0.08i -Gred -Wthinner >> $ps
-echo "-12.5 16.5 ISC Earthquakes" | gmt pstext -R -J -F+f18p,Times-Italic+jLM -O -K >> $ps
+gmt pslegend -R -J -O -K -DjTR+w2.2i+o0.2i -F+pthick+ithinner+gwhite --FONT_ANNOT_PRIMARY=18p,Times-Italic<< EOF >> $ps
+S 0.1i c 0.08i red thinnest 0.3i ISC Earthquakes
+EOF
 gmt pstext -R -J -O -F+f30,Helvetica-Bold,white=thin >> $ps << END
 -43 -5 SOUTH
 -43 -8 AMERICA
