@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: common_string.c 15178 2015-11-06 10:45:03Z fwobbe $
+ *	$Id: common_string.c 16722 2016-07-06 13:46:09Z remko $
  *
- *	Copyright (c) 1991-2015 by P. Wessel, W. H. F. Smith, R. Scharroo, J. Luis and F. Wobbe
+ *	Copyright (c) 1991-2016 by P. Wessel, W. H. F. Smith, R. Scharroo, J. Luis and F. Wobbe
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -24,22 +24,23 @@
  *
  * Modules in this file:
  *
- *  GMT_chop                Chops off any CR or LF at end of string
- *  GMT_chop_ext            Chops off the trailing .xxx (file extension)
- *  GMT_strstrip            Strip leading and trailing whitespace from string
- *  GMT_cr2lf               Replace CR with LF and terminate string
- *  GMT_strlshift           Left shift a string by n characters
- *  GMT_strrepc             Replaces all occurrences of a char in the string
- *  GMT_strlcmp             Compares strings (ignoring case) until first reaches null character
- *  GMT_strtok              Reiterant replacement of strtok
- *  DOS_path_fix            Turn /c/dir/... paths into c:/dir/...
+ *  gmt_chop                Chops off any CR or LF at end of string
+ *  gmt_chop_ext            Chops off the trailing .xxx (file extension)
+ *  gmt_get_ext             Returns a pointer to the tailing .xxx (file extension)
+ *  gmt_strstrip            Strip leading and trailing whitespace from string
+ *  gmt_strlshift           Left shift a string by n characters
+ *  gmt_strrepc             Replaces all occurrences of a char in the string
+ *  gmt_strlcmp             Compares strings (ignoring case) until first reaches null character
+ *  gmt_strtok              Reiterant replacement of strtok
+ *  gmt_strtok_m            A Matlab style strtok  
+ *  gmt_dos_path_fix        Turn /c/dir/... paths into c:/dir/...
  *  str(n)casecmp           Case-insensitive string comparison functions
  *  strtok_r                Reentrant string tokenizer from Gnulib (LGPL)
  *  strsep                  Reentrant string tokenizer that handles empty fields
  *  strsepz                 Like strsep but ignores empty fields
  *  stresep                 Like strsep but takes an additional argument esc in order
  *                          to ignore escaped chars (from NetBSD)
- *  match_string_in_file    Return true if a string is found in file
+ *  gmt_match_string_in_file    Return true if a string is found in file
  *  basename                Extract the base portion of a pathname
  */
 
@@ -59,7 +60,7 @@
 
 #define BUF_SIZE 4096
 
-char *GMT_chop_ext (char *string) {
+char *gmt_chop_ext (char *string) {
 	/* Chops off the filename extension (e.g., .ps) in the string by replacing the last
 	 * '.' with '\0' and returns a pointer to the extension or NULL if not found. */
 	char *p;
@@ -68,10 +69,10 @@ char *GMT_chop_ext (char *string) {
 		*p = '\0';
 		return (p + 1);
 	}
-	return (NULL);
+	return NULL;
 }
 
-void GMT_chop (char *string) {
+void gmt_chop (char *string) {
 	/* Chops off any CR or LF and terminates string */
 	char *p;
 	assert (string != NULL); /* NULL pointer */
@@ -81,7 +82,17 @@ void GMT_chop (char *string) {
 		*p = '\0';
 }
 
-void GMT_strstrip(char *string, bool strip_leading) {
+char *gmt_get_ext (char *string) {
+	/* Returns a pointer to the filename extension (e.g., .ps)  or NULL if not found. */
+	char *p;
+	assert (string != NULL); /* NULL pointer */
+	if ((p = strrchr(string, '.'))) {
+		return (p + 1);
+	}
+	return NULL;
+}
+
+void gmt_strstrip(char *string, bool strip_leading) {
 	/* Strip leading and trailing whitespace from string */
 	char *start = string;
 	char *end;
@@ -115,16 +126,7 @@ void GMT_strstrip(char *string, bool strip_leading) {
 		memmove(string, start, end-start+2);
 }
 
-void GMT_cr2lf (char *string) {
-	/* Replace CR with LF and terminate string */
-	char *p;
-	assert (string != NULL); /* NULL pointer */
-	if ((p = strchr (string, '\r')))
-		/* Overwrite 1st CR with LF + \0 */
-		strcpy(p, "\n");
-}
-
-void GMT_strlshift (char *string, size_t n) {
+void gmt_strlshift (char *string, size_t n) {
 	/* Left shift a string by n characters */
 	size_t len;
 	assert (string != NULL); /* NULL pointer */
@@ -139,7 +141,7 @@ void GMT_strlshift (char *string, size_t n) {
 	memmove(string, string + n, len + 1);
 }
 
-void GMT_strrepc (char *string, int c, int r) {
+void gmt_strrepc (char *string, int c, int r) {
 	/* Replaces all occurrences of c in the string with r */
 	assert (string != NULL); /* NULL pointer */
 	do {
@@ -148,8 +150,7 @@ void GMT_strrepc (char *string, int c, int r) {
 	} while (*(++string)); /* repeat until \0 reached */
 }
 
-size_t GMT_strlcmp (char *str1, char *str2)
-{
+size_t gmt_strlcmp (char *str1, char *str2) {
 	/* Compares str1 with str2 but only until str1 reaches the
 	 * null-terminator character while case is ignored.
 	 * When the strings match until that point, the routine returns the
@@ -161,16 +162,15 @@ size_t GMT_strlcmp (char *str1, char *str2)
 	return i;
 }
 
-unsigned int GMT_strtok (const char *string, const char *sep, unsigned int *pos, char *token)
-{
+unsigned int gmt_strtok (const char *string, const char *sep, unsigned int *pos, char *token) {
 	/* Reentrant replacement for strtok that uses no static variables.
 	 * Breaks string into tokens separated by one of more separator
-	 * characters (in sep).  Set *pos to 0 before first call.  Unlike
+	 * characters (in sep).  Set *pos to 0 before first call. Unlike
 	 * strtok, always pass the original string as first argument.
 	 * Returns 1 if it finds a token and 0 if no more tokens left.
 	 * pos is updated and token is returned.  char *token must point
 	 * to memory of length >= strlen (string).
-	 * string is not changed by GMT_strtok.
+	 * string is not changed by gmt_strtok.
 	 */
 
 	size_t i, j, string_len;
@@ -196,8 +196,31 @@ unsigned int GMT_strtok (const char *string, const char *sep, unsigned int *pos,
 	return 1;
 }
 
-unsigned int GMT_get_modifier (const char *string, char modifier, char *token)
-{
+void gmt_strtok_m (char *in, char **token, char **remain, char *sep) {
+	/* A Matlab style strtok. Note that 'token' and 'remain' must be virgin pointers,
+	   otherwise the memory they point to will be leaked because they are allocated here
+	   with strdup. For that reason the caller is responsable to free them after being consumed.
+	 */
+	unsigned int pos = 0;
+	char *p, *s;
+
+	if (sep == NULL)
+		s = " \t";
+	else
+		s = sep;
+
+	token[0] = NULL;		remain[0] = NULL;
+
+	p = malloc(strlen(in)+1);
+	if (gmt_strtok (in, s, &pos, p)) {
+		token[0] = strdup(p);
+		if (gmt_strtok (in, s, &pos, p))
+			remain[0] = strdup(p);
+	}
+	free(p);
+}
+
+unsigned int gmt_get_modifier (const char *string, char modifier, char *token) {
 	/* Looks for modifier string in the form +<modifier>[arg] and if found
 	   returns 1 and places arg in token, else return 0.  Must ignore any
 	   +<modifier> found inside quotes as part of text. If token is NULL
@@ -234,7 +257,7 @@ unsigned int GMT_get_modifier (const char *string, char modifier, char *token)
 #ifdef WIN32
 /* Turn '/c/dir/...' paths into 'c:/dir/...'
  * Must do it in a loop since dir may be several ';'-separated dirs */
-void DOS_path_fix (char *dir) {
+void gmt_dos_path_fix (char *dir) {
 	size_t n, k;
 
 	if (!dir || (n = strlen (dir)) < 2U)
@@ -243,10 +266,10 @@ void DOS_path_fix (char *dir) {
 
 	if (!strncmp (dir, "/cygdrive/", 10U))
 		/* May happen for example when Cygwin sets GMT_SHAREDIR */
-		GMT_strlshift (dir, 9); /* Chop '/cygdrive' */
+		gmt_strlshift (dir, 9); /* Chop '/cygdrive' */
 
 	/* Replace dumb backslashes with slashes */
-	GMT_strrepc (dir, '\\', '/');
+	gmt_strrepc (dir, '\\', '/');
 
 	/* If dir begins with '/' and is 2 long, as in '/c', replace with 'c:' */
 	if (n == 2U && dir[0] == '/') {
@@ -414,19 +437,18 @@ int strncasecmp (const char *s1, const char *s2, size_t n) {
    You should have received a copy of the GNU Lesser General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
-/* Parse S into tokens separated by characters in DELIM.
+#if 0
+/* Parse S into tokens separated by characters in DELIM. */
    If S is NULL, the saved pointer in SAVE_PTR is used as
    the next starting point.  For example:
         char s[] = "-abc-=-def";
         char *sp;
-        x = strtok_r(s, "-", &sp);      // x = "abc", sp = "=-def"
-        x = strtok_r(NULL, "-=", &sp);  // x = "def", sp = NULL
-        x = strtok_r(NULL, "=", &sp);   // x = NULL
-                                        // s = "abc\0-def\0"
-*/
-char *
-strtok_r (char *s, const char *delim, char **save_ptr)
-{
+        x = strtok_r(s, "-", &sp);      /* x = "abc", sp = "=-def"	*/
+        x = strtok_r(NULL, "-=", &sp);  /* x = "def", sp = NULL		*/
+        x = strtok_r(NULL, "=", &sp);   /* x = NULL					*/
+                                        /* s = "abc\0-def\0"		*/
+#endif
+char *strtok_r (char *s, const char *delim, char **save_ptr) {
   char *token;
 
   if (s == NULL)
@@ -474,9 +496,7 @@ strtok_r (char *s, const char *delim, char **save_ptr)
    You should have received a copy of the GNU Lesser General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
-char *
-strsep (char **stringp, const char *delim)
-{
+char * strsep (char **stringp, const char *delim) {
   char *start = *stringp;
   char *ptr;
 
@@ -560,9 +580,7 @@ char *strsepz (char **stringp, const char *delim) {
  * If *stringp is NULL, stresep returns NULL.
  */
 
-char *
-stresep(char **stringp, const char *delim, int esc)
-{
+char *stresep(char **stringp, const char *delim, int esc) {
 	char *s;
 	const char *spanp;
 	int c, sc;
@@ -593,20 +611,16 @@ stresep(char **stringp, const char *delim, int esc)
 }
 
 /* Return true if a string is found in file */
-int match_string_in_file (const char *filename, const char *string) {
+int gmt_match_string_in_file (const char *filename, const char *string) {
 	FILE *fp;
-	char line[BUF_SIZE+1];
+	char line[BUF_SIZE] = {""};
 
 	fp = fopen (filename, "r");
-	if ( fp == NULL )
-		return false;
-
-	/* make sure string is always \0-terminated */
-	line[BUF_SIZE] = '\0';
+	if (fp == NULL) return false;
 
 	/* search for string in each line */
-	while ( fgets (line, BUF_SIZE, fp) ) {
-		if ( strstr (line, string) ) {
+	while (fgets (line, BUF_SIZE-1, fp)) {
+		if (strstr (line, string)) {
 			/* line matches */
 			fclose (fp);
 			return true;
