@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *      $Id: gmt_notposix.c 15178 2015-11-06 10:45:03Z fwobbe $
+ *      $Id: gmt_notposix.c 15810 2016-03-05 00:33:55Z pwessel $
  *
- *      Copyright (c) 1991-2015 by P. Wessel, W. H. F. Smith, R. Scharroo, J. Luis and F. Wobbe
+ *      Copyright (c) 1991-2016 by P. Wessel, W. H. F. Smith, R. Scharroo, J. Luis and F. Wobbe
  *      See LICENSE.TXT file for copying and redistribution conditions.
  *
  *      This program is free software; you can redistribute it and/or modify
@@ -154,9 +154,9 @@ double atanh (double x) {
 	This should be used only if there isn't a better library routine available.
 	WHFS 30 March 2000  */
 
-	if (GMT_is_dnan (x)) return (x);
+	if (gmt_M_is_dnan (x)) return (x);
 	if (fabs (x) >= 1.0) {
-		GMT_make_dnan (x);
+		gmt_M_make_dnan (x);
 		return (x);
 	}
 
@@ -192,8 +192,7 @@ static double q2[5] = {1.872952849923460, 5.279051029514284e-01,
 #endif /* !defined(HAVE_ERF) || !defined(HAVE_ERFC) */
 
 #ifndef HAVE_ERF
-double erf (double y)
-{
+double erf (double y) {
 	int i, sign = 1;
 	double x, res, xsq, xnum, xden, xi;
 
@@ -245,8 +244,7 @@ double erf (double y)
 #endif /* HAVE_ERF */
 
 #ifndef HAVE_ERFC
-double erfc (double y)
-{
+double erfc (double y) {
 	int i, sign = 1;
 	double x, res, xsq, xnum, xden, xi;
 
@@ -310,8 +308,8 @@ double hypot (double x, double y) {
 
 	double a, b, c, d, r, s, t;
 
-	if (GMT_is_dnan (x)) return (x);
-	if (GMT_is_dnan (y)) return (y);
+	if (gmt_M_is_dnan (x)) return (x);
+	if (gmt_M_is_dnan (y)) return (y);
 
 	/* A complete implementation of IEEE exceptional values
 	would also return +Inf if either x or y is +/- Inf  */
@@ -362,8 +360,7 @@ double hypot (double x, double y) {
 #ifndef HAVE_J0
 /* Alternative j0 coded from Numerical Recipes by Press et al */
 
-double j0 (double x)
-{
+double j0 (double x) {
 	double ax, z, xx, y, ans, ans1, ans2, s, c;
 
 	if ((ax = fabs (x)) < 8.0) {
@@ -389,8 +386,7 @@ double j0 (double x)
 #ifndef HAVE_J1
 /* Alternative j1 coded from Numerical Recipes by Press et al */
 
-double j1 (double x)
-{
+double j1 (double x) {
 	double ax, z, xx, y, ans, ans1, ans2, s, c;
 
 	if ((ax = fabs (x)) < 8.0) {
@@ -422,8 +418,7 @@ double j1 (double x)
 
 /* Alternative jn coded from Numerical Recipes by Press et al */
 
-double jn (int n, double x)
-{
+double jn (int n, double x) {
 	int j, jsum, m;
 	double ax, bj, bjm, bjp, sum, tox, ans;
 
@@ -480,9 +475,9 @@ double log1p (double x) {
 
 	double u;
 
-	if (GMT_is_dnan (x)) return (x);
+	if (gmt_M_is_dnan (x)) return (x);
 	if (x <= -1.0) {
-		GMT_make_dnan (u);
+		gmt_M_make_dnan (u);
 		return (u);
 	}
 
@@ -503,8 +498,7 @@ double log1p (double x) {
 
 #if !defined(HAVE_SINCOS)
 /* Platform does not have sincos - make a dummy one with sin and cos */
-void sincos (double a, double *s, double *c)
-{
+void sincos (double a, double *s, double *c) {
 	*s = sin (a);
 	*c = cos (a);
 }
@@ -520,8 +514,7 @@ void sincos (double a, double *s, double *c)
 
 /* Alternative y0, y1, yn coded from Numerical Recipes by Press et al */
 
-double y0 (double x)
-{
+double y0 (double x) {
 	double z, ax, xx, y, ans, ans1, ans2, s, c;
 
 	if (x < 8.0) {
@@ -548,8 +541,7 @@ double y0 (double x)
 #ifndef HAVE_Y1
 /* Alternative y1 coded from Numerical Recipes by Press et al */
 
-double y1 (double x)
-{
+double y1 (double x) {
 	double z, ax, xx, y, ans, ans1, ans2, s, c;
 
 	if (x < 8.0) {
@@ -576,8 +568,7 @@ double y1 (double x)
 #ifndef HAVE_YN
 /* Alternative yn coded from Numerical Recipes by Press et al */
 
-double yn (int n, double x)
-{
+double yn (int n, double x) {
 	int j;
 	double by, bym, byp, tox;
 
