@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: gmt_project.h 15188 2015-11-07 02:12:40Z pwessel $
+ *	$Id: gmt_project.h 17154 2016-10-01 00:23:46Z pwessel $
  *
- *	Copyright (c) 1991-2015 by P. Wessel, W. H. F. Smith, R. Scharroo, J. Luis and F. Wobbe
+ *	Copyright (c) 1991-2016 by P. Wessel, W. H. F. Smith, R. Scharroo, J. Luis and F. Wobbe
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -37,21 +37,21 @@
 
 /*! GMT_180 is used to see if a value really is exceeding it (beyond roundoff) */
 #define GMT_180	(180.0 + GMT_CONV8_LIMIT)
-/*! GMT_WIND_LON will remove central meridian value and adjust so lon fits between -180/+180 */
-#define GMT_WIND_LON(C,lon) {lon -= C->current.proj.central_meridian; while (lon < -GMT_180) lon += 360.0; while (lon > +GMT_180) lon -= 360.0;}
+/*! gmt_M_wind_lon will remove central meridian value and adjust so lon fits between -180/+180 */
+#define gmt_M_wind_lon(C,lon) {lon -= C->current.proj.central_meridian; while (lon < -GMT_180) lon += 360.0; while (lon > +GMT_180) lon -= 360.0;}
 
 /*! Some shorthand notation for GMT specific cases */
+EXTERN_MSC double gmtmap_lat_swap_quick (struct GMT_CTRL *GMT, double lat, double c[]);
 
-#define GMT_latg_to_latc(C,lat) GMT_lat_swap_quick (C, lat, C->current.proj.GMT_lat_swap_vals.c[GMT_LATSWAP_G2C])
-#define GMT_latg_to_lata(C,lat) GMT_lat_swap_quick (C, lat, C->current.proj.GMT_lat_swap_vals.c[GMT_LATSWAP_G2A])
-#define GMT_latc_to_latg(C,lat) GMT_lat_swap_quick (C, lat, C->current.proj.GMT_lat_swap_vals.c[GMT_LATSWAP_C2G])
-#define GMT_lata_to_latg(C,lat) GMT_lat_swap_quick (C, lat, C->current.proj.GMT_lat_swap_vals.c[GMT_LATSWAP_A2G])
+#define gmt_M_latg_to_latc(C,lat) gmtmap_lat_swap_quick (C, lat, C->current.proj.lat_swap_vals.c[GMT_LATSWAP_G2C])
+#define gmt_M_latg_to_lata(C,lat) gmtmap_lat_swap_quick (C, lat, C->current.proj.lat_swap_vals.c[GMT_LATSWAP_G2A])
+#define gmt_M_latc_to_latg(C,lat) gmtmap_lat_swap_quick (C, lat, C->current.proj.lat_swap_vals.c[GMT_LATSWAP_C2G])
+#define gmt_M_lata_to_latg(C,lat) gmtmap_lat_swap_quick (C, lat, C->current.proj.lat_swap_vals.c[GMT_LATSWAP_A2G])
 
 /*! Macros returns true if the two coordinates are lon/lat; way should be GMT_IN or GMT_OUT */
-#define GMT_x_is_lon(C,way) (C->current.io.col_type[way][GMT_X] == GMT_IS_LON)
-#define GMT_y_is_lat(C,way) (C->current.io.col_type[way][GMT_Y] == GMT_IS_LAT)
-#define GMT_is_geographic(C,way) (GMT_x_is_lon(C,way) && GMT_y_is_lat(C,way))
-#define GMT_axis_is_geo(C,axis) (C->current.io.col_type[GMT_IN][axis] & GMT_IS_GEO)
+#define gmt_M_x_is_lon(C,way) (C->current.io.col_type[way][GMT_X] == GMT_IS_LON)
+#define gmt_M_y_is_lat(C,way) (C->current.io.col_type[way][GMT_Y] == GMT_IS_LAT)
+#define gmt_M_is_geographic(C,way) (gmt_M_x_is_lon(C,way) && gmt_M_y_is_lat(C,way))
 
 #define GMT_N_PROJECTIONS	29	/* Total number of projections in GMT */
 
@@ -61,9 +61,9 @@
 #define GMT_NO_PROJ		-1	/* Projection not specified (initial value) */
 
 /*! Linear projections tagged 0-99 */
-#define GMT_IS_LINEAR(C) (C->current.proj.projection / 100 == 0)
+#define gmt_M_is_linear(C) (C->current.proj.projection / 100 == 0)
 
-enum GMT_enum_annot {GMT_LINEAR = 0,
+enum gmt_enum_annot {GMT_LINEAR = 0,
 	GMT_LOG10,	/* These numbers are only used for GMT->current.proj.xyz_projection[3], */
 	GMT_POW,	/* while GMT->current.proj.projection = 0 */
 	GMT_TIME,
@@ -73,9 +73,9 @@ enum GMT_enum_annot {GMT_LINEAR = 0,
 #define GMT_ZAXIS		50
 
 /*! Cylindrical projections tagged 100-199 */
-#define GMT_IS_CYLINDRICAL(C) (C->current.proj.projection / 100 == 1)
+#define gmt_M_is_cylindrical(C) (C->current.proj.projection / 100 == 1)
 
-enum GMT_enum_cyl {GMT_MERCATOR = 100,
+enum gmt_enum_cyl {GMT_MERCATOR = 100,
 	GMT_CYL_EQ,
 	GMT_CYL_EQDIST,
 	GMT_CYL_STEREO,
@@ -87,17 +87,16 @@ enum GMT_enum_cyl {GMT_MERCATOR = 100,
 	GMT_OBLIQUE_MERC_POLE};
 
 /*! Conic projections tagged 200-299 */
-#define GMT_IS_CONICAL(C) (C->current.proj.projection / 100 == 2)
+#define gmt_M_is_conical(C) (C->current.proj.projection / 100 == 2)
 
-enum GMT_enum_conic {GMT_ALBERS = 200,
+enum gmt_enum_conic {GMT_ALBERS = 200,
 	GMT_ECONIC,
 	GMT_POLYCONIC,
 	GMT_LAMBERT = 250};
 
 /* Azimuthal projections tagged 300-399 */
-#define GMT_IS_AZIMUTHAL(C) (C->current.proj.projection / 100 == 3)
-#define GMT_IS_PERSPECTIVE(C) (C->current.proj.projection == GMT_ORTHO || C->current.proj.projection == GMT_GENPER)
-enum GMT_enum_azim {GMT_STEREO = 300,
+#define gmt_M_is_azimuthal(C) (C->current.proj.projection / 100 == 3)
+enum gmt_enum_azim {GMT_STEREO = 300,
 	GMT_LAMB_AZ_EQ,
 	GMT_ORTHO,
 	GMT_AZ_EQDIST,
@@ -106,8 +105,8 @@ enum GMT_enum_azim {GMT_STEREO = 300,
 	GMT_POLAR = 350};
 
 /* Misc projections tagged 400-499 */
-#define GMT_IS_MISC(C) (C->current.proj.projection / 100 == 4)
-enum GMT_enum_misc {GMT_MOLLWEIDE = 400,
+#define gmt_M_is_misc(C) (C->current.proj.projection / 100 == 4)
+enum gmt_enum_misc {GMT_MOLLWEIDE = 400,
 	GMT_HAMMER,
 	GMT_SINUSOIDAL,
 	GMT_VANGRINTEN,
@@ -117,7 +116,7 @@ enum GMT_enum_misc {GMT_MOLLWEIDE = 400,
 	GMT_WINKEL};
 
 /*! The various GMT measurement units */
-enum GMT_enum_units {GMT_IS_METER = 0,
+enum gmt_enum_units {GMT_IS_METER = 0,
 	GMT_IS_KM,
 	GMT_IS_MILE,
 	GMT_IS_NAUTICAL_MILE,
@@ -129,28 +128,25 @@ enum GMT_enum_units {GMT_IS_METER = 0,
 	GMT_N_UNITS,
 	GMT_IS_NOUNIT = -1};
 
-/* GMT_IS_RECT_GRATICULE means parallels and meridians are orthogonal, but does not imply linear spacing */
-#define GMT_IS_RECT_GRATICULE(C) (C->current.proj.projection <= GMT_MILLER)
+/* gmt_M_is_rect_graticule means parallels and meridians are orthogonal, but does not imply linear spacing */
+#define gmt_M_is_rect_graticule(C) (C->current.proj.projection <= GMT_MILLER)
 
-/* GMT_IS_NONLINEAR_GRATICULE means parallels and meridians are not orthogonal or have nonlinear spacing */
-#define GMT_IS_NONLINEAR_GRATICULE(C)	(!(C->current.proj.projection == GMT_CYL_EQDIST || C->current.proj.projection == GMT_LINEAR) || \
+/* gmt_M_is_nonlinear_graticule means parallels and meridians are not orthogonal or have nonlinear spacing */
+#define gmt_M_is_nonlinear_graticule(C)	(!(C->current.proj.projection == GMT_CYL_EQDIST || C->current.proj.projection == GMT_LINEAR) || \
 	C->current.proj.xyz_projection[GMT_X] == GMT_LOG10 || C->current.proj.xyz_projection[GMT_X] == GMT_POW || \
 	C->current.proj.xyz_projection[GMT_Y] == GMT_LOG10 || C->current.proj.xyz_projection[GMT_Y] == GMT_POW)
 
-#define GMT_POLE_IS_POINT(C) ((C->current.proj.projection == GMT_OBLIQUE_MERC || C->current.proj.projection == GMT_OBLIQUE_MERC_POLE) || (C->current.proj.projection >= GMT_LAMBERT && C->current.proj.projection <= GMT_VANGRINTEN))
-
-#define GMT_IS_SPHERICAL(C) (C->current.setting.ref_ellipsoid[C->current.setting.proj_ellipsoid].flattening < 1.0e-10)
-#define GMT_IS_FLATEARTH(C) (!strcmp (C->current.setting.ref_ellipsoid[C->current.setting.proj_ellipsoid].name, "FlatEarth"))
-
-#define GMT_is_grdmapproject(C) (!strncmp (C->init.module_name, "grdproject", 10U) || !strncmp (C->init.module_name, "mapproject", 10U))
+#define gmt_M_is_spherical(C) (C->current.setting.ref_ellipsoid[C->current.setting.proj_ellipsoid].flattening < 1.0e-10)
+#define gmt_M_is_flatearth(C) (!strcmp (C->current.setting.ref_ellipsoid[C->current.setting.proj_ellipsoid].name, "FlatEarth"))
 
 /* Return 0 for Flat Earth, 1 for Great-circles, 2 for geodesics, and 3 for loxodromes */
-#define GMT_sph_mode(C) (GMT_IS_FLATEARTH (C) ? GMT_FLATEARTH : (GMT_IS_SPHERICAL (C) ? GMT_GREATCIRCLE : (C->current.map.loxodrome ? GMT_LOXODROME : GMT_GEODESIC)))
+#define gmt_M_sph_mode(C) (gmt_M_is_flatearth (C) ? GMT_FLATEARTH : (gmt_M_is_spherical (C) ? GMT_GREATCIRCLE : (C->current.map.loxodrome ? GMT_LOXODROME : GMT_GEODESIC)))
 
-#define GMT_360_RANGE(w,e) (doubleAlmostEqual (fabs((e) - (w)), 360.0))
-#define GMT_180_RANGE(s,n) (doubleAlmostEqual (fabs((n) - (s)), 180.0))
-#define GMT_IS_POLE(y) (doubleAlmostEqual (fabs(y), 90.0))
-#define GMT_IS_ZERO(x) (fabs (x) < GMT_CONV8_LIMIT)
+//#define gmt_M_360_range(w,e) (doubleAlmostEqual (fabs((e) - (w)), 360.0))	/* PW: Reconsider this later perhaps but for now too tight */
+#define gmt_M_180_range(s,n) (doubleAlmostEqual (fabs((n) - (s)), 180.0))
+#define gmt_M_360_range(w,e) (gmt_M_is_zero (fabs ((e) - (w)) - 360.0))
+#define gmt_M_is_pole(y) (doubleAlmostEqual (fabs(y), 90.0))
+#define gmt_M_is_zero(x) (fabs (x) < GMT_CONV8_LIMIT)
 
 #ifndef D2R
 #define D2R (M_PI / 180.0)
@@ -251,9 +247,9 @@ struct GMT_PROJ {
 	bool inv_coordinates;	/* true if -fp[unit] was given and we must first recover lon,lat during reading */
 	bool N_hemi;		/* true if we only allow northern hemisphere oblique Mercator poles */
 	unsigned int n_antipoles;	/* Number of antipole coordinates so far [used for -JE only] */
-	struct GMT_LATSWAP_CONSTS GMT_lat_swap_vals;
+	struct GMT_LATSWAP_CONSTS lat_swap_vals;
 
-	enum GMT_enum_units inv_coord_unit;		/* Index to scale that converts input map coordinates to meter before inverting for lon,lat */
+	enum gmt_enum_units inv_coord_unit;		/* Index to scale that converts input map coordinates to meter before inverting for lon,lat */
 	char unit_name[GMT_N_UNITS][GMT_LEN16];	/* Names of the various distance units */
 	double m_per_unit[GMT_N_UNITS];	/* Meters in various units.  Use to scale units to meters */
 	double origin[3];		/* Projected values of the logical origin for the projection (x, y, z) */
@@ -304,6 +300,8 @@ struct GMT_PROJ {
 	double o_sin_pole_lat, o_cos_pole_lat;	/* Pole of rotation */
 	double o_pole_lon, o_pole_lat;	/* In degrees */
 	double o_beta;			/* lon' = beta for central_meridian (degrees) */
+	double o_shift;			/* Projected distance between oblique equator and chosen oblique latitude */
+	bool o_spole;			/* True if pole is in the southern hemisphere */
 	double o_FP[3], o_FC[3], o_IP[3], o_IC[3];
 
 	/* TM and UTM Projections */
@@ -423,7 +421,6 @@ enum GMT_enum_tick {GMT_ANNOT_UPPER = 0,	/* Tick annotations closest to the axis
 
 /* Some convenient macros for axis routines */
 
-#define GMT_uneven_interval(unit) ((unit == 'o' || unit == 'O' || unit == 'k' || unit == 'K' || unit == 'R' || unit == 'r' || unit == 'D' || unit == 'd') ? true : false)	/* true for uneven units */
 
 /* The array side in GMT_PLOT_FRAME follows the order south, east, north, west (CCW loop) + z.
  * Ro avoid using confusing indices 0-4 we define very brief constants S_SIDE, E_SIDE, N_SIDE
@@ -460,7 +457,7 @@ struct GMT_PLOT_AXIS_ITEM {		/* Information for one type of tick/annotation */
 struct GMT_PLOT_AXIS {		/* Information for one time axis */
 	unsigned int id;		/* 0 (x), 1(y), or 2(z) */
 	unsigned int type;		/* GMT_LINEAR, GMT_LOG10, GMT_POW, GMT_TIME */
-	unsigned int special;		/* 0, GMT_CUSTOM, GMT_CPT */
+	unsigned int special;		/* See gmt_enum_annot values */
 	unsigned int label_mode;	/* 0 = parallel to all axes, 1 = always horizontal on map */
 	struct GMT_PLOT_AXIS_ITEM item[6];	/* see above defines for which is which */
 	double phase;			/* Phase offset for strides: (knot-phase)%interval = 0  */
@@ -483,7 +480,7 @@ struct GMT_PLOT_FRAME {		/* Various parameters for plotting of time axis boundar
 	bool no_frame;			/* true if we just want gridlines but no frame, i.e +n was used */
 	bool check_side;		/* true if lon and lat annotations should be on x and y axis only */
 	bool primary;			/* true if current axis is primary, false if secondary */
-	bool slash;			/* true if slashes were used in the -B argument */
+	bool set_both;			/* true if -B argument applies to both x and y axes */
 	bool obl_grid;			/* true if +o was given to draw oblique gridlines */
 	unsigned int set_frame[2];	/* 1 if a -B<WESNframe> setting was given */
 	unsigned int horizontal;	/* 1 is S/N annotations should be parallel to axes, 2 if forced */
