@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *    $Id: gmtinfo.c 15178 2015-11-06 10:45:03Z fwobbe $
+ *    $Id: gmtinfo.c 17124 2016-09-22 21:35:10Z jluis $
  *
- *	Copyright (c) 1991-2015 by P. Wessel, W. H. F. Smith, R. Scharroo, J. Luis and F. Wobbe
+ *	Copyright (c) 1991-2016 by P. Wessel, W. H. F. Smith, R. Scharroo, J. Luis and F. Wobbe
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -27,14 +27,14 @@
 #define THIS_MODULE_NAME	"gmtinfo"
 #define THIS_MODULE_LIB		"core"
 #define THIS_MODULE_PURPOSE	"Get information about data tables"
-#define THIS_MODULE_KEYS	"<DI,>TO,>DC"
+#define THIS_MODULE_KEYS	"<D{,>T},>DC"
 
 #include "gmt_dev.h"
 
 #define GMT_PROG_OPTIONS "-:>Vbdfghiors" GMT_OPT("HMm")
 
-int gmt_geo_C_format (struct GMT_CTRL *GMT);
-unsigned int GMT_log_array (struct GMT_CTRL *GMT, double min, double max, double delta, double **array);
+EXTERN_MSC int gmtlib_geo_C_format (struct GMT_CTRL *GMT);
+EXTERN_MSC unsigned int gmtlib_log_array (struct GMT_CTRL *GMT, double min, double max, double delta, double **array);
 
 #define REPORT_PER_DATASET	0
 #define REPORT_PER_TABLE	1
@@ -71,6 +71,9 @@ struct MINMAX_CTRL {	/* All control options for this program (except common args
 		unsigned int mode;	/* Nominally 0, unless set to BEST_FOR_SURF, BEST_FOR_FFT or ACTUAL_BOUNDS */
 		double inc[GMT_MAX_COLUMNS];
 	} I;
+	struct L {	/* -L */
+		bool active;
+	} L;
 	struct S {	/* -S[x|y] */
 		bool active;
 		bool xbar, ybar;
@@ -82,40 +85,39 @@ struct MINMAX_CTRL {	/* All control options for this program (except common args
 	} T;
 };
 
-int strip_blanks_and_output (struct GMT_CTRL *GMT, char *text, double x, int col)
-{	/* Alternative to GMT_ascii_output_col that strips off leading blanks first */
+GMT_LOCAL int strip_blanks_and_output (struct GMT_CTRL *GMT, char *text, double x, int col) {
+	/* Alternative to GMT_ascii_output_col that strips off leading blanks first */
 
 	int k;
 
-	GMT_ascii_format_col (GMT, text, x, GMT_OUT, col);
+	gmt_ascii_format_col (GMT, text, x, GMT_OUT, col);
 	for (k = 0; text[k] && text[k] == ' '; k++);
 	return (k);	/* This is the position in text that we should start reporting from */
 }
 
-void *New_gmtinfo_Ctrl (struct GMT_CTRL *GMT) {	/* Allocate and initialize a new control structure */
+GMT_LOCAL void *New_Ctrl (struct GMT_CTRL *GMT) {	/* Allocate and initialize a new control structure */
 	struct MINMAX_CTRL *C = NULL;
 	
-	C = GMT_memory (GMT, NULL, 1, struct MINMAX_CTRL);
+	C = gmt_M_memory (GMT, NULL, 1, struct MINMAX_CTRL);
 	
 	/* Initialize values whose defaults are not 0/false/NULL */
 	C->E.col = UINT_MAX;	/* Meaning not set */
 	return (C);
 }
 
-void Free_gmtinfo_Ctrl (struct GMT_CTRL *GMT, struct MINMAX_CTRL *C) {	/* Deallocate control structure */
+GMT_LOCAL void Free_Ctrl (struct GMT_CTRL *GMT, struct MINMAX_CTRL *C) {	/* Deallocate control structure */
 	if (!C) return;
-	GMT_free (GMT, C);
+	gmt_M_free (GMT, C);
 }
 
-int GMT_gmtinfo_usage (struct GMTAPI_CTRL *API, int level)
-{
-	GMT_show_name_and_purpose (API, THIS_MODULE_LIB, THIS_MODULE_NAME, THIS_MODULE_PURPOSE);
+GMT_LOCAL int usage (struct GMTAPI_CTRL *API, int level) {
+	gmt_show_name_and_purpose (API, THIS_MODULE_LIB, THIS_MODULE_NAME, THIS_MODULE_PURPOSE);
 	if (level == GMT_MODULE_PURPOSE) return (GMT_NOERROR);
 	GMT_Message (API, GMT_TIME_NONE, "usage: gmtinfo [<table>] [-Aa|f|s] [-C] [-D[<dx>[/<dy>]] [-E<L|l|H|h><col>] [-I[p|f|s]<dx>[/<dy>[/<dz>..]]\n");
-	GMT_Message (API, GMT_TIME_NONE, "\t[-S[x][y]] [-T<dz>[/<col>]] [%s] [%s] [%s]\n\t[%s] [%s]\n\t[%s] [%s]\n\t[%s] [%s] [%s] [%s]\n",
+	GMT_Message (API, GMT_TIME_NONE, "\t[-L] [-S[x][y]] [-T<dz>[/<col>]] [%s] [%s] [%s]\n\t[%s] [%s]\n\t[%s] [%s]\n\t[%s] [%s] [%s] [%s]\n",
 		GMT_V_OPT, GMT_bi_OPT, GMT_d_OPT, GMT_f_OPT, GMT_g_OPT, GMT_h_OPT, GMT_i_OPT, GMT_o_OPT, GMT_r_OPT, GMT_s_OPT, GMT_colon_OPT);
 
-	if (level == GMT_SYNOPSIS) return (EXIT_FAILURE);
+	if (level == GMT_SYNOPSIS) return (GMT_MODULE_SYNOPSIS);
 
 	GMT_Message (API, GMT_TIME_NONE, "\n\tOPTIONS:\n");
 	GMT_Option (API, "<");
@@ -136,6 +138,8 @@ int GMT_gmtinfo_usage (struct GMTAPI_CTRL *API, int level)
 	GMT_Message (API, GMT_TIME_NONE, "\t     and allow -r to change from gridline-registration to pixel-registration.\n");
 	GMT_Message (API, GMT_TIME_NONE, "\t   Use -If<dx>[/<dy>] to report an extended region optimized for fastest results in FFTs.\n");
 	GMT_Message (API, GMT_TIME_NONE, "\t   Use -Is<dx>[/<dy>] to report an extended region optimized for fastest results in surface.\n");
+	GMT_Message (API, GMT_TIME_NONE, "\t-L Determine limiting region. With -I it rounds inward so bounds are within data range.\n");
+	GMT_Message (API, GMT_TIME_NONE, "\t   Use -A to find the limiting common bounds of all segments or tables.\n");
 	GMT_Message (API, GMT_TIME_NONE, "\t-S Add extra space for error bars. Useful together with -I.\n");
 	GMT_Message (API, GMT_TIME_NONE, "\t   -Sx leaves space for horizontal error bar using value in third (2) column.\n");
 	GMT_Message (API, GMT_TIME_NONE, "\t   -Sy leaves space for vertical error bar using value in third (2) column.\n");
@@ -144,11 +148,10 @@ int GMT_gmtinfo_usage (struct GMTAPI_CTRL *API, int level)
 	GMT_Message (API, GMT_TIME_NONE, "\t   Calculations are based on the first (0) column only.  Append /<col> to use another column.\n");
 	GMT_Option (API, "V,bi2,d,f,g,h,i,o,r,s,:,.");
 	
-	return (EXIT_FAILURE);
+	return (GMT_MODULE_USAGE);
 }
 
-int GMT_gmtinfo_parse (struct GMT_CTRL *GMT, struct MINMAX_CTRL *Ctrl, struct GMT_OPTION *options)
-{
+GMT_LOCAL int parse (struct GMT_CTRL *GMT, struct MINMAX_CTRL *Ctrl, struct GMT_OPTION *options) {
 	/* This parses the options provided to gmtinfo and sets parameters in CTRL.
 	 * Any GMT common options will override values set previously by other commands.
 	 * It also replaces any file names specified as input or output with the data ID
@@ -165,7 +168,7 @@ int GMT_gmtinfo_parse (struct GMT_CTRL *GMT, struct MINMAX_CTRL *Ctrl, struct GM
 		switch (opt->option) {
 
 			case '<':	/* Input files */
-				if (!GMT_check_filearg (GMT, '<', opt->arg, GMT_IN, GMT_IS_DATASET)) n_errors++;
+				if (!gmt_check_filearg (GMT, '<', opt->arg, GMT_IN, GMT_IS_DATASET)) n_errors++;
 				break;
 
 			/* Processes program-specific parameters */
@@ -194,9 +197,9 @@ int GMT_gmtinfo_parse (struct GMT_CTRL *GMT, struct MINMAX_CTRL *Ctrl, struct GM
 			case 'D':	/* Region adjustment Granularity */
 				Ctrl->D.active = true;
 				if (opt->arg[0]) {
-					Ctrl->D.ncol = GMT_getincn (GMT, opt->arg, Ctrl->D.inc, GMT_MAX_COLUMNS);
+					Ctrl->D.ncol = gmt_getincn (GMT, opt->arg, Ctrl->D.inc, GMT_MAX_COLUMNS);
 					Ctrl->D.mode = 1;
-					GMT_check_lattice (GMT, Ctrl->D.inc, NULL, &Ctrl->D.active);
+					gmt_check_lattice (GMT, Ctrl->D.inc, NULL, &Ctrl->D.active);
 				}
 				break;
 			case 'E':	/* Extrema reporting */
@@ -229,7 +232,10 @@ int GMT_gmtinfo_parse (struct GMT_CTRL *GMT, struct MINMAX_CTRL *Ctrl, struct GM
 					case '-': Ctrl->I.mode = ACTUAL_BOUNDS; break;
 					default: j = 0;	break;
 				}
-				Ctrl->I.ncol = (Ctrl->I.mode == ACTUAL_BOUNDS) ? 2 : GMT_getincn (GMT, &opt->arg[j], Ctrl->I.inc, GMT_MAX_COLUMNS);
+				Ctrl->I.ncol = (Ctrl->I.mode == ACTUAL_BOUNDS) ? 2 : gmt_getincn (GMT, &opt->arg[j], Ctrl->I.inc, GMT_MAX_COLUMNS);
+				break;
+			case 'L':	/* Detect limiting range */
+				Ctrl->L.active = true;
 				break;
 			case 'S':	/* Error bar output */
 				Ctrl->S.active = true;
@@ -248,15 +254,15 @@ int GMT_gmtinfo_parse (struct GMT_CTRL *GMT, struct MINMAX_CTRL *Ctrl, struct GM
 				break;
 
 			case 'b':	/* -b[i]c will land here */
-				if (GMT_compat_check (GMT, 4)) break;
+				if (gmt_M_compat_check (GMT, 4)) break;
 
 			default:	/* Report bad options */
-				n_errors += GMT_default_error (GMT, opt->option);
+				n_errors += gmt_default_error (GMT, opt->option);
 				break;
 		}
 	}
 
-	if (Ctrl->I.mode != ACTUAL_BOUNDS) GMT_check_lattice (GMT, Ctrl->I.inc, NULL, &Ctrl->I.active);
+	if (Ctrl->I.mode != ACTUAL_BOUNDS) gmt_check_lattice (GMT, Ctrl->I.inc, NULL, &Ctrl->I.active);
 	if (Ctrl->I.active && special && Ctrl->I.ncol > 1) {
 		GMT_Report (API, GMT_MSG_NORMAL, "Syntax error -Ip. Only a single increment is expected.\n");
 		n_errors++;
@@ -269,22 +275,25 @@ int GMT_gmtinfo_parse (struct GMT_CTRL *GMT, struct MINMAX_CTRL *Ctrl, struct GM
 		Ctrl->D.inc[GMT_Y] = Ctrl->D.inc[GMT_X];
 		Ctrl->D.ncol = 2;
 	}
-	n_errors += GMT_check_condition (GMT, Ctrl->D.active && !Ctrl->I.active, "Syntax error: -D requires -I\n");
-	n_errors += GMT_check_condition (GMT, Ctrl->I.active && !Ctrl->C.active && Ctrl->I.ncol < 2, "Syntax error: -Ip requires -C\n");
-	n_errors += GMT_check_condition (GMT, Ctrl->I.active && Ctrl->T.active, "Syntax error: Only one of -I and -T can be specified\n");
-	n_errors += GMT_check_condition (GMT, Ctrl->T.active && Ctrl->T.inc <= 0.0 , "Syntax error -T option: Must specify a positive increment\n");
+	n_errors += gmt_M_check_condition (GMT, Ctrl->D.active && !Ctrl->I.active, "Syntax error: -D requires -I\n");
+	n_errors += gmt_M_check_condition (GMT, Ctrl->I.active && !Ctrl->C.active && Ctrl->I.ncol < 2,
+	                                   "Syntax error: -Ip requires -C\n");
+	n_errors += gmt_M_check_condition (GMT, Ctrl->I.active && Ctrl->T.active,
+	                                   "Syntax error: Only one of -I and -T can be specified\n");
+	n_errors += gmt_M_check_condition (GMT, Ctrl->T.active && Ctrl->T.inc <= 0.0 ,
+	                                   "Syntax error -T option: Must specify a positive increment\n");
 	for (k = 0; Ctrl->I.active && k < Ctrl->I.ncol; k++) {
-		n_errors += GMT_check_condition (GMT, Ctrl->I.mode != ACTUAL_BOUNDS && Ctrl->I.inc[k] <= 0.0, "Syntax error -I option: Must specify positive increment(s)\n");
+		n_errors += gmt_M_check_condition (GMT, Ctrl->I.mode != ACTUAL_BOUNDS && Ctrl->I.inc[k] <= 0.0,
+		                                   "Syntax error -I option: Must specify positive increment(s)\n");
 	}
-	n_errors += GMT_check_binary_io (GMT, 1);
-	return (n_errors ? GMT_PARSE_ERROR : GMT_OK);
+	n_errors += gmt_check_binary_io (GMT, 1);
+	return (n_errors ? GMT_PARSE_ERROR : GMT_NOERROR);
 }
 
-#define bailout(code) {GMT_Free_Options (mode); return (code);}
-#define Return(code) {Free_gmtinfo_Ctrl (GMT, Ctrl); if (xyzmin) GMT_free (GMT, xyzmin); if (xyzmax) GMT_free (GMT, xyzmax); if (Q) GMT_free (GMT, Q); GMT_end_module (GMT, GMT_cpy); bailout (code);}
+#define bailout(code) {gmt_M_free_options (mode); return (code);}
+#define Return(code) {Free_Ctrl (GMT, Ctrl); gmt_M_free (GMT, xyzmin); gmt_M_free (GMT, xyzmax); gmt_M_free (GMT, xyzminL); gmt_M_free (GMT, xyzmaxL); gmt_M_free (GMT, Q); gmt_end_module (GMT, GMT_cpy); bailout (code);}
 
-int GMT_gmtinfo (void *V_API, int mode, void *args)
-{
+int GMT_gmtinfo (void *V_API, int mode, void *args) {
 	bool got_stuff = false, first_data_record, give_r_string = false;
 	bool brackets = false, work_on_abs_value, do_report, done, full_range = false;
 	int i, j, error = 0, col_type[GMT_MAX_COLUMNS];
@@ -295,28 +304,29 @@ int GMT_gmtinfo (void *V_API, int mode, void *args)
 
 	double *xyzmin = NULL, *xyzmax = NULL, *in = NULL, *dchosen = NULL, phase[2] = {0.0, 0.0}, this_phase, off;
 	double west = 0.0, east = 0.0, south = 0.0, north = 0.0, low, high, value, e_min = DBL_MAX, e_max = -DBL_MAX;
+	double *xyzminL = NULL, *xyzmaxL = NULL;
 
 	struct GMT_QUAD *Q = NULL;
 	struct MINMAX_CTRL *Ctrl = NULL;
 	struct GMT_CTRL *GMT = NULL, *GMT_cpy = NULL;
 	struct GMT_OPTION *options = NULL;
-	struct GMTAPI_CTRL *API = GMT_get_API_ptr (V_API);	/* Cast from void to GMTAPI_CTRL pointer */
+	struct GMTAPI_CTRL *API = gmt_get_api_ptr (V_API);	/* Cast from void to GMTAPI_CTRL pointer */
 
 	/*----------------------- Standard module initialization and parsing ----------------------*/
 
 	if (API == NULL) return (GMT_NOT_A_SESSION);
-	if (mode == GMT_MODULE_PURPOSE) return (GMT_gmtinfo_usage (API, GMT_MODULE_PURPOSE));	/* Return the purpose of program */
+	if (mode == GMT_MODULE_PURPOSE) return (usage (API, GMT_MODULE_PURPOSE));	/* Return the purpose of program */
 	options = GMT_Create_Options (API, mode, args);	if (API->error) return (API->error);	/* Set or get option list */
 
-	if (options && options->option == GMT_OPT_USAGE) bailout (GMT_gmtinfo_usage (API, GMT_USAGE));	/* Return the usage message */
-	if (options && options->option == GMT_OPT_SYNOPSIS) bailout (GMT_gmtinfo_usage (API, GMT_SYNOPSIS));	/* Return the synopsis */
+	if (options && options->option == GMT_OPT_USAGE) bailout (usage (API, GMT_USAGE));	/* Return the usage message */
+	if (options && options->option == GMT_OPT_SYNOPSIS) bailout (usage (API, GMT_SYNOPSIS));	/* Return the synopsis */
 
 	/* Parse the command-line arguments */
 
-	GMT = GMT_begin_module (API, THIS_MODULE_LIB, THIS_MODULE_NAME, &GMT_cpy); /* Save current state */
+	GMT = gmt_begin_module (API, THIS_MODULE_LIB, THIS_MODULE_NAME, &GMT_cpy); /* Save current state */
 	if (GMT_Parse_Common (API, GMT_PROG_OPTIONS, options)) Return (API->error);
-	Ctrl = New_gmtinfo_Ctrl (GMT);	/* Allocate and initialize a new control structure */
-	if ((error = GMT_gmtinfo_parse (GMT, Ctrl, options)) != 0) Return (error);
+	Ctrl = New_Ctrl (GMT);	/* Allocate and initialize a new control structure */
+	if ((error = parse (GMT, Ctrl, options)) != 0) Return (error);
 
 	/*---------------------------- This is the gmtinfo main code ----------------------------*/
 
@@ -328,38 +338,41 @@ int GMT_gmtinfo (void *V_API, int mode, void *args)
 
 	brackets = !Ctrl->C.active;
 	work_on_abs_value = (Ctrl->E.active && Ctrl->E.abs);
-	if (GMT_x_is_lon (GMT, GMT_IN)) {	/* Must check that output format won't mess things up by printing west > east */
+	if (gmt_M_x_is_lon (GMT, GMT_IN)) {	/* Must check that output format won't mess things up by printing west > east */
 		if (!strcmp (GMT->current.setting.format_geo_out, "D")) {
 			strcpy (GMT->current.setting.format_geo_out, "+D");
-			GMT_err_fail (GMT, gmt_geo_C_format (GMT), "");
-			GMT_Report (API, GMT_MSG_VERBOSE, "Warning: FORMAT_GEO_OUT reset from D to %s to ensure east > west\n", GMT->current.setting.format_geo_out);
+			gmt_M_err_fail (GMT, gmtlib_geo_C_format (GMT), "");
+			GMT_Report (API, GMT_MSG_VERBOSE, "Warning: FORMAT_GEO_OUT reset from D to %s to ensure east > west\n",
+			            GMT->current.setting.format_geo_out);
 		}
 		else if (!strcmp (GMT->current.setting.format_geo_out, "ddd:mm:ss")) {
 			strcpy (GMT->current.setting.format_geo_out, "ddd:mm:ssF");
-			GMT_err_fail (GMT, gmt_geo_C_format (GMT), "");
-			GMT_Report (API, GMT_MSG_VERBOSE, "Warning: FORMAT_GEO_OUT reset from ddd:mm:ss to %s to ensure east > west\n", GMT->current.setting.format_geo_out);
+			gmt_M_err_fail (GMT, gmtlib_geo_C_format (GMT), "");
+			GMT_Report (API, GMT_MSG_VERBOSE, "Warning: FORMAT_GEO_OUT reset from ddd:mm:ss to %s to ensure east > west\n",
+			            GMT->current.setting.format_geo_out);
 		}
 	}
 
-	if ((error = GMT_set_cols (GMT, GMT_IN, 0)) != 0) Return (error);
+	if ((error = gmt_set_cols (GMT, GMT_IN, 0)) != 0) Return (error);
 	o_mode = (Ctrl->C.active) ? GMT_IS_DATASET : GMT_IS_TEXTSET;
-	if (GMT_Init_IO (API, GMT_IS_DATASET, GMT_IS_NONE, GMT_IN,  GMT_ADD_DEFAULT, 0, options) != GMT_OK) {	/* Establishes data input */
+	if (GMT_Init_IO (API, GMT_IS_DATASET, GMT_IS_NONE, GMT_IN,  GMT_ADD_DEFAULT, 0, options) != GMT_NOERROR) {	/* Establishes data input */
 		Return (API->error);
 	}
-	if (GMT_Init_IO (API, o_mode, GMT_IS_NONE, GMT_OUT, GMT_ADD_DEFAULT, 0, options) != GMT_OK) {	/* Establishes data output */
+	if (GMT_Init_IO (API, o_mode, GMT_IS_NONE, GMT_OUT, GMT_ADD_DEFAULT, 0, options) != GMT_NOERROR) {	/* Establishes data output */
 		Return (API->error);
 	}
 
-	if (GMT_Begin_IO (API, GMT_IS_DATASET,  GMT_IN, GMT_HEADER_ON) != GMT_OK) {	/* Enables data input and sets access mode */
+	if (GMT_Begin_IO (API, GMT_IS_DATASET,  GMT_IN, GMT_HEADER_ON) != GMT_NOERROR) {	/* Enables data input and sets access mode */
 		Return (API->error);	/* Enables data output and sets access mode */
 	}
-	if (GMT_Begin_IO (API, o_mode, GMT_OUT, GMT_HEADER_OFF) != GMT_OK) {
+	if (GMT_Begin_IO (API, o_mode, GMT_OUT, GMT_HEADER_OFF) != GMT_NOERROR) {
 		Return (API->error);
 	}
 
 	if (Ctrl->C.active) {	/* Must set output column types since each input col will produce two output cols. */
-		GMT_memcpy (col_type, GMT->current.io.col_type[GMT_OUT], GMT_MAX_COLUMNS, int);	/* Save previous output col types */
-		for (col = 0; col < GMT_MAX_COLUMNS/2; col++) GMT->current.io.col_type[GMT_OUT][2*col] = GMT->current.io.col_type[GMT_OUT][2*col+1] = GMT->current.io.col_type[GMT_IN][col];
+		gmt_M_memcpy (col_type, GMT->current.io.col_type[GMT_OUT], GMT_MAX_COLUMNS, int);	/* Save previous output col types */
+		for (col = 0; col < GMT_MAX_COLUMNS/2; col++)
+			GMT->current.io.col_type[GMT_OUT][2*col] = GMT->current.io.col_type[GMT_OUT][2*col+1] = GMT->current.io.col_type[GMT_IN][col];
 	}
 		
 	save_range = GMT->current.io.geo.range;
@@ -369,13 +382,13 @@ int GMT_gmtinfo (void *V_API, int mode, void *args)
 		in = GMT_Get_Record (API, GMT_READ_DOUBLE | GMT_READ_FILEBREAK, NULL);
 		do_report = false;
 
-		if (GMT_REC_IS_ERROR (GMT)) Return (GMT_RUNTIME_ERROR);
-		if (GMT_REC_IS_TABLE_HEADER (GMT)) continue;	/* Skip table headers */
-		if ((GMT_REC_IS_SEGMENT_HEADER (GMT) && Ctrl->A.mode != REPORT_PER_SEGMENT)) continue;	/* Since we are not reporting per segment they are just headers as far as we are concerned */
+		if (gmt_M_rec_is_error (GMT)) Return (GMT_RUNTIME_ERROR);
+		if (gmt_M_rec_is_table_header (GMT)) continue;	/* Skip table headers */
+		if ((gmt_M_rec_is_segment_header (GMT) && Ctrl->A.mode != REPORT_PER_SEGMENT)) continue;	/* Since we are not reporting per segment they are just headers as far as we are concerned */
 		
-		if (GMT_REC_IS_SEGMENT_HEADER (GMT) || (GMT_REC_IS_FILE_BREAK (GMT) && Ctrl->A.mode == REPORT_PER_TABLE) || GMT_REC_IS_EOF (GMT)) {	/* Time to report */
-			if (GMT_REC_IS_SEGMENT_HEADER (GMT) && GMT->current.io.seg_no == 0) continue;	/* Very first segment header means there is no prior segment to report on yet */
-			if (GMT_REC_IS_EOF (GMT)) {	/* We are done after this since we hit EOF */
+		if (gmt_M_rec_is_segment_header (GMT) || (Ctrl->A.mode == REPORT_PER_TABLE && gmt_M_rec_is_file_break (GMT)) || gmt_M_rec_is_eof (GMT)) {	/* Time to report */
+			if (gmt_M_rec_is_segment_header (GMT) && GMT->current.io.seg_no == 0) continue;	/* Very first segment header means there is no prior segment to report on yet */
+			if (gmt_M_rec_is_eof (GMT)) {	/* We are done after this since we hit EOF */
 				done = true;
 				GMT->current.io.seg_no++;	/* Must manually increment since we are not reading any futher */
 			}
@@ -384,26 +397,35 @@ int GMT_gmtinfo (void *V_API, int mode, void *args)
 			/* Here we must issue a report */
 			
 			do_report = true;
+			if (Ctrl->L.active && !gmt_M_rec_is_eof (GMT)) do_report = false;	/* Only final report for -L */
  			for (col = 0; col < ncol; col++) if (GMT->current.io.col_type[GMT_IN][col] == GMT_IS_LON) {	/* Must finalize longitudes first */
-				j = GMT_quad_finalize (GMT, &Q[col]);
+				j = gmt_quad_finalize (GMT, &Q[col]);
 				GMT->current.io.geo.range = Q[col].range[j];		/* Override this setting explicitly */
 				xyzmin[col] = Q[col].min[j];	xyzmax[col] = Q[col].max[j];
 			}
 			if (Ctrl->I.active) {	/* Must report multiples of dx/dy etc */
 				if (n > 1 && fixed_phase[GMT_X] && fixed_phase[GMT_Y]) {	/* Got xy[z] data that lined up on a grid, so use the common phase shift */
-					GMT_Report (API, GMT_MSG_LONG_VERBOSE, "Input (x,y) data are regularly distributed; fixed phase shifts are %g/%g.\n", phase[GMT_X], phase[GMT_Y]);
+					GMT_Report (API, GMT_MSG_LONG_VERBOSE, "Input (x,y) data are regularly distributed; fixed phase shifts are %g/%g.\n",
+					            phase[GMT_X], phase[GMT_Y]);
 				}
 				else {	/* Data not on grid, just return bounding box rounded off to nearest inc */
 					buffer[0] = '.';	buffer[1] = 0;
 					if (GMT->common.r.active) strcpy (buffer, " (-r is ignored).");
-					GMT_Report (API, GMT_MSG_LONG_VERBOSE, "Input (x,y) data are irregularly distributed; phase shifts set to 0/0%s\n", buffer);
+					GMT_Report (API, GMT_MSG_LONG_VERBOSE,
+					            "Input (x,y) data are irregularly distributed; phase shifts set to 0/0%s\n", buffer);
 					phase[GMT_X] = phase[GMT_Y] = off = 0.0;
 				}
 				if (Ctrl->I.mode == ACTUAL_BOUNDS) {
 					west  = xyzmin[GMT_X];	east  = xyzmax[GMT_X];
 					south = xyzmin[GMT_Y];	north = xyzmax[GMT_Y];
 				}
-				else { /* Round off to nearest inc */
+				else if (Ctrl->L.active) { /* Round down to nearest inc for this segment or table */
+					west  = (ceil ((xyzmin[GMT_X] - phase[GMT_X]) / Ctrl->I.inc[GMT_X]) - off) * Ctrl->I.inc[GMT_X] + phase[GMT_X];
+					east  = (floor  ((xyzmax[GMT_X] - phase[GMT_X]) / Ctrl->I.inc[GMT_X]) + off) * Ctrl->I.inc[GMT_X] + phase[GMT_X];
+					south = (ceil ((xyzmin[GMT_Y] - phase[GMT_Y]) / Ctrl->I.inc[GMT_Y]) - off) * Ctrl->I.inc[GMT_Y] + phase[GMT_Y];
+					north = (floor  ((xyzmax[GMT_Y] - phase[GMT_Y]) / Ctrl->I.inc[GMT_Y]) + off) * Ctrl->I.inc[GMT_Y] + phase[GMT_Y];
+				}
+				else { /* Round up to nearest inc */
 					west  = (floor ((xyzmin[GMT_X] - phase[GMT_X]) / Ctrl->I.inc[GMT_X]) - off) * Ctrl->I.inc[GMT_X] + phase[GMT_X];
 					east  = (ceil  ((xyzmax[GMT_X] - phase[GMT_X]) / Ctrl->I.inc[GMT_X]) + off) * Ctrl->I.inc[GMT_X] + phase[GMT_X];
 					south = (floor ((xyzmin[GMT_Y] - phase[GMT_Y]) / Ctrl->I.inc[GMT_Y]) - off) * Ctrl->I.inc[GMT_Y] + phase[GMT_Y];
@@ -417,36 +439,44 @@ int GMT_gmtinfo (void *V_API, int mode, void *args)
 						south += off;	north += off;
 					}
 				}
-				if (GMT_is_geographic (GMT, GMT_IN)) {
-					if (GMT_is_geographic (GMT, GMT_IN)) {	/* Must make sure we dont get outside valid bounds */
+				if (gmt_M_is_geographic (GMT, GMT_IN)) {
+					if (gmt_M_is_geographic (GMT, GMT_IN)) {	/* Must make sure we dont get outside valid bounds */
 						if (south < -90.0) {
 							south = -90.0;
-							GMT_Report (API, GMT_MSG_VERBOSE, "Warning: Using -I caused south to become < -90.  Reset to -90.\n");
+							GMT_Report (API, GMT_MSG_VERBOSE, "Warning: Using -I caused south to become < -90. Reset to -90.\n");
 						}
 						if (north > 90.0) {
 							north = 90.0;
-							GMT_Report (API, GMT_MSG_VERBOSE, "Warning: Using -I caused north to become > +90.  Reset to +90.\n");
+							GMT_Report (API, GMT_MSG_VERBOSE, "Warning: Using -I caused north to become > +90. Reset to +90.\n");
 						}
 						if (fabs (east - west) > 360.0) {
-							GMT_Report (API, GMT_MSG_VERBOSE, "Warning: Using -I caused longitude range to exceed 360.  Reset to a range of 360.\n");
+							GMT_Report (API, GMT_MSG_VERBOSE,
+							            "Warning: Using -I caused longitude range to exceed 360. Reset to a range of 360.\n");
 							west = (west < 0.0) ? -180.0 : 0.0;
 							east = (west < 0.0) ? +180.0 : 360.0;
 							full_range = true;
 						}
 					}
 				}
-				if (Ctrl->I.mode == BEST_FOR_FFT || Ctrl->I.mode == BEST_FOR_SURF) {	/* Wish to extend the region to optimize the resulting nx/ny */
+				if (Ctrl->L.active) {
+					for (col = 0; col < ncol; col++) {	/* Report innermost min/max for each column */
+						if (xyzmin[col] > xyzminL[col]) xyzminL[col] = xyzmin[col];
+						if (xyzmax[col] < xyzmaxL[col]) xyzmaxL[col] = xyzmax[col];
+					}
+				}
+				if (Ctrl->I.mode == BEST_FOR_FFT || Ctrl->I.mode == BEST_FOR_SURF) {	/* Wish to extend the region to optimize the resulting n_columns/n_rows */
 					unsigned int sub, add, in_dim[2], out_dim[2];
 					double ww, ee, ss, nn;
-					in_dim[GMT_X] = GMT_get_n (GMT, west, east, Ctrl->I.inc[GMT_X], GMT->common.r.active);
-					in_dim[GMT_Y] = GMT_get_n (GMT, south, north, Ctrl->I.inc[GMT_Y], GMT->common.r.active);
+					in_dim[GMT_X] = gmt_M_get_n (GMT, west, east, Ctrl->I.inc[GMT_X], GMT->common.r.active);
+					in_dim[GMT_Y] = gmt_M_get_n (GMT, south, north, Ctrl->I.inc[GMT_Y], GMT->common.r.active);
 					ww = west;	ee = east; ss = south;	nn = north;
-					GMT_best_dim_choice (GMT, Ctrl->I.mode, in_dim, out_dim);
+					gmt_best_dim_choice (GMT, Ctrl->I.mode, in_dim, out_dim);
 					sub = (out_dim[GMT_X] - in_dim[GMT_X]) / 2;	add = out_dim[GMT_X] - in_dim[GMT_X] - sub;
 					west  -= sub * Ctrl->I.inc[GMT_X];		east  += add * Ctrl->I.inc[GMT_X];
 					sub = (out_dim[GMT_Y] - in_dim[GMT_Y]) / 2;	add = out_dim[GMT_Y] - in_dim[GMT_Y] - sub;
 					south -= sub * Ctrl->I.inc[GMT_Y];		north += add * Ctrl->I.inc[GMT_Y];
-					GMT_Report (API, GMT_MSG_VERBOSE, "Initial -R: %g/%g/%g/%g [nx = %u ny = %u] --> Suggested -R:  %g/%g/%g/%g [nx = %u ny = %u].\n",
+					GMT_Report (API, GMT_MSG_VERBOSE,
+					            "Initial -R: %g/%g/%g/%g [n_columns = %u n_rows = %u] --> Suggested -R:  %g/%g/%g/%g [n_columns = %u n_rows = %u].\n",
 						ww, ee, ss, nn, in_dim[GMT_X], in_dim[GMT_Y], west, east, south, north, out_dim[GMT_X], out_dim[GMT_Y]);
 				}
 			}
@@ -472,9 +502,9 @@ int GMT_gmtinfo (void *V_API, int mode, void *args)
 			else if (Ctrl->E.active) {	/* Return extreme record */
 				int sep = 0;
 				if (GMT->common.b.active[GMT_IN]) {	/* Make ASCII record */
-					GMT_memset (chosen, GMT_BUFSIZ, char);
+					gmt_M_memset (chosen, GMT_BUFSIZ, char);
 					for (col = 0; col < ncol; col++) {	/* Report min/max for each column in the format controlled by -C */
-						GMT_add_to_record (GMT, chosen, dchosen[col], col, sep);
+						gmt_add_to_record (GMT, chosen, dchosen[col], col, GMT_OUT, sep);
 						sep = 1;
 					}
 				}
@@ -504,6 +534,16 @@ int GMT_gmtinfo (void *V_API, int mode, void *args)
 							low  = south;
 							high = north;
 						}
+						else if (Ctrl->L.active) {
+							low  = (Ctrl->I.active) ? ceil  (xyzmin[col] / Ctrl->I.inc[col]) * Ctrl->I.inc[col] : xyzmin[col];
+							high = (Ctrl->I.active) ? floor (xyzmax[col] / Ctrl->I.inc[col]) * Ctrl->I.inc[col] : xyzmax[col];
+							if (low  > xyzminL[col]) xyzminL[col] = low;
+							if (high < xyzmax[col])  xyzmaxL[col] = high;
+							if (do_report) {	/* Last time so finalize */
+								low  = xyzminL[col];
+								high = xyzmaxL[col];
+							}
+						}
 						else {
 							low  = (Ctrl->I.active) ? floor (xyzmin[col] / Ctrl->I.inc[col]) * Ctrl->I.inc[col] : xyzmin[col];
 							high = (Ctrl->I.active) ? ceil  (xyzmax[col] / Ctrl->I.inc[col]) * Ctrl->I.inc[col] : xyzmax[col];
@@ -519,104 +559,107 @@ int GMT_gmtinfo (void *V_API, int mode, void *args)
 					}
 					else {
 						if (brackets) strcat (record, "<");
-						GMT_ascii_format_col (GMT, buffer, low, GMT_OUT, col);
+						gmt_ascii_format_col (GMT, buffer, low, GMT_OUT, col);
 						strcat (record, buffer);
 						strcat (record, delimeter);
-						GMT_ascii_format_col (GMT, buffer, high, GMT_OUT, col);
+						gmt_ascii_format_col (GMT, buffer, high, GMT_OUT, col);
 						strcat (record, buffer);
 						if (brackets) strcat (record, ">");
 						if (col < (ncol - 1)) strcat (record, "\t");
 					}
 				}
 			}
-			if (Ctrl->C.active) {	/* Plain data record */
-				GMT_Put_Record (API, GMT_WRITE_DOUBLE, GMT->current.io.curr_rec);	/* Write data record to output destination */
-			}
-			else {
-				strcat (record, "\n");
-				GMT_Put_Record (API, GMT_WRITE_TEXT, record);	/* Write text record to output destination */
+			if (do_report) {
+				if (Ctrl->C.active) {	/* Plain data record */
+					GMT_Put_Record (API, GMT_WRITE_DOUBLE, GMT->current.io.curr_rec);	/* Write data record to output destination */
+				}
+				else {
+					GMT_Put_Record (API, GMT_WRITE_TEXT, record);	/* Write text record to output destination */
+				}
 			}
 			got_stuff = true;		/* We have at least reported something */
 			for (col = 0; col < ncol; col++) {	/* Reset counters for next block */
 				xyzmin[col] = DBL_MAX;
 				xyzmax[col] = -DBL_MAX;
 			}
-			GMT_quad_reset (GMT, Q, ncol);
+			gmt_quad_reset (GMT, Q, ncol);
 			n = 0;
 			file[0] = '\0';
 			fixed_phase[GMT_X] = fixed_phase[GMT_Y] = 1;	/* Get ready for next batch */
-			if (done || do_report || GMT_REC_IS_FILE_BREAK (GMT)) continue;	/* We are done OR have no data record to process yet */
+			if (done || do_report || gmt_M_rec_is_file_break (GMT)) continue;	/* We are done OR have no data record to process yet */
 		}
-		if (GMT_REC_IS_FILE_BREAK (GMT)) continue;
+		if (gmt_M_rec_is_file_break (GMT)) continue;
 
 		/* We get here once we have read a data record */
 		
 		if (first_data_record) {	/* First time we read data, we must allocate arrays based on the number of columns */
 
-			ncol = GMT_get_cols (GMT, GMT_IN);
+			ncol = gmt_get_cols (GMT, GMT_IN);
 			if (Ctrl->E.active) {
 				if (Ctrl->E.col == UINT_MAX) Ctrl->E.col = ncol - 1;	/* Default is last column */
-				if (GMT->common.b.active[GMT_IN]) dchosen = GMT_memory (GMT, NULL, ncol, double);
+				if (GMT->common.b.active[GMT_IN]) dchosen = gmt_M_memory (GMT, NULL, ncol, double);
 			}
 			min_cols = 2;	if (Ctrl->S.xbar) min_cols++;	if (Ctrl->S.ybar) min_cols++;
 			if (Ctrl->S.active && min_cols > ncol) {
 				GMT_Report (API, GMT_MSG_NORMAL, "Not enough columns to support the -S option\n");
-				Return (EXIT_FAILURE);
+				Return (GMT_DIM_TOO_SMALL);
 			}
 			if (Ctrl->E.active && Ctrl->E.col >= ncol) {
   				GMT_Report (API, GMT_MSG_NORMAL, "Syntax error -E option: Chosen column exceeds column range (0-%d)\n", ncol-1);
-				Return (EXIT_FAILURE);
+				Return (GMT_DIM_TOO_LARGE);
 			}
 			if (Ctrl->T.active && Ctrl->T.col >= ncol) {
 				GMT_Report (API, GMT_MSG_NORMAL, "Syntax error -T option: Chosen column exceeds column range (0-%d)\n", ncol-1);
-				Return (EXIT_FAILURE);
+				Return (GMT_DIM_TOO_LARGE);
 			}
 			if (Ctrl->T.active) ncol = Ctrl->T.col + 1;
 			if (give_r_string) ncol = 2;	/* Since we only will concern ourselves with lon/lat or x/y */
 
 			/* Now we know number of columns, so allocate memory */
 
-			Q = GMT_quad_init (GMT, ncol);
-			xyzmin = GMT_memory (GMT, NULL, ncol, double);
-			xyzmax = GMT_memory (GMT, NULL, ncol, double);
+			Q = gmt_quad_init (GMT, ncol);
+			xyzmin = gmt_M_memory (GMT, NULL, ncol, double);
+			xyzmax = gmt_M_memory (GMT, NULL, ncol, double);
+			xyzminL = gmt_M_memory (GMT, NULL, ncol, double);
+			xyzmaxL = gmt_M_memory (GMT, NULL, ncol, double);
 
 			for (col = 0; col < ncol; col++) {	/* Initialize */
-				xyzmin[col] = DBL_MAX;
-				xyzmax[col] = -DBL_MAX;
+				xyzmin[col] = xyzmaxL[col] = DBL_MAX;
+				xyzmax[col] = xyzminL[col] = -DBL_MAX;
 			}
 			n = 0;
 			if (Ctrl->I.active && ncol < 2 && !Ctrl->C.active) Ctrl->I.active = false;
 			first_data_record = false;
-			if (Ctrl->C.active && (error = GMT_set_cols (GMT, GMT_OUT, 2*ncol)) != 0) Return (error);
+			if (Ctrl->C.active && (error = gmt_set_cols (GMT, GMT_OUT, 2*ncol)) != 0) Return (error);
 		}
 
 		/* Process all columns and update the corresponding minmax arrays */
 
 		if (Ctrl->E.active) {		/* See if this record should become the chosen one  */
-			if (!GMT_is_dnan (in[Ctrl->E.col])) {		/* But skip NaNs */
+			if (!gmt_M_is_dnan (in[Ctrl->E.col])) {		/* But skip NaNs */
 				value = (work_on_abs_value) ? fabs (in[Ctrl->E.col]) : in[Ctrl->E.col];
 				if (Ctrl->E.mode == -1 && value < e_min) {	/* Lower than previous low */
 					e_min = value;
 					if (GMT->common.b.active[GMT_IN])
-						GMT_memcpy (dchosen, in, ncol, double);
+						gmt_M_memcpy (dchosen, in, ncol, double);
 					else
-						strncpy (chosen, GMT->current.io.current_record, GMT_BUFSIZ);
+						strncpy (chosen, GMT->current.io.record, GMT_BUFSIZ);
 				}
 				else if (Ctrl->E.mode == +1 && value > e_max) {	/* Higher than previous high */
 					e_max = value;
 					if (GMT->common.b.active[GMT_IN])
-						GMT_memcpy (dchosen, in, ncol, double);
+						gmt_M_memcpy (dchosen, in, ncol, double);
 					else
-						strncpy (chosen, GMT->current.io.current_record, GMT_BUFSIZ);
+						strncpy (chosen, GMT->current.io.record, GMT_BUFSIZ);
 				}
 			}
 		}
 		else {	/* Update min/max values for each column */
 			for (col = 0; col < ncol; col++) {
-				if (GMT_is_dnan (in[col])) continue;	/* We always skip NaNs */
+				if (gmt_M_is_dnan (in[col])) continue;	/* We always skip NaNs */
 				if (GMT->current.io.col_type[GMT_IN][col] == GMT_IS_LON) {	/* Longitude requires more work */
 					/* We must keep separate min/max for both Dateline and Greenwich conventions */
-					GMT_quad_add (GMT, &Q[col], in[col]);
+					gmt_quad_add (GMT, &Q[col], in[col]);
 				}
 				else if ((col == 0 && Ctrl->S.xbar) || (col == 1 && Ctrl->S.ybar)) {
 					/* Add/subtract value from error bar column */
@@ -639,13 +682,13 @@ int GMT_gmtinfo (void *V_API, int mode, void *args)
 			}
 		}
 		n++;	/* Number of records processed in current block (all/table/segment; see -A) */
-		if (file[0] == 0) strncpy (file, GMT->current.io.current_filename[GMT_IN], GMT_BUFSIZ);	/* Grab name of current file while we can */
+		if (file[0] == 0) strncpy (file, GMT->current.io.filename[GMT_IN], GMT_BUFSIZ);	/* Grab name of current file while we can */
 		
 	}
-	if (GMT_End_IO (API, GMT_IN,  0) != GMT_OK) {	/* Disables further data input */
+	if (GMT_End_IO (API, GMT_IN,  0) != GMT_NOERROR) {	/* Disables further data input */
 		Return (API->error);
 	}
-	if (GMT_End_IO (API, GMT_OUT, 0) != GMT_OK) {	/* Disables further data output */
+	if (GMT_End_IO (API, GMT_OUT, 0) != GMT_NOERROR) {	/* Disables further data output */
 		Return (API->error);
 	}
 	
@@ -653,10 +696,10 @@ int GMT_gmtinfo (void *V_API, int mode, void *args)
 
 	GMT->current.io.geo.range = save_range;	/* Restore what we changed */
 	if (Ctrl->C.active) {	/* Restore previous output col types */
-		GMT_memcpy (GMT->current.io.col_type[GMT_OUT], col_type, GMT_MAX_COLUMNS, int);
+		gmt_M_memcpy (GMT->current.io.col_type[GMT_OUT], col_type, GMT_MAX_COLUMNS, int);
 	}
 	if (Ctrl->E.active && GMT->common.b.active[GMT_IN])
-		GMT_free (GMT, dchosen);
+		gmt_M_free (GMT, dchosen);
 
-	Return (GMT_OK);
+	Return (GMT_NOERROR);
 }
