@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: gmtflexure.c 15178 2015-11-06 10:45:03Z fwobbe $
+ *	$Id: gmtflexure.c 16555 2016-06-16 22:49:46Z pwessel $
  *
- *	Copyright (c) 1991-2015 by P. Wessel, W. H. F. Smith, R. Scharroo, J. Luis and F. Wobbe
+ *	Copyright (c) 1991-2016 by P. Wessel, W. H. F. Smith, R. Scharroo, J. Luis and F. Wobbe
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -27,7 +27,7 @@
 #define THIS_MODULE_NAME	"gmtflexure"
 #define THIS_MODULE_LIB		"potential"
 #define THIS_MODULE_PURPOSE	"Compute flexural deformation of 2-D loads, forces, and bending moments"
-#define THIS_MODULE_KEYS	"<DI,QDi,>DO"
+#define THIS_MODULE_KEYS	"ED(,QD(,TD(,>D}"
 
 #include "gmt_dev.h"
 
@@ -37,7 +37,7 @@
 #define	NORMAL_GRAVITY	9.806199203	/* Moritz's 1980 IGF value for gravity at 45 degrees latitude (m/s) */
 #define	POISSONS_RATIO	0.25
 
-/* 
+/*
  * gmtflexure computes the flexure produced by an arbitrary varying load
  * on a variable rigidity plate. One of four possible boundary contditions
  * can be imposed on each end of the profiles. The user may [optionally] provide 2
@@ -119,18 +119,18 @@ enum gmtflexure_load {
 	NO_LOAD = 0,
 	F_LOAD,
 	T_LOAD};
-	
+
 enum gmtflexure_bc {
 	BC_INFINITY=0,
 	BC_PERIODIC,
 	BC_CLAMPED,
 	BC_FREE};
-	
-void *New_gmtflexure_Ctrl (struct GMT_CTRL *GMT) {	/* Allocate and initialize a new control structure */
+
+GMT_LOCAL void *New_Ctrl (struct GMT_CTRL *GMT) {	/* Allocate and initialize a new control structure */
 	struct GMTFLEXURE_CTRL *C = NULL;
-	
-	C = GMT_memory (GMT, NULL, 1, struct GMTFLEXURE_CTRL);
-	
+
+	C = gmt_M_memory (GMT, NULL, 1, struct GMTFLEXURE_CTRL);
+
 	/* Initialize values whose defaults are not 0/false/NULL */
 	C->C.E = YOUNGS_MODULUS;
 	C->C.nu = POISSONS_RATIO;
@@ -138,16 +138,16 @@ void *New_gmtflexure_Ctrl (struct GMT_CTRL *GMT) {	/* Allocate and initialize a
 	return (C);
 }
 
-void Free_gmtflexure_Ctrl (struct GMT_CTRL *GMT, struct GMTFLEXURE_CTRL *C) {	/* Deallocate control structure */
+GMT_LOCAL void Free_Ctrl (struct GMT_CTRL *GMT, struct GMTFLEXURE_CTRL *C) {	/* Deallocate control structure */
 	if (!C) return;
-	if (C->Out.file) free (C->Out.file);
-	if (C->E.file) free (C->E.file);	
-	if (C->Q.file) free (C->Q.file);	
-	if (C->T.file) free (C->T.file);	
-	GMT_free (GMT, C);	
+	gmt_M_str_free (C->Out.file);
+	gmt_M_str_free (C->E.file);
+	gmt_M_str_free (C->Q.file);
+	gmt_M_str_free (C->T.file);
+	gmt_M_free (GMT, C);
 }
 
-int GMT_gmtflexure_parse (struct GMT_CTRL *GMT, struct GMTFLEXURE_CTRL *Ctrl, struct GMT_OPTION *options) {
+GMT_LOCAL int parse (struct GMT_CTRL *GMT, struct GMTFLEXURE_CTRL *Ctrl, struct GMT_OPTION *options) {
 
 	unsigned int side, k, n_errors = 0, n_files = 0;
 	int n;
@@ -159,7 +159,7 @@ int GMT_gmtflexure_parse (struct GMT_CTRL *GMT, struct GMTFLEXURE_CTRL *Ctrl, st
 		switch (opt->option) {
 
 			case '>':	/* Got named output file */
-				if (n_files++ == 0 && GMT_check_filearg (GMT, '>', opt->arg, GMT_OUT, GMT_IS_DATASET))
+				if (n_files++ == 0 && gmt_check_filearg (GMT, '>', opt->arg, GMT_OUT, GMT_IS_DATASET))
 					Ctrl->Out.file = strdup (opt->arg);
 				else
 					n_errors++;
@@ -184,7 +184,7 @@ int GMT_gmtflexure_parse (struct GMT_CTRL *GMT, struct GMTFLEXURE_CTRL *Ctrl, st
 					Ctrl->A.deflection[side] = (opt->arg[k+2]) ? atof (&opt->arg[k+2]) : 0.0;
 				else if (Ctrl->A.bc[side] == BC_FREE) {	/* Get bending moment and shear force */
 					if (opt->arg[k+2])
-						n = sscanf (&opt->arg[k+2], "%lf/%lf", &Ctrl->A.moment[side], &Ctrl->A.force[side]);
+						sscanf (&opt->arg[k+2], "%lf/%lf", &Ctrl->A.moment[side], &Ctrl->A.force[side]);
 				}
 				if (both) {	/* Copy values over from left to right */
 					Ctrl->A.bc[RIGHT] = Ctrl->A.bc[LEFT];
@@ -217,10 +217,10 @@ int GMT_gmtflexure_parse (struct GMT_CTRL *GMT, struct GMTFLEXURE_CTRL *Ctrl, st
 				break;
 			case 'E':	/* Set elastic thickness or rigidities */
 				Ctrl->E.active = true;
-				if (!GMT_access (GMT, opt->arg, F_OK))	/* file exists */
+				if (!gmt_access (GMT, opt->arg, F_OK))	/* file exists */
 					Ctrl->E.file = strdup (opt->arg);
 				else {	/* Got a value */
-					GMT_Get_Value (API, opt->arg, &Ctrl->E.te);	/* Returns Te in m if k was appended */
+					GMT_Get_Values (API, opt->arg, &Ctrl->E.te, 1);	/* Returns Te in m if k was appended */
 					if (Ctrl->E.te > 1e10) { /* Given flexural rigidity, compute Te in meters */
 						Ctrl->E.te = pow ((12.0 * (1.0 - Ctrl->C.nu * Ctrl->C.nu)) * Ctrl->E.te / Ctrl->C.E, 1.0/3.0);
 					}
@@ -274,33 +274,33 @@ int GMT_gmtflexure_parse (struct GMT_CTRL *GMT, struct GMTFLEXURE_CTRL *Ctrl, st
 				break;
 			case 'W':	/* Water depth */
 				Ctrl->W.active = true;
-				GMT_Get_Value (API, opt->arg, &Ctrl->W.water_depth);	/* This yields water depth in meters if k was added */
+				GMT_Get_Values (API, opt->arg, &Ctrl->W.water_depth, 1);	/* This yields water depth in meters if k was added */
 				break;
 			case 'Z':	/* Moho depth */
 				Ctrl->Z.active = true;
-				GMT_Get_Value (API, opt->arg, &Ctrl->Z.zm);	/* This yields Moho depth in meters if k was added */
+				GMT_Get_Values (API, opt->arg, &Ctrl->Z.zm, 1);	/* This yields Moho depth in meters if k was added */
 				break;
 			default:
-				n_errors += GMT_default_error (GMT, opt->option);
+				n_errors += gmt_default_error (GMT, opt->option);
 				break;
 		}
 	}
-	n_errors += GMT_check_condition (GMT, !Ctrl->D.active, "Syntax error -D option: Must set density values\n");
-	n_errors += GMT_check_condition (GMT, !Ctrl->E.active, "Syntax error -E option: Must specify plate thickness or rigidity\n");
-	n_errors += GMT_check_condition (GMT, !Ctrl->Q.active, "Syntax error -Q option: Must specify load option\n");
-	n_errors += GMT_check_condition (GMT, !Ctrl->E.file && Ctrl->Q.mode == NO_LOAD && !Ctrl->Q.set_x, "Syntax error -Q option: Must specify equidistant min/max/inc setting\n");
-	n_errors += GMT_check_condition (GMT, n_files > 1, "Syntax error: Only one output destination can be specified\n");
+	n_errors += gmt_M_check_condition (GMT, !Ctrl->D.active, "Syntax error -D option: Must set density values\n");
+	n_errors += gmt_M_check_condition (GMT, !Ctrl->E.active, "Syntax error -E option: Must specify plate thickness or rigidity\n");
+	n_errors += gmt_M_check_condition (GMT, !Ctrl->Q.active, "Syntax error -Q option: Must specify load option\n");
+	n_errors += gmt_M_check_condition (GMT, !Ctrl->E.file && Ctrl->Q.mode == NO_LOAD && !Ctrl->Q.set_x, "Syntax error -Q option: Must specify equidistant min/max/inc setting\n");
+	n_errors += gmt_M_check_condition (GMT, n_files > 1, "Syntax error: Only one output destination can be specified\n");
 
-	return (n_errors ? GMT_PARSE_ERROR : GMT_OK);
+	return (n_errors ? GMT_PARSE_ERROR : GMT_NOERROR);
 }
 
-int GMT_gmtflexure_usage (struct GMTAPI_CTRL *API, int level) {
-	GMT_show_name_and_purpose (API, THIS_MODULE_LIB, THIS_MODULE_NAME, THIS_MODULE_PURPOSE);
+GMT_LOCAL int usage (struct GMTAPI_CTRL *API, int level) {
+	gmt_show_name_and_purpose (API, THIS_MODULE_LIB, THIS_MODULE_NAME, THIS_MODULE_PURPOSE);
 	if (level == GMT_MODULE_PURPOSE) return (GMT_NOERROR);
 	GMT_Message (API, GMT_TIME_NONE, "usage: gmtflexure -D<rhom>/<rhol>[/<rhoi>]/<rhow> -E<te> -Q<loadinfo> [-A[l|r]<bc>[/<args>]]\n");
-	GMT_Message (API, GMT_TIME_NONE,"\t[-C[p|y]<value] [-F<force>] [-S] [-T<wpre>] [%s] [-W<w0>] [-Z<zm>]\n\t[%s]\n\n", GMT_V_OPT, GMT_h_OPT, GMT_i_OPT, GMT_o_OPT);
+	GMT_Message (API, GMT_TIME_NONE,"\t[-C[p|y]<value] [-F<force>] [-S] [-T<wpre>] [%s] [-W<w0>] [-Z<zm>]\n\t[%s] [%s] [%s]\n\n", GMT_V_OPT, GMT_h_OPT, GMT_i_OPT, GMT_o_OPT);
 
-	if (level == GMT_SYNOPSIS) return (EXIT_FAILURE);
+	if (level == GMT_SYNOPSIS) return (GMT_MODULE_SYNOPSIS);
 
 	GMT_Message (API, GMT_TIME_NONE, "\t-D Sets density values for mantle, load(crust), optional moat infill [same as load], and water in kg/m^3.\n");
 	GMT_Message (API, GMT_TIME_NONE, "\t-E Sets elastic plate thickness in m; append k for km.  If Te > 1e10 it will be interpreted\n");
@@ -333,16 +333,16 @@ int GMT_gmtflexure_usage (struct GMTAPI_CTRL *API, int level) {
 	GMT_Message (API, GMT_TIME_NONE, "\t   Subaerial topography will be scaled by -D to account for density differences.\n");
 	GMT_Message (API, GMT_TIME_NONE, "\t-Z Specify reference depth to flexed surface in m; append k for km.  Must be positive [0].\n");
 	GMT_Option (API, "h,i,o,.");
-	return (EXIT_FAILURE);
+	return (GMT_MODULE_USAGE);
 }
 
-double te_2_d (struct GMTFLEXURE_CTRL *Ctrl, double te)
-{	/* Convert elastic thickness to flexural rigidity */
+GMT_LOCAL double te_2_d (struct GMTFLEXURE_CTRL *Ctrl, double te) {
+	/* Convert elastic thickness to flexural rigidity */
 	return (Ctrl->C.E * pow (te, 3.0) / (12.0 * (1.0 - Ctrl->C.nu * Ctrl->C.nu)));
 }
 
-int get_curvature (double flexure[], int n, double dist_increment, double curvature[])
-{	/* Calculate central second differences of flexure = curvature */
+GMT_LOCAL int get_curvature (double flexure[], int n, double dist_increment, double curvature[]) {
+	/* Calculate central second differences of flexure = curvature */
 	int i;
 
 	dist_increment = -1.0/(dist_increment*dist_increment);	/* - since z points down */
@@ -354,8 +354,8 @@ int get_curvature (double flexure[], int n, double dist_increment, double curvat
 	return (1);
 }
 
-int lu_solver (struct GMT_CTRL *GMT, double *a, int n, double *x, double *b)
-{ /* A 5-diagonal matrix problem A*w = p solved using a LU-transformation */
+GMT_LOCAL int lu_solver (struct GMT_CTRL *GMT, double *a, int n, double *x, double *b) {
+	/* A 5-diagonal matrix problem A*w = p solved using a LU-transformation */
 
 	int i, off3, off5;
 	double new_max, old_max, *l = NULL, *u = NULL, *z = NULL;
@@ -365,9 +365,9 @@ int lu_solver (struct GMT_CTRL *GMT, double *a, int n, double *x, double *b)
 		return (1);
 	}
 
-	l = GMT_memory (GMT, NULL, n * 5, double);
-	u = GMT_memory (GMT, NULL, n * 5, double);
-	z = GMT_memory (GMT, NULL, n, double);
+	l = gmt_M_memory (GMT, NULL, n * 5, double);
+	u = gmt_M_memory (GMT, NULL, n * 5, double);
+	z = gmt_M_memory (GMT, NULL, n, double);
 
 	/* Find largest element in coefficient matrix */
 
@@ -444,9 +444,9 @@ int lu_solver (struct GMT_CTRL *GMT, double *a, int n, double *x, double *b)
 	for (i = n-3, off3 = i*3; i >= 0; i--, off3 -= 3)
 		x[i] = (z[i] - x[i+1] * u[off3+1] - x[i+2] * u[off3+2]) / u[off3];
 
-	GMT_free (GMT, u);
-	GMT_free (GMT, l);
-	GMT_free (GMT, z);
+	gmt_M_free (GMT, u);
+	gmt_M_free (GMT, l);
+	gmt_M_free (GMT, z);
 
 	return (0);
 }
@@ -482,22 +482,21 @@ int lu_solver (struct GMT_CTRL *GMT, double *a, int n, double *x, double *b)
  * Revised:	5-AUG-1989	Now k is a function of x
  *
  */
- 
-int flx1d (struct GMT_CTRL *GMT, double *w, double *d, double *p, int n, double dx, double *k, int k_flag, double stress, int bc_left, int bc_right)
-{
+
+GMT_LOCAL int flx1d (struct GMT_CTRL *GMT, double *w, double *d, double *p, int n, double dx, double *k, int k_flag, double stress, int bc_left, int bc_right) {
 	int i, row, off, ind, error;
 	double dx_4, c_1 = 0.0, c_2 = 0.0, stress2, restore, *work = NULL;
-	
+
 	/* Must allocate memory */
-	
-	work = GMT_memory (GMT, NULL, 5 * n, double);
-	
+
+	work = gmt_M_memory (GMT, NULL, 5 * n, double);
+
 	dx_4 = pow (dx, 4.0);
 	stress *= (dx * dx);
 	stress2 = 2.0 * stress;
-	
+
 	for (i = 0; i < n; i++) p[i] *= dx_4;
-		
+
 	/* Matrix row 0: */
 
 	work[0] = 0.0;
@@ -526,9 +525,9 @@ int flx1d (struct GMT_CTRL *GMT, double *w, double *d, double *p, int n, double
 		c_2 =  - 2.0 * pow (dx, 3.0) * w[1];
 		p[0] -= c_1*(2.0*d[1] - 4.0*d[0]) + c_2;
 	}
-	
+
 	/* Matrix row 1: */
-	
+
 	ind = (k_flag) ? 1 : 0;
 	restore = k[ind] * dx_4;
 	work[5] = 0.0;
@@ -559,9 +558,9 @@ int flx1d (struct GMT_CTRL *GMT, double *w, double *d, double *p, int n, double
 		p[1] -= c_1 * (d[1] + 0.5 * d[2] - 0.5 * d[0]);
 		w[0] = w[1] = 0.0;
 	}
-	
+
 	/* Matrix row 2 -> n - 3: */
-	
+
 	for (row = 2; row < (n-2); row++) {
 		ind = (k_flag) ? row : 0;
 		restore = k[ind] * dx_4;
@@ -574,7 +573,7 @@ int flx1d (struct GMT_CTRL *GMT, double *w, double *d, double *p, int n, double
 	}
 
 	/* Matrix row n - 2: */
-	
+
 	row = n - 2;
 	off = row * 5;
 	ind = (k_flag) ? row : 0;
@@ -608,7 +607,7 @@ int flx1d (struct GMT_CTRL *GMT, double *w, double *d, double *p, int n, double
 	}
 
 	/* Matrix row nx - 1: */
-	
+
 	off += 5;
 	row++;
 	ind = (k_flag) ? row : 0;
@@ -638,20 +637,20 @@ int flx1d (struct GMT_CTRL *GMT, double *w, double *d, double *p, int n, double
 		p[row] -= c_1*(2.0*d[row-1] - 4.0*d[row]) + c_2;
 		w[row-1] = w[row] = 0.0;
 	}
-		
+
 
 	/* Solve for w */
-	
+
 	off = 5 * n;
 	error = lu_solver (GMT, work, n, w, p);
-	GMT_free (GMT, work);
+	gmt_M_free (GMT, work);
 	if (error == 1) {
 		fprintf (stderr, "flx1d: error=1 returned from lu_solver!\n");
 		return (error);
 	}
 	return (0);
 }
-	
+
 /* flx1dk will compute 1-D plate flexure for a variable rigidity case with
  * a restoring force that depends on the sign of the deflection.  After each
  * iteration, we recompute k(x) so that k(x) = G * (rho_m - rho_infill (or rho_load)) where
@@ -691,57 +690,58 @@ int flx1d (struct GMT_CTRL *GMT, double *w, double *d, double *p, int n, double
  * Revised:	5-AUG-1989	Now k is a function of x
  *
  */
- 
+
 #define LIMIT	0.01
 
-int flx1dk (struct GMT_CTRL *GMT, double w[], double d[], double p[], int n, double dx, double rho_m, double rho_l, double rho_i, double rho_w, double stress, int bc_left, int bc_right)
-{
+GMT_LOCAL int flx1dk (struct GMT_CTRL *GMT, double w[], double d[], double p[], int n, double dx, double rho_m, double rho_l, double rho_i, double rho_w, double stress, int bc_left, int bc_right) {
 	int i, error;
-	double restore_a, restore_b1, restore_b2, diff, dw, w0, w1, wn1, wn, max_dw;
+	double restore_a, restore_b1, restore_b2, diff = 2 * LIMIT, dw, w0, w1, wn1, wn, max_dw;
 	double *w_old = NULL, *k = NULL, *load = NULL;
-	
+
 	/* Allocate memory for load and restore force */
-	
-	k = GMT_memory (GMT, NULL, n, double);
-	w_old = GMT_memory (GMT, NULL, n, double);
-	load = GMT_memory (GMT, NULL, n, double);
-	
+
+	k = gmt_M_memory (GMT, NULL, n, double);
+	load = gmt_M_memory (GMT, NULL, n, double);
+
 	/* Initialize restoring force */
-	
+
 	restore_a  = NORMAL_GRAVITY * (rho_m - rho_w);
 	restore_b1 = NORMAL_GRAVITY * (rho_m - rho_i);
 	restore_b2 = NORMAL_GRAVITY * (rho_m - rho_l);
-	
+
 	for (i = 0; i < n; i++)	k[i] = (p[i] > 0.0) ? restore_b2 : restore_b1;
-	
+
 	/* Save possible boundary values */
-	
+
 	w0 = w[0];	w1 = w[1];	wn1 = w[n-2];	wn = w[n-1];
-	
-	memcpy ((void *)load, (void *)p, n * sizeof (double));
-	
-	error = flx1d (GMT, w, d, load, n, dx, k, 1, stress, bc_left, bc_right);
-	
-	if (error) return (error);
-	
-	do {	/* Iterate as long as rms difference is > LIMIT */
-	
+
+	gmt_M_memcpy (load, p, n, double);
+
+	if ((error = flx1d (GMT, w, d, load, n, dx, k, 1, stress, bc_left, bc_right))) {
+		gmt_M_free (GMT, load);		gmt_M_free (GMT, k);
+		return (error);
+	}
+
+	w_old = gmt_M_memory (GMT, NULL, n, double);
+
+	while (!error && diff > LIMIT) {	/* Iterate as long as rms difference is > LIMIT. diff starts at 2*LIMIT. */
+
 		/* Set variable restoring force */
-	
+
 		for (i = 0; i < n; i++)	k[i] = (w[i] > 0.0) ? ((p[i] > 0.0) ? restore_b2 : restore_b1) : restore_a;
-		
+
 		/* Save previous solution */
-		
-		memcpy ((void *)w_old, (void *)w, n * sizeof (double));
-		
+
+		gmt_M_memcpy (w_old, w, n, double);
+
 		/* Initialize arrays again */
-		
-		memcpy ((void *)load, (void *)p, n * sizeof (double));
-		memset ((void *)w, 0, n * sizeof (double));
+
+		gmt_M_memcpy (load, p, n, double);
+		gmt_M_memset (w, n, double);
 		w[0] = w0;	w[1] = w1;	w[n-2] = wn1;	w[n-1] = wn;	/* Reset BC values */
-		
+
 		error = flx1d (GMT, w, d, load, n, dx, k, 1, stress, bc_left, bc_right);
-		
+
 		for (i = 0, diff = max_dw = 0.0; i < n; i++) {
 			dw = fabs (w[i] - w_old[i]);
 			if (dw > max_dw) max_dw = dw;
@@ -750,14 +750,13 @@ int flx1dk (struct GMT_CTRL *GMT, double w[], double d[], double p[], int n, dou
 		/* diff = sqrt (diff / n); RMS */
 		diff = max_dw;
 	}
-	while (!error && diff > LIMIT);
-	
-	GMT_free (GMT, k);
-	GMT_free (GMT, load);
-	GMT_free (GMT, w_old);
-	
+
+	gmt_M_free (GMT, k);
+	gmt_M_free (GMT, load);
+	gmt_M_free (GMT, w_old);
+
 	return (error);
-}	
+}
 
 /* flx1dw0 will compute 1-D plate flexure for a variable rigidity case with
  * a pre-existing deformation.  The equation is
@@ -794,33 +793,31 @@ int flx1dk (struct GMT_CTRL *GMT, double w[], double d[], double p[], int n, dou
  * 		29-OCT-1990	Include pre-existing deformation
  *
  */
- 
-int flx1dw0 (struct GMT_CTRL *GMT, double *w, double *w0, double *d, double *p, int n, double dx, double *k, int k_flag, double stress, int bc_left, int bc_right)
-{
+
+GMT_LOCAL int flx1dw0 (struct GMT_CTRL *GMT, double *w, double *w0, double *d, double *p, int n, double dx, double *k, int k_flag, double stress, int bc_left, int bc_right) {
 	int i, row, off, ind, error;
 	double dx_4, c_1 = 0.0, c_2, stress2, restore, *work = NULL, *squeeze = NULL;
-	
+
 	/* Must allocate memory */
-	
-	work = GMT_memory (GMT, NULL, 5 * n, double);
-	squeeze = GMT_memory (GMT, NULL, n, double);
-	
+
+	work = gmt_M_memory (GMT, NULL, 5 * n, double);
+	squeeze = gmt_M_memory (GMT, NULL, n, double);
+
 	dx_4 = pow (dx, 4.0);
 	stress *= (dx * dx);
 	stress2 = 2.0 * stress;
-	
+
 	for (i = 0; i < n; i++) p[i] *= dx_4;	/* Scale load */
-	
+
 	/* Add in buckling force on preexisting topo */
-	
+
 	for (i = 1; i < n-1; i++) squeeze[i] = -stress * (w0[i+1] - 2.0 * w[i] - w[i-1]);
 	squeeze[0] = squeeze[1];	squeeze[n-1] = squeeze[n-2];
 	for (i = 0; i < n; i++) p[i] -= squeeze[i];
-		
+
 	/* Matrix row 0: */
 
-	work[0] = 0.0;
-	work[1] = 0.0;
+	work[0] = work[1] = 0.0;
 	restore = k[0] * dx_4;
 	if (bc_left == 0) {		/* 'infinity' conditions */
 		work[2] = 10.0 * d[0] - 4.0 * d[1] + restore - stress2;
@@ -845,9 +842,9 @@ int flx1dw0 (struct GMT_CTRL *GMT, double *w, double *w0, double *d, double *p,
 		c_2 =  - 2.0 * pow (dx, 3.0) * w[1];
 		p[0] -= c_1*(2.0*d[1] - 4.0*d[0]) + c_2;
 	}
-	
+
 	/* Matrix row 1: */
-	
+
 	ind = (k_flag) ? 1 : 0;
 	restore = k[ind] * dx_4;
 	work[5] = 0.0;
@@ -878,9 +875,9 @@ int flx1dw0 (struct GMT_CTRL *GMT, double *w, double *w0, double *d, double *p,
 		p[1] -= c_1 * (d[1] + 0.5 * d[2] - 0.5 * d[0]);
 		w[0] = w[1] = 0.0;
 	}
-	
+
 	/* Matrix row 2 -> n - 3: */
-	
+
 	for (row = 2; row < (n-2); row++) {
 		ind = (k_flag) ? row : 0;
 		restore = k[ind] * dx_4;
@@ -893,7 +890,7 @@ int flx1dw0 (struct GMT_CTRL *GMT, double *w, double *w0, double *d, double *p,
 	}
 
 	/* Matrix row n - 2: */
-	
+
 	row = n - 2;
 	off = row * 5;
 	ind = (k_flag) ? row : 0;
@@ -927,7 +924,7 @@ int flx1dw0 (struct GMT_CTRL *GMT, double *w, double *w0, double *d, double *p,
 	}
 
 	/* Matrix row nx - 1: */
-	
+
 	off += 5;
 	row++;
 	ind = (k_flag) ? row : 0;
@@ -957,21 +954,21 @@ int flx1dw0 (struct GMT_CTRL *GMT, double *w, double *w0, double *d, double *p,
 		p[row] -= c_1*(2.0*d[row-1] - 4.0*d[row]) + c_2;
 		w[row-1] = w[row] = 0.0;
 	}
-		
+
 
 	/* Solve for w */
-	
+
 	off = 5 * n;
 	error = lu_solver (GMT, work, n, w, p);
-	GMT_free (GMT, work);
-	GMT_free (GMT, squeeze);
+	gmt_M_free (GMT, work);
+	gmt_M_free (GMT, squeeze);
 	if (error == 1) {
 		fprintf (stderr, "flx1d: error=1 returned from lu_solver!\n");
 		return (error);
 	}
 	/* for (i = 0; i < n; i++) w[i] += w0[i]; */
 	return (0);
-}	
+}
 
 /* flxr will compute a cross-section of 3-D plate flexure for a variable rigidity
  * plate with an axially symmetric load applied. In this case we have no phi-
@@ -998,17 +995,17 @@ int flx1dw0 (struct GMT_CTRL *GMT, double *w, double *w0, double *d, double *p,
  * ONLY APPLIES IF RHO_L == RHO_I
  */
 
-int flxr (struct GMT_CTRL *GMT, double *w, double *d, double *p, int n, double dx, double restore)
-{
+#if 0
+GMT_LOCAL int flxr (struct GMT_CTRL *GMT, double *w, double *d, double *p, int n, double dx, double restore) {
 	int i, row, off, error;
 	double dx_4, r2m1, r2p1, rp1, rm1, r4 = 0.0, r, *work = NULL;
-	
-	work = GMT_memory (GMT, NULL, n * 5, double);
+
+	work = gmt_M_memory (GMT, NULL, n * 5, double);
 	dx_4 = pow (dx, 4.0);
 	restore *= dx_4;
-	
+
 	for (i = 0; i < n; i++) p[i] *= dx_4;
-		
+
 	/* Matrix row 0: */
 
 	work[0] = 0.0;
@@ -1016,17 +1013,17 @@ int flxr (struct GMT_CTRL *GMT, double *w, double *d, double *p, int n, double d
 	work[2] = 16.0 * d[0] + 2.0 * d[1] + restore;
 	work[3] = -8.0 * d[1] - 16.0 * d[0];
 	work[4] = 6.0 * d[1];
-	
+
 	/* Matrix row 1: */
-	
+
 	work[5] = 0.0;
 	work[6] = -2.0 * d[0] - d[1];
 	work[7] = 4.0 * d[1] + 1.125 * d[2] + 2.0 * d[0] + restore;
 	work[8] = -3.0 * (d[2] + d[1]);
 	work[9] = 1.875 * d[2];
-	
+
 	/* Matrix row 2 -> n - 3: */
-	
+
 	for (row = 2; row < (n-2); row++) {
 		r = row;
 		off = row * 5;
@@ -1043,7 +1040,7 @@ int flxr (struct GMT_CTRL *GMT, double *w, double *d, double *p, int n, double d
 	}
 
 	/* Matrix row n - 2: */
-	
+
 	row = n - 2;
 	off = row * 5;
 	r = row;
@@ -1058,35 +1055,34 @@ int flxr (struct GMT_CTRL *GMT, double *w, double *d, double *p, int n, double d
 	work[off+2] += (2.0*r + 3.0) * r2p1 * d[row+1] / (r4 * rp1);
 	work[off+3] = -r2p1 * (d[row+1] + d[row]) / r;
 	/* Matrix row nx - 1: */
-	
+
 	off += 5;
 	row++;
 	work[off] = work[off+1] = work[off+3] = work[off+4] = 0.0;
 	work[off+2] = 1.0;
 	p[row] = 0.0;
-		
+
 
 	/* Solve for w */
 	off = 5*n;
 	error = lu_solver (GMT, work, n, w, p);
-	GMT_free (GMT, work);
+	gmt_M_free (GMT, work);
 	if (error == 1) {
 		fprintf(stderr, "flxr: error=1 returned from lu_solver!\n");
 		return (error);
 	}
 	return (0);
-}	
+}
 
-int flxr2 (struct GMT_CTRL *GMT, double *w, double *d, double *p, int n, double dx, double *restore)
-{
+GMT_LOCAL int flxr2 (struct GMT_CTRL *GMT, double *w, double *d, double *p, int n, double dx, double *restore) {
 	int i, row, off, error;
 	double dx_4, r2m1, r2p1, rp1, rm1, r4 = 0.0, r, *work = NULL;
-	
-	work = GMT_memory (GMT, NULL, n * 5, double);
+
+	work = gmt_M_memory (GMT, NULL, n * 5, double);
 	dx_4 = pow (dx, 4.0);
-	
+
 	for (i = 0; i < n; i++) p[i] *= dx_4;
-		
+
 	/* Matrix row 0: */
 
 	work[0] = 0.0;
@@ -1094,17 +1090,17 @@ int flxr2 (struct GMT_CTRL *GMT, double *w, double *d, double *p, int n, double
 	work[2] = 16.0 * d[0] + 2.0 * d[1] + restore[0] * dx_4;
 	work[3] = -8.0 * d[1] - 16.0 * d[0];
 	work[4] = 6.0 * d[1];
-	
+
 	/* Matrix row 1: */
-	
+
 	work[5] = 0.0;
 	work[6] = -2.0 * d[0] - d[1];
 	work[7] = 4.0 * d[1] + 1.125 * d[2] + 2.0 * d[0] + restore[1] * dx_4;
 	work[8] = -3.0 * (d[2] + d[1]);
 	work[9] = 1.875 * d[2];
-	
+
 	/* Matrix row 2 -> n - 3: */
-	
+
 	for (row = 2; row < (n-2); row++) {
 		r = row;
 		off = row * 5;
@@ -1121,7 +1117,7 @@ int flxr2 (struct GMT_CTRL *GMT, double *w, double *d, double *p, int n, double
 	}
 
 	/* Matrix row n - 2: */
-	
+
 	row = n - 2;
 	off = row * 5;
 	r = row;
@@ -1136,58 +1132,55 @@ int flxr2 (struct GMT_CTRL *GMT, double *w, double *d, double *p, int n, double
 	work[off+2] += (2.0*r + 3.0) * r2p1 * d[row+1] / (r4 * rp1);
 	work[off+3] = -r2p1 * (d[row+1] + d[row]) / r;
 	/* Matrix row nx - 1: */
-	
+
 	off += 5;
 	row++;
 	work[off] = work[off+1] = work[off+3] = work[off+4] = 0.0;
 	work[off+2] = 1.0;
 	p[row] = 0.0;
-		
+
 
 	/* Solve for w */
 	off = 5*n;
 	error = lu_solver (GMT, work, n, w, p);
-	GMT_free (GMT, work);
+	gmt_M_free (GMT, work);
 	if (error == 1) {
 		fprintf(stderr, "flxr2: error=1 returned from lu_solver!\n");
 		return (error);
 	}
 	return (0);
-}	
+}
 
-int flxrk (struct GMT_CTRL *GMT, double w[], double  d[], double  p[], int n, double dx, double rho_m, double rho_l, double rho_i, double rho_w, double rho_i2, double rx)
-{
+GMT_LOCAL int flxrk (struct GMT_CTRL *GMT, double w[], double  d[], double  p[], int n, double dx, double rho_m, double rho_l, double rho_i, double rho_w, double rho_i2, double rx) {
 	int i, error, i_rx;
-	double restore_a, restore_b1, restore_b2, restore_b3, diff, dw, max_dw;
+	double restore_a, restore_b1, restore_b2, restore_b3, diff = 2 * LIMIT, dw, max_dw;
 	double *w_old = NULL, *k = NULL, *load = NULL;
-	
+
 	/* Allocate memory for load and restore force */
-	
-	k = GMT_memory (GMT, NULL, n, double);
-	w_old = GMT_memory (GMT, NULL, n, double);
-	load = GMT_memory (GMT, NULL, n, double);
-	
+
+	k = gmt_M_memory (GMT, NULL, n, double);
+	w_old = gmt_M_memory (GMT, NULL, n, double);
+	load = gmt_M_memory (GMT, NULL, n, double);
+
 	/* Initialize restoring force */
-	
+
 	restore_a  = NORMAL_GRAVITY * (rho_m - rho_w);
 	restore_b1 = NORMAL_GRAVITY * (rho_m - rho_i);
 	restore_b2 = NORMAL_GRAVITY * (rho_m - rho_l);
 	restore_b3 = NORMAL_GRAVITY * (rho_m - rho_i2);
-	
+
 	i_rx = (int) rint (rx / dx);
-	
+
 	for (i = 0; i < n; i++)	k[i] = (p[i] > 0.0) ? ((i <= i_rx) ? restore_b3 : restore_b2) : restore_b1;
-		
+
 	memcpy ((void *)load, (void *)p, n * sizeof (double));
-	
+
 	error = flxr2 (GMT, w, d, p, n, dx, k);
-	
-	if (error) return (error);
-	
-	do {	/* Iterate as long as rms difference is > LIMIT */
-	
+
+	while (!error && diff > LIMIT) {	/* Iterate as long as rms difference is > LIMIT. diff starts at 2*LIMIT. */
+
 		/* Set variable restoring force */
-	
+
 		for (i = 0; i < n; i++)	{
 			if (w[i] > 0.0) {	/* Positive depression is down */
 				if (i <= i_rx)		/* We are under the heavier core load */
@@ -1200,18 +1193,18 @@ int flxrk (struct GMT_CTRL *GMT, double w[], double  d[], double  p[], int n, do
 			else				/* At the bulges */
 				k[i] = restore_a;
 		}
-		
+
 		/* Save previous solution */
-		
+
 		memcpy ((void *)w_old, (void *)w, n * sizeof (double));
-		
+
 		/* Initialize arrays again */
-		
+
 		memcpy ((void *)p, (void *)load, n * sizeof (double));
 		memset ((void *)w, 0, n * sizeof (double));
-		
+
 		error = flxr2 (GMT, w, d, p, n, dx, k);
-		
+
 		for (i = 0, diff = max_dw = 0.0; i < n; i++) {
 			dw = fabs (w[i] - w_old[i]);
 			if (dw > max_dw) max_dw = dw;
@@ -1220,17 +1213,17 @@ int flxrk (struct GMT_CTRL *GMT, double w[], double  d[], double  p[], int n, do
 		/* diff = sqrt (diff / n); RMS */
 		diff = max_dw;
 	}
-	while (!error && diff > LIMIT);
-	
-	GMT_free (GMT, k);
-	GMT_free (GMT, load);
-	GMT_free (GMT, w_old);
-	
-	return (error);
-}	
 
-#define bailout(code) {GMT_Free_Options (mode); return (code);}
-#define Return(code) {Free_gmtflexure_Ctrl (GMT, Ctrl); GMT_end_module (GMT, GMT_cpy); bailout (code);}
+	gmt_M_free (GMT, k);
+	gmt_M_free (GMT, load);
+	gmt_M_free (GMT, w_old);
+
+	return (error);
+}
+#endif
+
+#define bailout(code) {gmt_M_free_options (mode); return (code);}
+#define Return(code) {Free_Ctrl (GMT, Ctrl); gmt_end_module (GMT, GMT_cpy); bailout (code);}
 
 int GMT_gmtflexure (void *V_API, int mode, void *args) {
 	uint64_t tbl, seg, row, n_columns;
@@ -1245,30 +1238,30 @@ int GMT_gmtflexure (void *V_API, int mode, void *args) {
 	struct GMT_DATASEGMENT *S = NULL;
 	struct GMT_CTRL *GMT = NULL, *GMT_cpy = NULL;
 	struct GMT_OPTION *options = NULL;
-	struct GMTAPI_CTRL *API = GMT_get_API_ptr (V_API);	/* Cast from void to GMTAPI_CTRL pointer */
+	struct GMTAPI_CTRL *API = gmt_get_api_ptr (V_API);	/* Cast from void to GMTAPI_CTRL pointer */
 
 	/*----------------------- Standard module initialization and parsing ----------------------*/
 
 	if (API == NULL) return (GMT_NOT_A_SESSION);
-	if (mode == GMT_MODULE_PURPOSE) return (GMT_gmtflexure_usage (API, GMT_MODULE_PURPOSE));	/* Return the purpose of program */
+	if (mode == GMT_MODULE_PURPOSE) return (usage (API, GMT_MODULE_PURPOSE));	/* Return the purpose of program */
 	options = GMT_Create_Options (API, mode, args);
 	if (API->error) return (API->error);	/* Set or get option list */
 
 	if (!options || options->option == GMT_OPT_USAGE)
-		bailout (GMT_gmtflexure_usage (API, GMT_USAGE));	/* Return the usage message */
+		bailout (usage (API, GMT_USAGE));	/* Return the usage message */
 	if (options->option == GMT_OPT_SYNOPSIS)
-		bailout (GMT_gmtflexure_usage (API, GMT_SYNOPSIS));	/* Return the synopsis */
+		bailout (usage (API, GMT_SYNOPSIS));	/* Return the synopsis */
 
 	/* Parse the command-line arguments */
 
-	GMT = GMT_begin_module (API, THIS_MODULE_LIB, THIS_MODULE_NAME, &GMT_cpy); /* Save current state */
+	GMT = gmt_begin_module (API, THIS_MODULE_LIB, THIS_MODULE_NAME, &GMT_cpy); /* Save current state */
 	if (GMT_Parse_Common (API, GMT_PROG_OPTIONS, options)) Return (API->error);
-	Ctrl = New_gmtflexure_Ctrl (GMT);	/* Allocate and initialize a new control structure */
-	if ((error = GMT_gmtflexure_parse (GMT, Ctrl, options)) != 0) Return (error);
+	Ctrl = New_Ctrl (GMT);	/* Allocate and initialize a new control structure */
+	if ((error = parse (GMT, Ctrl, options)) != 0) Return (error);
 
 	/*---------------------------- This is the gmtflexure main code ----------------------------*/
 
-	
+
 	if (Ctrl->Q.mode == NO_LOAD) {	/* No load file given */
 		GMT_Report (API, GMT_MSG_VERBOSE, "No load file given; Flexure only determined by boundary conditions\n");
 	}
@@ -1278,6 +1271,10 @@ int GMT_gmtflexure (void *V_API, int mode, void *args) {
 		if ((Q = GMT_Read_Data (API, GMT_IS_DATASET, GMT_IS_FILE, GMT_IS_LINE, GMT_READ_NORMAL, NULL, Ctrl->Q.file, NULL)) == NULL) {
 			Return (API->error);
 		}
+		if (Q->n_columns < 2) {
+			GMT_Report (API, GMT_MSG_NORMAL, "Input file %s has %d column(s) but at least 2 are needed\n", Ctrl->Q.file, (int)Q->n_columns);
+			Return (GMT_DIM_TOO_SMALL);
+		}
 		/* If topography given then scale to load */
 		if (Ctrl->Q.mode == T_LOAD) {
 			uint64_t n_subaerial = 0;
@@ -1287,12 +1284,12 @@ int GMT_gmtflexure (void *V_API, int mode, void *args) {
 				for (seg = 0; seg < Q->table[tbl]->n_segments; seg++) {
 					S = Q->table[tbl]->segment[seg];	/* Current segment */
 					for (row = 0; row < S->n_rows; row++) {	/* Covert to pressure */
-						if (Ctrl->M.active[1]) S->coord[GMT_Y][row] *= 1000;	/* Got topography in km so scale to meters */
-						if (Ctrl->W.active && S->coord[GMT_Y][row] > Ctrl->W.water_depth) {
-							S->coord[GMT_Y][row] = (float)(Ctrl->W.water_depth + (S->coord[GMT_Y][row] - Ctrl->W.water_depth) * boost);
+						if (Ctrl->M.active[1]) S->data[GMT_Y][row] *= 1000;	/* Got topography in km so scale to meters */
+						if (Ctrl->W.active && S->data[GMT_Y][row] > Ctrl->W.water_depth) {
+							S->data[GMT_Y][row] = (float)(Ctrl->W.water_depth + (S->data[GMT_Y][row] - Ctrl->W.water_depth) * boost);
 							n_subaerial++;
 						}
-						S->coord[GMT_Y][row] *= scale;
+						S->data[GMT_Y][row] *= scale;
 					}
 				}
 			}
@@ -1303,17 +1300,23 @@ int GMT_gmtflexure (void *V_API, int mode, void *args) {
 		double scale = (Ctrl->M.active[1]) ? 1000.0 : 1.0;	/* Either got Te in km or m */
 		double d_min = DBL_MAX, d_max = 0.0;
 		GMT_Report (API, GMT_MSG_VERBOSE, "Processing input Te or Rigidity table data\n");
+		gmt_disable_i_opt (GMT);	/* Do not want any -i to affect the reading from -C,-F,-L files */
 		if ((E = GMT_Read_Data (API, GMT_IS_DATASET, GMT_IS_FILE, GMT_IS_LINE, GMT_READ_NORMAL, NULL, Ctrl->E.file, NULL)) == NULL) {
 			Return (API->error);
 		}
+		if (E->n_columns < 2) {
+			GMT_Report (API, GMT_MSG_NORMAL, "Input file %s has %d column(s) but at least 2 are needed\n", Ctrl->E.file, (int)E->n_columns);
+			Return (GMT_DIM_TOO_SMALL);
+		}
+		gmt_reenable_i_opt (GMT);	/* Recover settings provided by user (if -i was used at all) */
 		for (tbl = 0; tbl < E->n_tables; tbl++) {
 			for (seg = 0; seg < E->table[tbl]->n_segments; seg++) {
 				S = E->table[tbl]->segment[seg];	/* Current segment */
 				for (row = 0; row < S->n_rows; row++) {	/* Covert to pressure */
-					if (S->coord[GMT_Y][row] < 1e10) /* Got elastic thickness, convert to rigidity */
-						S->coord[GMT_Y][row] = te_2_d (Ctrl, scale * S->coord[GMT_Y][row]);
-					if (S->coord[GMT_Y][row] < d_min) d_min = S->coord[GMT_Y][row];
-					if (S->coord[GMT_Y][row] > d_max) d_max = S->coord[GMT_Y][row];
+					if (S->data[GMT_Y][row] < 1e10) /* Got elastic thickness, convert to rigidity */
+						S->data[GMT_Y][row] = te_2_d (Ctrl, scale * S->data[GMT_Y][row]);
+					if (S->data[GMT_Y][row] < d_min) d_min = S->data[GMT_Y][row];
+					if (S->data[GMT_Y][row] > d_max) d_max = S->data[GMT_Y][row];
 				}
 			}
 		}
@@ -1329,7 +1332,7 @@ int GMT_gmtflexure (void *V_API, int mode, void *args) {
 			for (tbl = 0; tbl < Q->n_tables; tbl++) {
 				for (seg = 0; seg < Q->table[tbl]->n_segments; seg++) {
 					S = Q->table[tbl]->segment[seg];	/* Current segment */
-					GMT_memset (S->coord[GMT_Y], S->n_rows, double);
+					gmt_M_memset (S->data[GMT_Y], S->n_rows, double);
 				}
 			}
 		}
@@ -1342,7 +1345,7 @@ int GMT_gmtflexure (void *V_API, int mode, void *args) {
 			}
 			S = Q->table[0]->segment[0];	/* Only a single segment here */
 			for (row = 0; row < dim[GMT_ROW]; row++) {	/* Fill in x values */
-				S->coord[GMT_X][row] = (row == (S->n_rows-1)) ? Ctrl->Q.max: Ctrl->Q.min + row * Ctrl->Q.inc;
+				S->data[GMT_X][row] = (row == (S->n_rows-1)) ? Ctrl->Q.max: Ctrl->Q.min + row * Ctrl->Q.inc;
 			}
 		}
 	}
@@ -1355,7 +1358,7 @@ int GMT_gmtflexure (void *V_API, int mode, void *args) {
 			for (seg = 0; seg < E->table[tbl]->n_segments; seg++) {
 				S = E->table[tbl]->segment[seg];	/* Current segment */
 				for (row = 0; row < S->n_rows; row++)	/* Set constant rigidity */
-					S->coord[GMT_Y][row] = d;
+					S->data[GMT_Y][row] = d;
 			}
 		}
 	}
@@ -1363,11 +1366,17 @@ int GMT_gmtflexure (void *V_API, int mode, void *args) {
 		GMT_Report (API, GMT_MSG_NORMAL, "Number of load and rigidity records are not the same!\n");
 		Return (API->error);
 	}
-	
+
 	if (Ctrl->T.active && Ctrl->T.file)	{	/* Read pre-existing deflections */
+		gmt_disable_i_opt (GMT);	/* Do not want any -i to affect the reading from -C,-F,-L files */
 		if ((T = GMT_Read_Data (API, GMT_IS_DATASET, GMT_IS_FILE, GMT_IS_LINE, GMT_READ_NORMAL, NULL, Ctrl->T.file, NULL)) == NULL) {
 			Return (API->error);
 		}
+		if (T->n_columns < 2) {
+			GMT_Report (API, GMT_MSG_NORMAL, "Input file %s has %d column(s) but at least 2 are needed\n", Ctrl->T.file, (int)T->n_columns);
+			Return (GMT_DIM_TOO_SMALL);
+		}
+		gmt_reenable_i_opt (GMT);	/* Recover settings provided by user (if -i was used at all) */
 		if (T->n_tables != E->n_tables || T->n_segments != E->n_segments || T->n_records != E->n_records) {
 			GMT_Report (API, GMT_MSG_NORMAL, "Number of pre-existing deflection records is not correct!\n");
 			Return (API->error);
@@ -1376,15 +1385,15 @@ int GMT_gmtflexure (void *V_API, int mode, void *args) {
 
 	restore = (Ctrl->D.rhom - Ctrl->D.rhoi) * NORMAL_GRAVITY;
 	n_columns = (Ctrl->S.active) ? 3 : 2;	/* Duplicate Q but posibly add 1 more column */
-	W = GMT_alloc_dataset (GMT, Q, 0, n_columns, GMT_ALLOC_NORMAL);
-	
+	W = gmt_alloc_dataset (GMT, Q, 0, n_columns, GMT_ALLOC_NORMAL);
+
 	for (tbl = 0; tbl < W->n_tables; tbl++) {
 		for (seg = 0; seg < W->table[tbl]->n_segments; seg++) {
 			S = Q->table[tbl]->segment[seg];
-			deflection = W->table[tbl]->segment[seg]->coord[GMT_Y];	/* Current flexure */
-			load = S->coord[GMT_Y];	/* Current load */
-			rigidity = E->table[tbl]->segment[seg]->coord[GMT_Y];	/* Current rigidities */
-			GMT_memcpy (W->table[tbl]->segment[seg]->coord[GMT_X], S->coord[GMT_X], S->n_rows, double);
+			deflection = W->table[tbl]->segment[seg]->data[GMT_Y];	/* Current flexure */
+			load = S->data[GMT_Y];	/* Current load */
+			rigidity = E->table[tbl]->segment[seg]->data[GMT_Y];	/* Current rigidities */
+			gmt_M_memcpy (W->table[tbl]->segment[seg]->data[GMT_X], S->data[GMT_X], S->n_rows, double);
 			sprintf (msg, "BCs > ");
 			if (Ctrl->A.bc[LEFT] == BC_INFINITY) strcat (msg, "infinity at left edge + ");
 			else if (Ctrl->A.bc[LEFT] == BC_PERIODIC) strcat (msg, "periodic at left edge + ");
@@ -1415,16 +1424,16 @@ int GMT_gmtflexure (void *V_API, int mode, void *args) {
 			GMT_Report (API, GMT_MSG_VERBOSE, msg);
 			for (row = 0, airy = true; airy && row < S->n_rows; row++)
 				if (rigidity[row] > 0.0) airy = false;
-			
+
 			if (airy) {	/* Airy compensation */
 				GMT_Report (API, GMT_MSG_VERBOSE, "Calculate flexure using Airy compensation\n");
 				for (row = 0; row < S->n_rows; row++) deflection[row] = load[row] / restore;
 			}
-			x_inc = S->coord[GMT_X][1] - S->coord[GMT_X][0];
+			x_inc = S->data[GMT_X][1] - S->data[GMT_X][0];
 			if (Ctrl->M.active[0]) x_inc *= 1000.0;	/* Got x in km */
-			
+
 			if (Ctrl->T.active) {	/* Plate has pre-existing deflection */
-				double *w0 = T->table[tbl]->segment[seg]->coord[GMT_Y];
+				double *w0 = T->table[tbl]->segment[seg]->data[GMT_Y];
 				GMT_Report (API, GMT_MSG_VERBOSE, "Calculate flexure of pre-deformed surface\n");
 				error = flx1dw0 (GMT, deflection, w0, rigidity, load, (int)S->n_rows, x_inc, &restore, 0, Ctrl->F.force, Ctrl->A.bc[LEFT], Ctrl->A.bc[RIGHT]);
 			}
@@ -1436,14 +1445,14 @@ int GMT_gmtflexure (void *V_API, int mode, void *args) {
 				GMT_Report (API, GMT_MSG_VERBOSE, "Calculate flexure for constant restoring force\n");
 				error = flx1d (GMT, deflection, rigidity, load, (int)S->n_rows, x_inc, &restore, 0, Ctrl->F.force, Ctrl->A.bc[LEFT], Ctrl->A.bc[RIGHT]);
 			}
-		
+
 			if (error) {
 				GMT_Report (API, GMT_MSG_VERBOSE, "Flexure sub-function returned error = %d!\n", error);
 				Return (API->error);
 			}
-	
+
 			if (Ctrl->S.active) {	/* Compute curvatures */
-				double *curvature = W->table[tbl]->segment[seg]->coord[GMT_Z];
+				double *curvature = W->table[tbl]->segment[seg]->data[GMT_Z];
 				get_curvature (deflection, (int)S->n_rows, x_inc, curvature);
 			}
 
@@ -1454,12 +1463,12 @@ int GMT_gmtflexure (void *V_API, int mode, void *args) {
 			}
 		}
 	}
-	
-	if (GMT_Write_Data (API, GMT_IS_DATASET, GMT_IS_FILE, GMT_IS_LINE, 0, NULL, Ctrl->Out.file, W) != GMT_OK) {
+
+	if (GMT_Write_Data (API, GMT_IS_DATASET, GMT_IS_FILE, GMT_IS_LINE, 0, NULL, Ctrl->Out.file, W) != GMT_NOERROR) {
 		Return (API->error);
 	}
-	
-	GMT_free_dataset (GMT, &W);
 
-	Return (EXIT_SUCCESS);
+	gmt_free_dataset (GMT, &W);
+
+	Return (GMT_NOERROR);
 }
