@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: pshistogram.c 15178 2015-11-06 10:45:03Z fwobbe $
+ *	$Id: pshistogram.c 17220 2016-10-19 02:56:33Z pwessel $
  *
- *	Copyright (c) 1991-2015 by P. Wessel, W. H. F. Smith, R. Scharroo, J. Luis and F. Wobbe
+ *	Copyright (c) 1991-2016 by P. Wessel, W. H. F. Smith, R. Scharroo, J. Luis and F. Wobbe
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -26,7 +26,7 @@
 #define THIS_MODULE_NAME	"pshistogram"
 #define THIS_MODULE_LIB		"core"
 #define THIS_MODULE_PURPOSE	"Calculate and plot histograms"
-#define THIS_MODULE_KEYS	"<DI,>XO,>Do"
+#define THIS_MODULE_KEYS	"<D{,>X},>D),>DI"
 
 #include "gmt_dev.h"
 
@@ -120,30 +120,30 @@ struct PSHISTOGRAM_INFO {	/* Control structure for pshistogram */
 	enum Pshistogram_extreme extremes;
 };
 
-void *New_pshistogram_Ctrl (struct GMT_CTRL *GMT) {	/* Allocate and initialize a new control structure */
+GMT_LOCAL void *New_Ctrl (struct GMT_CTRL *GMT) {	/* Allocate and initialize a new control structure */
 	unsigned int k;
 	struct PSHISTOGRAM_CTRL *C = NULL;
 
-	C = GMT_memory (GMT, NULL, 1, struct PSHISTOGRAM_CTRL);
+	C = gmt_M_memory (GMT, NULL, 1, struct PSHISTOGRAM_CTRL);
 
 	/* Initialize values whose defaults are not 0/false/NULL */
 	C->D.offset = 6.0 / 72.0;	/* 6 points */
-	C->D.font = GMT->current.setting.font_annot[0];		/* Default font */
-	GMT_init_fill (GMT, &C->G.fill, -1.0, -1.0, -1.0);	/* Do not fill is default */
+	C->D.font = GMT->current.setting.font_annot[GMT_PRIMARY];		/* Default font */
+	gmt_init_fill (GMT, &C->G.fill, -1.0, -1.0, -1.0);	/* Do not fill is default */
 	C->L.pen = GMT->current.setting.map_default_pen;
 	for (k = 0; k < 3; k++) C->N.pen[k] = GMT->current.setting.map_default_pen;
 
 	return (C);
 }
 
-void Free_pshistogram_Ctrl (struct GMT_CTRL *GMT, struct PSHISTOGRAM_CTRL *C) {	/* Deallocate control structure */
+GMT_LOCAL void Free_Ctrl (struct GMT_CTRL *GMT, struct PSHISTOGRAM_CTRL *C) {	/* Deallocate control structure */
 	if (!C) return;
-	if (C->Out.file) free (C->Out.file);
-	if (C->C.file) free (C->C.file);
-	GMT_free (GMT, C);
+	gmt_M_str_free (C->Out.file);
+	gmt_M_str_free (C->C.file);
+	gmt_M_free (GMT, C);
 }
 
-int fill_boxes (struct GMT_CTRL *GMT, struct PSHISTOGRAM_INFO *F, double *data, uint64_t n) {
+GMT_LOCAL int fill_boxes (struct GMT_CTRL *GMT, struct PSHISTOGRAM_INFO *F, double *data, uint64_t n) {
 
 	double add_half = 0.0;
 	uint64_t b0, b1, ibox, count_sum;
@@ -159,7 +159,7 @@ int fill_boxes (struct GMT_CTRL *GMT, struct PSHISTOGRAM_INFO *F, double *data,
 
 	if (F->n_boxes == 0) return (-1);
 
-	F->boxh = GMT_memory (GMT, NULL, F->n_boxes, uint64_t);
+	F->boxh = gmt_M_memory (GMT, NULL, F->n_boxes, uint64_t);
 
 	F->n_counted = 0;
 
@@ -203,11 +203,11 @@ int fill_boxes (struct GMT_CTRL *GMT, struct PSHISTOGRAM_INFO *F, double *data,
 		else if (F->hist_type == PSHISTOGRAM_LOG10_COUNTS)
 			F->yy0 = d_log101p (GMT, (double)b0);
 		else if (F->hist_type == PSHISTOGRAM_FREQ_PCT)
-			F->yy0 = (100.0 * b0) / F->n_counted;
+			F->yy0 = (F->n_counted) ? (100.0 * b0) / F->n_counted : 0.0;
 		else if (F->hist_type == PSHISTOGRAM_LOG_FREQ_PCT)
-			F->yy0 = d_log1p (GMT, 100.0 * b0 / F->n_counted );
+			F->yy0 = (F->n_counted) ? d_log1p (GMT, 100.0 * b0 / F->n_counted) : 0.0;
 		else if (F->hist_type == PSHISTOGRAM_LOG10_FREQ_PCT)
-			F->yy0 = d_log101p (GMT, 100.0 * b0 / F->n_counted );
+			F->yy0 = (F->n_counted) ? d_log101p (GMT, 100.0 * b0 / F->n_counted) : 0.0;
 		else
 			F->yy0 = (double)b0;
 	}
@@ -219,11 +219,11 @@ int fill_boxes (struct GMT_CTRL *GMT, struct PSHISTOGRAM_INFO *F, double *data,
 		else if (F->hist_type == PSHISTOGRAM_LOG10_COUNTS)
 			F->yy1 = d_log101p (GMT, (double)b1);
 		else if (F->hist_type == PSHISTOGRAM_FREQ_PCT)
-			F->yy1 = (100.0 * b1) / F->n_counted;
+			F->yy1 = (F->n_counted) ? (100.0 * b1) / F->n_counted : 0.0;
 		else if (F->hist_type == PSHISTOGRAM_LOG_FREQ_PCT)
-			F->yy1 = d_log1p (GMT, 100.0 * b1 / F->n_counted );
+			F->yy1 = (F->n_counted) ? d_log1p (GMT, 100.0 * b1 / F->n_counted) : 0.0;
 		else if (F->hist_type == PSHISTOGRAM_LOG10_FREQ_PCT)
-			F->yy1 = d_log101p (GMT, 100.0 * b1 / F->n_counted );
+			F->yy1 = (F->n_counted) ? d_log101p (GMT, 100.0 * b1 / F->n_counted) : 0.0;
 		else
 			F->yy1 = (double)b1;
 	}
@@ -233,8 +233,7 @@ int fill_boxes (struct GMT_CTRL *GMT, struct PSHISTOGRAM_INFO *F, double *data,
 	return (0);
 }
 
-double plot_boxes (struct GMT_CTRL *GMT, struct PSL_CTRL *PSL, struct GMT_PALETTE *P, struct PSHISTOGRAM_INFO *F, bool stairs, bool flip_to_y, bool draw_outline, struct GMT_PEN *pen, struct GMT_FILL *fill, bool cpt, struct D *D)
-{
+GMT_LOCAL double plot_boxes (struct GMT_CTRL *GMT, struct PSL_CTRL *PSL, struct GMT_PALETTE *P, struct PSHISTOGRAM_INFO *F, bool stairs, bool flip_to_y, bool draw_outline, struct GMT_PEN *pen, struct GMT_FILL *fill, bool cpt, struct D *D) {
 	int i, index, fmode = 0, label_justify = (flip_to_y) ? PSL_ML : PSL_BC;
 	uint64_t ibox;
 	char label[GMT_LEN64] = {""};
@@ -243,7 +242,7 @@ double plot_boxes (struct GMT_CTRL *GMT, struct PSL_CTRL *PSL, struct GMT_PALETT
 	double plot_x = 0.0, plot_y = 0.0;
 	struct GMT_FILL *f = NULL;
 
-	if (draw_outline) GMT_setpen (GMT, pen);
+	if (draw_outline) gmt_setpen (GMT, pen);
 
 	if (flip_to_y) {
 		px = y;
@@ -254,19 +253,7 @@ double plot_boxes (struct GMT_CTRL *GMT, struct PSL_CTRL *PSL, struct GMT_PALETT
 		py = y;
 	}
 
-	if (D->active) {	/* Place label, so set font */
-		fmode = GMT_setfont (GMT, &D->font);
-		if (D->just) {	/* Want labels beneath the bar, not above */
-			label_justify = (flip_to_y) ? PSL_MR: PSL_TC;
-			if (D->mode) label_justify = (flip_to_y) ? PSL_TC : PSL_MR;
-			if (D->mode) label_angle = (flip_to_y) ? -90.0 : 90.0;
-		}
-		else {	/* Want labels above the bar */
-			label_justify = (flip_to_y) ? PSL_ML : PSL_BC;
-			if (D->mode) label_justify = (flip_to_y) ? PSL_BC : PSL_ML;
-			if (D->mode) label_angle = (flip_to_y) ? -90.0 : 90.0;
-		}
-	}
+	/* First lay down the bars or curve */
 	for (ibox = 0; ibox < F->n_boxes; ibox++) {
 		if (stairs || F->boxh[ibox]) {
 			x[0] = F->wesn[XLO] + ibox * F->box_width;
@@ -297,7 +284,7 @@ double plot_boxes (struct GMT_CTRL *GMT, struct PSL_CTRL *PSL, struct GMT_PALETT
 				area += F->boxh[ibox];
 
 			for (i = 0; i < 4; i++) {
-				GMT_geo_to_xy (GMT, px[i], py[i], &xx, &yy);
+				gmt_geo_to_xy (GMT, px[i], py[i], &xx, &yy);
 				px[i] = xx;	py[i] = yy;
 			}
 
@@ -310,18 +297,65 @@ double plot_boxes (struct GMT_CTRL *GMT, struct PSL_CTRL *PSL, struct GMT_PALETT
 				PSL_plotpoint (PSL, px[2], py[2], PSL_DRAW);
 			}
 			else if (cpt) {
-				index = GMT_get_rgb_from_z (GMT, P, xval, rgb);
-				if ((index >= 0 && (f = P->range[index].fill) != NULL) || (index < 0 && (f = P->patch[index+3].fill) != NULL))	/* Pattern */
-					GMT_setfill (GMT, f, draw_outline);
+				index = gmt_get_rgb_from_z (GMT, P, xval, rgb);
+				if ((index >= 0 && (f = P->data[index].fill) != NULL) || (index < 0 && (f = P->bfn[index+3].fill) != NULL))	/* Pattern */
+					gmt_setfill (GMT, f, draw_outline);
 				else
 					PSL_setfill (PSL, rgb, draw_outline);
 				PSL_plotpolygon (PSL, px, py, 4);
 			}
 			else {
-				GMT_setfill (GMT, fill, draw_outline);
+				gmt_setfill (GMT, fill, draw_outline);
 				PSL_plotpolygon (PSL, px, py, 4);
 			}
-			if (D->active) {	/* Place label */
+		}
+	}
+	if (stairs) PSL_plotpoint (PSL, px[1], py[1], PSL_DRAW + PSL_STROKE);
+
+	/* If -D then place labels */
+	if (D->active) {	/* Place label, so set font */
+		fmode = gmt_setfont (GMT, &D->font);
+		if (D->just) {	/* Want labels beneath the bar, not above */
+			label_justify = (flip_to_y) ? PSL_MR: PSL_TC;
+			if (D->mode) label_justify = (flip_to_y) ? PSL_TC : PSL_MR;
+			if (D->mode) label_angle = (flip_to_y) ? -90.0 : 90.0;
+		}
+		else {	/* Want labels above the bar */
+			label_justify = (flip_to_y) ? PSL_ML : PSL_BC;
+			if (D->mode) label_justify = (flip_to_y) ? PSL_BC : PSL_ML;
+			if (D->mode) label_angle = (flip_to_y) ? -90.0 : 90.0;
+		}
+		for (ibox = 0; ibox < F->n_boxes; ibox++) {
+			if (stairs || F->boxh[ibox]) {
+				x[0] = F->wesn[XLO] + ibox * F->box_width;
+				if (F->center_box) x[0] -= (0.5 * F->box_width);
+				x[1] = x[0] + F->box_width;
+				if (x[0] < F->wesn[XLO]) x[0] = F->wesn[XLO];
+				if (x[1] > F->wesn[XHI]) x[1] = F->wesn[XHI];
+				xval = 0.5 * (x[0] + x[1]);	/* Used for cpt lookup */
+				x[2] = x[1];
+				x[3] = x[0];
+				y[0] = y[1] = F->wesn[YLO];
+				if (F->hist_type == PSHISTOGRAM_LOG_COUNTS)
+					y[2] = d_log1p (GMT, (double)F->boxh[ibox]);
+				else if (F->hist_type == PSHISTOGRAM_LOG10_COUNTS)
+					y[2] = d_log101p (GMT, (double)F->boxh[ibox]);
+				else if (F->hist_type == PSHISTOGRAM_FREQ_PCT)
+					y[2] = (100.0 * F->boxh[ibox]) / F->n_counted;
+				else if (F->hist_type == PSHISTOGRAM_LOG_FREQ_PCT)
+					y[2] = d_log1p (GMT, 100.0 * F->boxh[ibox] / F->n_counted );
+				else if (F->hist_type == PSHISTOGRAM_LOG10_FREQ_PCT)
+					y[2] = d_log101p (GMT, 100.0 * F->boxh[ibox] / F->n_counted );
+				else
+					y[2] = (double)F->boxh[ibox];
+				y[3] = y[2];
+
+				for (i = 0; i < 4; i++) {
+					gmt_geo_to_xy (GMT, px[i], py[i], &xx, &yy);
+					px[i] = xx;	py[i] = yy;
+				}
+
+				/* Place label */
 				if (flip_to_y) {
 					plot_y = 0.5 * (py[0] + py[1]);
 					plot_x = (D->just) ? px[0] - D->offset : px[2] + D->offset;
@@ -336,13 +370,11 @@ double plot_boxes (struct GMT_CTRL *GMT, struct PSL_CTRL *PSL, struct GMT_PALETT
 		}
 	}
 
-	if (stairs) PSL_plotpoint (PSL, px[1], py[1], PSL_DRAW + PSL_STROKE);
 	if (F->cumulative) return (area);
 	return (area * F->box_width);
 }
 
-int get_loc_scl (struct GMT_CTRL *GMT, double *data, uint64_t n, double *stats)
-{
+GMT_LOCAL int get_loc_scl (struct GMT_CTRL *GMT, double *data, uint64_t n, double *stats) {
 	/* Returns stats[] = L2, L1, LMS location, L2, L1, LMS scale  */
 
 	uint64_t i, j;
@@ -351,7 +383,7 @@ int get_loc_scl (struct GMT_CTRL *GMT, double *data, uint64_t n, double *stats)
 
 	if (n < 3) return (-1);
 
-	GMT_sort_array (GMT, data, n, GMT_DOUBLE);
+	gmt_sort_array (GMT, data, n, GMT_DOUBLE);
 
 	/* Get median */
 	j = n/2;
@@ -359,16 +391,16 @@ int get_loc_scl (struct GMT_CTRL *GMT, double *data, uint64_t n, double *stats)
 
 	/* Get mode */
 
-	GMT_mode (GMT, data, n, j, 0, 0, &n_multiples, &stats[2]);
+	gmt_mode (GMT, data, n, j, 0, 0, &n_multiples, &stats[2]);
 	if (n_multiples > 0) GMT_Report (GMT->parent, GMT_MSG_VERBOSE, "Warning: %d multiple modes found\n", n_multiples);
 
 	/* Get MAD for L1 */
 
-	GMT_getmad (GMT, data, n, stats[1], &stats[4]);
+	gmt_getmad (GMT, data, n, stats[1], &stats[4]);
 
 	/* Get LMSscale for mode */
 
-	GMT_getmad (GMT, data, n, stats[2], &stats[5]);
+	gmt_getmad (GMT, data, n, stats[2], &stats[5]);
 
 	/* Calculate mean and stdev in two passes to minimize risk of overflow */
 
@@ -384,9 +416,8 @@ int get_loc_scl (struct GMT_CTRL *GMT, double *data, uint64_t n, double *stats)
 	return (0);
 }
 
-int GMT_pshistogram_usage (struct GMTAPI_CTRL *API, int level)
-{
-	GMT_show_name_and_purpose (API, THIS_MODULE_LIB, THIS_MODULE_NAME, THIS_MODULE_PURPOSE);
+GMT_LOCAL int usage (struct GMTAPI_CTRL *API, int level) {
+	gmt_show_name_and_purpose (API, THIS_MODULE_LIB, THIS_MODULE_NAME, THIS_MODULE_PURPOSE);
 	if (level == GMT_MODULE_PURPOSE) return (GMT_NOERROR);
 	GMT_Message (API, GMT_TIME_NONE, "usage: pshistogram [<table>] %s -W<width>[+l|h|b] [-A] [%s] [-C<cpt>] [-D[+b][+f<font>][+o<off>][+r]]\n", GMT_Jx_OPT, GMT_B_OPT);
 	GMT_Message (API, GMT_TIME_NONE, "\t[-F] [-G<fill>] [-I[o|O]] [%s] [-K] [-L<pen>] [-N[<mode>][+p<pen>]] [-O] [-P] [-Q]\n", GMT_Jz_OPT);
@@ -394,7 +425,7 @@ int GMT_pshistogram_usage (struct GMTAPI_CTRL *API, int level)
 	GMT_Message (API, GMT_TIME_NONE, "\t[%s] [%s] [%s] [%s]\n\t[%s] [%s]\n\t[%s] [%s] [%s]\n\n", GMT_bi_OPT, GMT_di_OPT, GMT_c_OPT, GMT_f_OPT, GMT_h_OPT,
 		GMT_i_OPT, GMT_p_OPT, GMT_s_OPT, GMT_t_OPT);
 
-	if (level == GMT_SYNOPSIS) return (EXIT_FAILURE);
+	if (level == GMT_SYNOPSIS) return (GMT_MODULE_SYNOPSIS);
 
 	GMT_Option (API, "JXZ");
 	GMT_Message (API, GMT_TIME_NONE, "\t-W Set the bin width.  Append +l|h|b to include extreme values\n");
@@ -402,19 +433,19 @@ int GMT_pshistogram_usage (struct GMTAPI_CTRL *API, int level)
 	GMT_Message (API, GMT_TIME_NONE, "\n\tOPTIONS:\n");
 	GMT_Option (API, "<,B-");
 	GMT_Message (API, GMT_TIME_NONE, "\t-A Plot horizontal bars, i.e., flip x and y axis [Default is vertical].\n");
-	GMT_Message (API, GMT_TIME_NONE, "\t-C Use CPT file to assign fill to bars based on the mid x-value.\n");
+	GMT_Message (API, GMT_TIME_NONE, "\t-C Use CPT to assign fill to bars based on the mid x-value.\n");
 	GMT_Message (API, GMT_TIME_NONE, "\t-D Place histogram count labels on top of each bar; optionally append modifiers:\n");
 	GMT_Message (API, GMT_TIME_NONE, "\t   +b places the labels beneath the bars [above]\n");
 	GMT_Message (API, GMT_TIME_NONE, "\t   +f<font> sets the label font [FONT_ANNOT_PRIMARY]\n");
 	GMT_Message (API, GMT_TIME_NONE, "\t   +o sets the offset <off> between bar and label [6p]\n");
 	GMT_Message (API, GMT_TIME_NONE, "\t   +r rotates the label to be vertical [horizontal]\n");
 	GMT_Message (API, GMT_TIME_NONE, "\t-F Center the bins.\n");
-	GMT_fill_syntax (API->GMT, 'G', "Select color/pattern for columns.");
+	gmt_fill_syntax (API->GMT, 'G', "Select color/pattern for columns.");
 	GMT_Message (API, GMT_TIME_NONE, "\t-I Inquire about min/max x and y.  No plotting is done.\n");
 	GMT_Message (API, GMT_TIME_NONE, "\t   Append o to output the resulting x, y data.\n");
 	GMT_Message (API, GMT_TIME_NONE, "\t   Append O to output all resulting x, y data even with y=0.\n");
 	GMT_Option (API, "K");
-	GMT_pen_syntax (API->GMT, 'L', "Specify pen to draw histogram.", 0);
+	gmt_pen_syntax (API->GMT, 'L', "Specify pen to draw histogram.", 0);
 	GMT_Message (API, GMT_TIME_NONE, "\t-N Draw the equivalent normal distribution; append desired pen [0.25p,black].\n");
 	GMT_Message (API, GMT_TIME_NONE, "\t   <mode> selects which central location and scale to use:\n");
 	GMT_Message (API, GMT_TIME_NONE, "\t   0 = mean and standard deviation [Default]\n");
@@ -435,11 +466,10 @@ int GMT_pshistogram_usage (struct GMTAPI_CTRL *API, int level)
 	GMT_Message (API, GMT_TIME_NONE, "\t   5 - Log10 (1+frequency percent).\n");
 	GMT_Option (API, "bi2,c,di,f,h,i,p,s,t,.");
 
-	return (EXIT_FAILURE);
+	return (GMT_MODULE_USAGE);
 }
 
-int GMT_pshistogram_parse (struct GMT_CTRL *GMT, struct PSHISTOGRAM_CTRL *Ctrl, struct GMT_OPTION *options)
-{
+GMT_LOCAL int parse (struct GMT_CTRL *GMT, struct PSHISTOGRAM_CTRL *Ctrl, struct GMT_OPTION *options) {
 	/* This parses the options provided to pshistogram and sets parameters in Ctrl.
 	 * Note Ctrl has already been initialized and non-zero default values set.
 	 * Any GMT common options will override values set previously by other commands.
@@ -458,10 +488,10 @@ int GMT_pshistogram_parse (struct GMT_CTRL *GMT, struct PSHISTOGRAM_CTRL *Ctrl,
 		switch (opt->option) {
 
 			case '<':	/* Skip input files */
-				if (!GMT_check_filearg (GMT, '<', opt->arg, GMT_IN, GMT_IS_DATASET)) n_errors++;
+				if (!gmt_check_filearg (GMT, '<', opt->arg, GMT_IN, GMT_IS_DATASET)) n_errors++;
 				break;
 			case '>':	/* Got named output file */
-				if (n_files++ == 0 && GMT_check_filearg (GMT, '>', opt->arg, GMT_OUT, GMT_IS_DATASET))
+				if (n_files++ == 0 && gmt_check_filearg (GMT, '>', opt->arg, GMT_OUT, GMT_IS_DATASET))
 					Ctrl->Out.file = strdup (opt->arg);
 				else
 					n_errors++;
@@ -473,22 +503,22 @@ int GMT_pshistogram_parse (struct GMT_CTRL *GMT, struct PSHISTOGRAM_CTRL *Ctrl,
 				Ctrl->A.active = true;
 				break;
 			case 'C':
-				if (Ctrl->C.file) free (Ctrl->C.file);
+				gmt_M_str_free (Ctrl->C.file);
 				Ctrl->C.file = strdup (opt->arg);
 				Ctrl->C.active = true;
 				break;
 			case 'D':
 				Ctrl->D.active = true;
-				while (GMT_getmodopt (GMT, opt->arg, "bfor", &pos, p)) {	/* Looking for +b, +f, +o, +r */
+				while (gmt_getmodopt (GMT, opt->arg, "bfor", &pos, p)) {	/* Looking for +b, +f, +o, +r */
 					switch (p[0]) {
 						case 'b':	/* beneath */
 							Ctrl->D.just = 1;
 							break;
 						case 'o':	/* offset */
-							Ctrl->D.offset = GMT_to_inch (GMT, &p[1]);
+							Ctrl->D.offset = gmt_M_to_inch (GMT, &p[1]);
 							break;
 						case 'f':	/* offset */
-							n_errors += GMT_getfont (GMT, &p[1], &(Ctrl->D.font));
+							n_errors += gmt_getfont (GMT, &p[1], &(Ctrl->D.font));
 							break;
 						case 'r':	/* rotate */
 							Ctrl->D.mode = 1;
@@ -505,8 +535,8 @@ int GMT_pshistogram_parse (struct GMT_CTRL *GMT, struct PSHISTOGRAM_CTRL *Ctrl,
 				break;
 			case 'G':
 				Ctrl->G.active = true;
-				if (GMT_getfill (GMT, opt->arg, &Ctrl->G.fill)) {
-					GMT_fill_syntax (GMT, 'G', " ");
+				if (gmt_getfill (GMT, opt->arg, &Ctrl->G.fill)) {
+					gmt_fill_syntax (GMT, 'G', " ");
 					n_errors++;
 				}
 				break;
@@ -517,8 +547,8 @@ int GMT_pshistogram_parse (struct GMT_CTRL *GMT, struct PSHISTOGRAM_CTRL *Ctrl,
 				break;
 			case 'L':		/* Set line attributes */
 				Ctrl->L.active = true;
-				if (GMT_getpen (GMT, opt->arg, &Ctrl->L.pen)) {
-					GMT_pen_syntax (GMT, 'L', " ", 0);
+				if (gmt_getpen (GMT, opt->arg, &Ctrl->L.pen)) {
+					gmt_pen_syntax (GMT, 'L', " ", 0);
 					n_errors++;
 				}
 				break;
@@ -534,8 +564,8 @@ int GMT_pshistogram_parse (struct GMT_CTRL *GMT, struct PSHISTOGRAM_CTRL *Ctrl,
 				}
 				Ctrl->N.selected[mode] = true;
 				if ((c = strstr (opt->arg, "+p")) != NULL) {
-					if (GMT_getpen (GMT, &c[2], &Ctrl->N.pen[mode])) {
-						GMT_pen_syntax (GMT, 'L', " ", 0);
+					if (gmt_getpen (GMT, &c[2], &Ctrl->N.pen[mode])) {
+						gmt_pen_syntax (GMT, 'L', " ", 0);
 						n_errors++;
 					}
 				}
@@ -547,12 +577,12 @@ int GMT_pshistogram_parse (struct GMT_CTRL *GMT, struct PSHISTOGRAM_CTRL *Ctrl,
 				Ctrl->S.active = true;
 				break;
 			case 'T':
-				if (GMT_compat_check (GMT, 4)) {
+				if (gmt_M_compat_check (GMT, 4)) {
 					GMT_Report (API, GMT_MSG_COMPAT, "Warning: The -T option is deprecated; use -i instead.\n");
 					n_errors += gmt_parse_i_option (GMT, opt->arg);
 				}
 				else
-					n_errors += GMT_default_error (GMT, opt->option);
+					n_errors += gmt_default_error (GMT, opt->option);
 				break;
 			case 'W':
 				Ctrl->W.active = true;
@@ -574,34 +604,33 @@ int GMT_pshistogram_parse (struct GMT_CTRL *GMT, struct PSHISTOGRAM_CTRL *Ctrl,
 			case 'Z':
 				Ctrl->Z.active = true;
 				sval = atoi (opt->arg);
-				n_errors += GMT_check_condition (GMT, sval < PSHISTOGRAM_COUNTS || sval > PSHISTOGRAM_LOG10_FREQ_PCT, "Syntax error -Z option: histogram type must be in 0-5 range\n");
+				n_errors += gmt_M_check_condition (GMT, sval < PSHISTOGRAM_COUNTS || sval > PSHISTOGRAM_LOG10_FREQ_PCT, "Syntax error -Z option: histogram type must be in 0-5 range\n");
 				Ctrl->Z.mode = sval;
 				break;
 
 			default:	/* Report bad options */
-				n_errors += GMT_default_error (GMT, opt->option);
+				n_errors += gmt_default_error (GMT, opt->option);
 				break;
 		}
 	}
 
-	n_errors += GMT_check_condition (GMT, !Ctrl->I.active && !GMT_IS_LINEAR (GMT), "Syntax error -J option: Only linear projection supported.\n");
-	n_errors += GMT_check_condition (GMT, !Ctrl->W.active, "Syntax error -W option: Must specify bin width\n");
-	n_errors += GMT_check_condition (GMT, Ctrl->W.active && Ctrl->W.inc <= 0.0, "Syntax error -W option: bin width must be nonzero\n");
+	n_errors += gmt_M_check_condition (GMT, !Ctrl->I.active && !gmt_M_is_linear (GMT), "Syntax error -J option: Only linear projection supported.\n");
+	n_errors += gmt_M_check_condition (GMT, !Ctrl->W.active, "Syntax error -W option: Must specify bin width\n");
+	n_errors += gmt_M_check_condition (GMT, Ctrl->W.active && Ctrl->W.inc <= 0.0, "Syntax error -W option: bin width must be nonzero\n");
 
 	/* Now must specify either fill color with -G or outline pen with -L */
-	n_errors += GMT_check_condition (GMT, !(Ctrl->C.active || Ctrl->I.active || Ctrl->G.active || Ctrl->L.active), "Must specify either fill (-G) or lookup colors (-C), outline pen attributes (-L), or both.\n");
-	n_errors += GMT_check_condition (GMT, Ctrl->C.active && Ctrl->G.active, "Cannot specify both fill (-G) and lookup colors (-C).\n");
-	n_errors += GMT_check_binary_io (GMT, 0);
-	n_errors += GMT_check_condition (GMT, n_files > 1, "Syntax error: Only one output destination can be specified\n");
+	n_errors += gmt_M_check_condition (GMT, !(Ctrl->C.active || Ctrl->I.active || Ctrl->G.active || Ctrl->L.active), "Must specify either fill (-G) or lookup colors (-C), outline pen attributes (-L), or both.\n");
+	n_errors += gmt_M_check_condition (GMT, Ctrl->C.active && Ctrl->G.active, "Cannot specify both fill (-G) and lookup colors (-C).\n");
+	n_errors += gmt_check_binary_io (GMT, 0);
+	n_errors += gmt_M_check_condition (GMT, n_files > 1, "Syntax error: Only one output destination can be specified\n");
 
-	return (n_errors ? GMT_PARSE_ERROR : GMT_OK);
+	return (n_errors ? GMT_PARSE_ERROR : GMT_NOERROR);
 }
 
-#define bailout(code) {GMT_Free_Options (mode); return (code);}
-#define Return(code) {Free_pshistogram_Ctrl (GMT, Ctrl); GMT_end_module (GMT, GMT_cpy); bailout (code);}
+#define bailout(code) {gmt_M_free_options (mode); return (code);}
+#define Return(code) {Free_Ctrl (GMT, Ctrl); gmt_end_module (GMT, GMT_cpy); bailout (code);}
 
-int GMT_pshistogram (void *V_API, int mode, void *args)
-{
+int GMT_pshistogram (void *V_API, int mode, void *args) {
 	bool automatic = false;
 	int error = 0;
 
@@ -618,21 +647,21 @@ int GMT_pshistogram (void *V_API, int mode, void *args)
 	struct GMT_CTRL *GMT = NULL, *GMT_cpy = NULL;		/* General GMT interal parameters */
 	struct GMT_OPTION *options = NULL;
 	struct PSL_CTRL *PSL = NULL;		/* General PSL interal parameters */
-	struct GMTAPI_CTRL *API = GMT_get_API_ptr (V_API);	/* Cast from void to GMTAPI_CTRL pointer */
+	struct GMTAPI_CTRL *API = gmt_get_api_ptr (V_API);	/* Cast from void to GMTAPI_CTRL pointer */
 
 	/*----------------------- Standard module initialization and parsing ----------------------*/
 
 	if (API == NULL) return (GMT_NOT_A_SESSION);
-	if (mode == GMT_MODULE_PURPOSE) return (GMT_pshistogram_usage (API, GMT_MODULE_PURPOSE));	/* Return the purpose of program */
+	if (mode == GMT_MODULE_PURPOSE) return (usage (API, GMT_MODULE_PURPOSE));	/* Return the purpose of program */
 	options = GMT_Create_Options (API, mode, args);	if (API->error) return (API->error);	/* Set or get option list */
 
-	if (!options || options->option == GMT_OPT_USAGE) bailout (GMT_pshistogram_usage (API, GMT_USAGE));	/* Return the usage message */
-	if (options->option == GMT_OPT_SYNOPSIS) bailout (GMT_pshistogram_usage (API, GMT_SYNOPSIS));	/* Return the synopsis */
+	if (!options || options->option == GMT_OPT_USAGE) bailout (usage (API, GMT_USAGE));	/* Return the usage message */
+	if (options->option == GMT_OPT_SYNOPSIS) bailout (usage (API, GMT_SYNOPSIS));	/* Return the synopsis */
 
 	/* Parse the command-line arguments; return if errors are encountered */
 
-	GMT = GMT_begin_module (API, THIS_MODULE_LIB, THIS_MODULE_NAME, &GMT_cpy); /* Save current state */
-	if (GMT_compat_check (GMT, 4)) {	/* Must see if -E was given and temporarily change it */
+	GMT = gmt_begin_module (API, THIS_MODULE_LIB, THIS_MODULE_NAME, &GMT_cpy); /* Save current state */
+	if (gmt_M_compat_check (GMT, 4)) {	/* Must see if -E was given and temporarily change it */
 		struct GMT_OPTION *opt = NULL;
 		for (opt = options; opt->next; opt = opt->next) {
 			if (opt->option == 'E' && (opt->arg[0] == '\0' || opt->arg[0] == 'l' || opt->arg[0] == 'h'))
@@ -640,54 +669,56 @@ int GMT_pshistogram (void *V_API, int mode, void *args)
 		}
 	}
 	if (GMT_Parse_Common (API, GMT_PROG_OPTIONS, options)) Return (API->error);
-	Ctrl = New_pshistogram_Ctrl (GMT);	/* Allocate and initialize a new control structure */
-	if ((error = GMT_pshistogram_parse (GMT, Ctrl, options)) != 0) Return (error);
+	Ctrl = New_Ctrl (GMT);	/* Allocate and initialize a new control structure */
+	if ((error = parse (GMT, Ctrl, options)) != 0) Return (error);
 
 	/*---------------------------- This is the pshistogram main code ----------------------------*/
 
 	GMT_Report (API, GMT_MSG_VERBOSE, "Processing input table data\n");
-	GMT_memset (&F, 1, struct PSHISTOGRAM_INFO);
+	gmt_M_memset (&F, 1, struct PSHISTOGRAM_INFO);
 	F.hist_type  = Ctrl->Z.mode;
 	F.box_width  = Ctrl->W.inc;
 	F.cumulative = Ctrl->Q.active;
 	F.center_box = Ctrl->F.active;
 	F.extremes = Ctrl->W.mode;
 	if (!Ctrl->I.active && !GMT->common.R.active) automatic = true;
-	if (GMT->common.R.active) GMT_memcpy (F.wesn, GMT->common.R.wesn, 4, double);
+	if (GMT->common.R.active) gmt_M_memcpy (F.wesn, GMT->common.R.wesn, 4, double);
 
-	if ((error = GMT_set_cols (GMT, GMT_IN, 1)) != GMT_OK) {
+	if ((error = gmt_set_cols (GMT, GMT_IN, 1)) != GMT_NOERROR) {
 		Return (error);
 	}
-	if (GMT_Init_IO (API, GMT_IS_DATASET, GMT_IS_NONE, GMT_IN, GMT_ADD_DEFAULT, 0, options) != GMT_OK) {	/* Register data input */
+	if (GMT_Init_IO (API, GMT_IS_DATASET, GMT_IS_NONE, GMT_IN, GMT_ADD_DEFAULT, 0, options) != GMT_NOERROR) {	/* Register data input */
 		Return (API->error);
 	}
-	if (GMT_Begin_IO (API, GMT_IS_DATASET, GMT_IN, GMT_HEADER_ON) != GMT_OK) {	/* Enables data input and sets access mode */
+	if (GMT_Begin_IO (API, GMT_IS_DATASET, GMT_IN, GMT_HEADER_ON) != GMT_NOERROR) {	/* Enables data input and sets access mode */
 		Return (API->error);
 	}
 
-	if (Ctrl->C.active && (P = GMT_Read_Data (API, GMT_IS_CPT, GMT_IS_FILE, GMT_IS_NONE, GMT_READ_NORMAL, NULL, Ctrl->C.file, NULL)) == NULL) {
+	if (Ctrl->C.active && (P = GMT_Read_Data (API, GMT_IS_PALETTE, GMT_IS_FILE, GMT_IS_NONE, GMT_READ_NORMAL, NULL, Ctrl->C.file, NULL)) == NULL) {
 		Return (GMT_DATA_READ_ERROR);
 	}
 
-	data = GMT_memory (GMT, NULL, n_alloc , double);
+	data = gmt_M_memory (GMT, NULL, n_alloc , double);
 
 	n = 0;
 	x_min = DBL_MAX;	x_max = -DBL_MAX;
 
 	do {	/* Keep returning records until we reach EOF */
 		if ((in = GMT_Get_Record (API, GMT_READ_DOUBLE, NULL)) == NULL) {	/* Read next record, get NULL if special case */
-			if (GMT_REC_IS_ERROR (GMT)) 		/* Bail if there are any read errors */
+			if (gmt_M_rec_is_error (GMT)) { 		/* Bail if there are any read errors */
+				gmt_M_free (GMT, data);
 				Return (GMT_RUNTIME_ERROR);
-			if (GMT_REC_IS_ANY_HEADER (GMT)) 	/* Skip all table and segment headers */
+			}
+			if (gmt_M_rec_is_any_header (GMT)) 	/* Skip all table and segment headers */
 				continue;
-			if (GMT_REC_IS_EOF (GMT)) 		/* Reached end of file */
+			if (gmt_M_rec_is_eof (GMT)) 		/* Reached end of file */
 				break;
 		}
 
 		/* Data record to process */
 
 		data[n] = in[GMT_X];
-		if (!GMT_is_dnan (data[n])) {
+		if (!gmt_M_is_dnan (data[n])) {
 			x_min = MIN (x_min, data[n]);
 			x_max = MAX (x_max, data[n]);
 			n++;
@@ -695,29 +726,33 @@ int GMT_pshistogram (void *V_API, int mode, void *args)
 
 		if (n == n_alloc) {
 			n_alloc <<= 1;
-			data = GMT_memory (GMT, data,  n_alloc, double);
+			data = gmt_M_memory (GMT, data,  n_alloc, double);
 		}
 	} while (true);
 
-	if (GMT_End_IO (API, GMT_IN, 0) != GMT_OK) {
+	if (GMT_End_IO (API, GMT_IN, 0) != GMT_NOERROR) {
+		gmt_M_free (GMT, data);
 		Return (API->error);	/* Disables further data input */
 	}
 
 	if (n == 0) {
 		GMT_Report (API, GMT_MSG_NORMAL, "Fatal error, read only 0 points.\n");
-		Return (EXIT_FAILURE);
+		gmt_M_free (GMT, data);
+		Return (GMT_RUNTIME_ERROR);
 	}
 
 	GMT_Report (API, GMT_MSG_VERBOSE, "%" PRIu64 " points read\n", n);
 
-	data = GMT_memory (GMT, data, n, double);
+	data = gmt_M_memory (GMT, data, n, double);
 
 	get_loc_scl (GMT, data, n, stats);
 
-	if (GMT_is_verbose (GMT, GMT_MSG_VERBOSE)) {
+	if (gmt_M_is_verbose (GMT, GMT_MSG_VERBOSE)) {
 		sprintf (format, "Extreme values of the data :\t%s\t%s\n", GMT->current.setting.format_float_out, GMT->current.setting.format_float_out);
 		GMT_Report (API, GMT_MSG_VERBOSE, format, data[0], data[n-1]);
-		sprintf (format, "Locations: L2, L1, LMS; Scales: L2, L1, LMS\t%s\t%s\t%s\t%s\t%s\t%s\n", GMT->current.setting.format_float_out, GMT->current.setting.format_float_out, GMT->current.setting.format_float_out, GMT->current.setting.format_float_out, GMT->current.setting.format_float_out, GMT->current.setting.format_float_out);
+		sprintf (format, "Locations: L2, L1, LMS; Scales: L2, L1, LMS\t%s\t%s\t%s\t%s\t%s\t%s\n",
+		         GMT->current.setting.format_float_out, GMT->current.setting.format_float_out, GMT->current.setting.format_float_out,
+		         GMT->current.setting.format_float_out, GMT->current.setting.format_float_out, GMT->current.setting.format_float_out);
 		GMT_Report (API, GMT_MSG_VERBOSE, format, stats[0], stats[1], stats[2], stats[3], stats[4], stats[5]);
 	}
 
@@ -740,11 +775,14 @@ int GMT_pshistogram (void *V_API, int mode, void *args)
 
 	if (fill_boxes (GMT, &F, data, n)) {
 		GMT_Report (API, GMT_MSG_NORMAL, "Fatal error during box fill.\n");
-		Return (EXIT_FAILURE);
+		gmt_M_free (GMT, data);		gmt_M_free (GMT, F.boxh);
+		Return (GMT_RUNTIME_ERROR);
 	}
 
-	if (GMT_is_verbose (GMT, GMT_MSG_VERBOSE)) {
-		sprintf (format, "min/max values are :\t%s\t%s\t%s\t%s\n", GMT->current.setting.format_float_out, GMT->current.setting.format_float_out, GMT->current.setting.format_float_out, GMT->current.setting.format_float_out);
+	if (gmt_M_is_verbose (GMT, GMT_MSG_VERBOSE)) {
+		sprintf (format, "min/max values are :\t%s\t%s\t%s\t%s\n",
+		         GMT->current.setting.format_float_out, GMT->current.setting.format_float_out,
+		         GMT->current.setting.format_float_out, GMT->current.setting.format_float_out);
 		GMT_Report (API, GMT_MSG_VERBOSE, format, x_min, x_max, F.yy0, F.yy1);
 	}
 
@@ -768,9 +806,11 @@ int GMT_pshistogram (void *V_API, int mode, void *args)
 			dim[GMT_ROW] = n_boxes;
 			if ((D = GMT_Create_Data (API, GMT_IS_DATASET, GMT_IS_NONE, 0, dim, NULL, NULL, 0, 0, NULL)) == NULL) {
 				GMT_Report (API, GMT_MSG_NORMAL, "Unable to create a data set for histogram\n");
+				gmt_M_free (GMT, data);		gmt_M_free (GMT, F.boxh);
 				Return (API->error);
 			}
-			if ((error = GMT_set_cols (GMT, GMT_OUT, 2)) != GMT_OK) {
+			if ((error = gmt_set_cols (GMT, GMT_OUT, 2)) != GMT_NOERROR) {
+				gmt_M_free (GMT, data);		gmt_M_free (GMT, F.boxh);
 				Return (error);
 			}
 			S = D->table[0]->segment[0];	/* Only one table with one segment here, with 2 cols and F.n_boxes rows */
@@ -790,30 +830,35 @@ int GMT_pshistogram (void *V_API, int mode, void *args)
 					yy = d_log101p (GMT, 100.0 * F.boxh[ibox] / F.n_counted );
 				else
 					yy = (double)F.boxh[ibox];
-				S->coord[GMT_X][row] = xx;
-				S->coord[GMT_Y][row] = yy;
+				S->data[GMT_X][row] = xx;
+				S->data[GMT_Y][row] = yy;
 				row++;
 			}
-			if (GMT_Write_Data (GMT->parent, GMT_IS_DATASET, GMT_IS_STREAM, GMT_IS_POINT, D->io_mode, NULL, Ctrl->Out.file, D) != GMT_OK) {
+			if (GMT_Write_Data (GMT->parent, GMT_IS_DATASET, GMT_IS_STREAM, GMT_IS_POINT, D->io_mode, NULL, Ctrl->Out.file, D) != GMT_NOERROR) {
+				gmt_M_free (GMT, data);		gmt_M_free (GMT, F.boxh);
 				Return (API->error);
 			}
-			if (GMT_Destroy_Data (GMT->parent, &D) != GMT_OK) {
+			if (GMT_Destroy_Data (GMT->parent, &D) != GMT_NOERROR) {
+				gmt_M_free (GMT, data);		gmt_M_free (GMT, F.boxh);
 				Return (API->error);
 			}
 		}
 		else {	/* Report the min/max values as the data result */
 			double out[4];
 			unsigned int col_type[4];
-			GMT_memcpy (col_type, GMT->current.io.col_type[GMT_OUT], 4U, unsigned int);	/* Save first 4 current output col types */
+			gmt_M_memcpy (col_type, GMT->current.io.col_type[GMT_OUT], 4U, unsigned int);	/* Save first 4 current output col types */
 			GMT->current.io.col_type[GMT_OUT][0] = GMT->current.io.col_type[GMT_OUT][1] = GMT->current.io.col_type[GMT_IN][0];
 			GMT->current.io.col_type[GMT_OUT][2] = GMT->current.io.col_type[GMT_OUT][3] = GMT_IS_FLOAT;
-			if ((error = GMT_set_cols (GMT, GMT_OUT, 4U)) != GMT_OK) {
+			if ((error = gmt_set_cols (GMT, GMT_OUT, 4U)) != GMT_NOERROR) {
+				gmt_M_free (GMT, data);		gmt_M_free (GMT, F.boxh);
 				Return (error);
 			}
-			if (GMT_Init_IO (API, GMT_IS_DATASET, GMT_IS_NONE, GMT_OUT, GMT_ADD_DEFAULT, 0, options) != GMT_OK) {	/* Establishes data output */
+			if (GMT_Init_IO (API, GMT_IS_DATASET, GMT_IS_NONE, GMT_OUT, GMT_ADD_DEFAULT, 0, options) != GMT_NOERROR) {	/* Establishes data output */
+				gmt_M_free (GMT, data);		gmt_M_free (GMT, F.boxh);
 				Return (API->error);
 			}
-			if (GMT_Begin_IO (API, GMT_IS_DATASET, GMT_OUT, GMT_HEADER_ON) != GMT_OK) {
+			if (GMT_Begin_IO (API, GMT_IS_DATASET, GMT_OUT, GMT_HEADER_ON) != GMT_NOERROR) {
+				gmt_M_free (GMT, data);		gmt_M_free (GMT, F.boxh);
 				Return (API->error);	/* Enables data output and sets access mode */
 			}
 			sprintf (format, "xmin\txmax\tymin\tymax from pshistogram -I -W%g -Z%u", Ctrl->W.inc, Ctrl->Z.mode);
@@ -821,14 +866,15 @@ int GMT_pshistogram (void *V_API, int mode, void *args)
 			out[0] = x_min;	out[1] = x_max;	out[2] = F.yy0;	out[3] = F.yy1;
 			GMT_Put_Record (API, GMT_WRITE_TABLE_HEADER, format);	/* Write this to output if -ho */
 			GMT_Put_Record (API, GMT_WRITE_DOUBLE, out);
-			if (GMT_End_IO (API, GMT_OUT, 0) != GMT_OK) {	/* Disables further data output */
+			if (GMT_End_IO (API, GMT_OUT, 0) != GMT_NOERROR) {	/* Disables further data output */
+				gmt_M_free (GMT, data);		gmt_M_free (GMT, F.boxh);
 				Return (API->error);
 			}
-			GMT_memcpy (GMT->current.io.col_type[GMT_OUT], col_type, 4U, unsigned int);	/* Restore 4 current output col types */
+			gmt_M_memcpy (GMT->current.io.col_type[GMT_OUT], col_type, 4U, unsigned int);	/* Restore 4 current output col types */
 		}
-		GMT_free (GMT, data);
-		GMT_free (GMT, F.boxh);
-		Return (EXIT_SUCCESS);
+		gmt_M_free (GMT, data);
+		gmt_M_free (GMT, F.boxh);
+		Return (GMT_NOERROR);
 	}
 
 	if (automatic) {	/* Set up s/n based on 'clever' rounding up of the minmax values */
@@ -849,22 +895,28 @@ int GMT_pshistogram (void *V_API, int mode, void *args)
 		}
 		if (GMT->current.proj.pars[0] == 0.0 && GMT->current.proj.pars[1] == 0.0) {
 			GMT_Report (API, GMT_MSG_NORMAL, "Need to provide both x- and y-scale.\n");
-			Return (EXIT_FAILURE);
+			gmt_M_free (GMT, data);
+			Return (GMT_RUNTIME_ERROR);
 		}
 	}
 
-	if (automatic && GMT_is_verbose (GMT, GMT_MSG_VERBOSE)) {
-		sprintf (format, "Use w/e/s/n = %s/%s/%s/%s and x-tick/y-tick = %s/%s\n", GMT->current.setting.format_float_out, GMT->current.setting.format_float_out, GMT->current.setting.format_float_out, GMT->current.setting.format_float_out, GMT->current.setting.format_float_out, GMT->current.setting.format_float_out);
-		GMT_Report (API, GMT_MSG_VERBOSE, format, F.wesn[XLO], F.wesn[XHI], F.wesn[YLO], F.wesn[YHI], GMT->current.map.frame.axis[GMT_X].item[GMT_ANNOT_UPPER].interval, GMT->current.map.frame.axis[GMT_Y].item[GMT_ANNOT_UPPER].interval);
+	if (automatic && gmt_M_is_verbose (GMT, GMT_MSG_VERBOSE)) {
+		sprintf (format, "Use w/e/s/n = %s/%s/%s/%s and x-tick/y-tick = %s/%s\n",
+		         GMT->current.setting.format_float_out, GMT->current.setting.format_float_out,
+		         GMT->current.setting.format_float_out, GMT->current.setting.format_float_out,
+		         GMT->current.setting.format_float_out, GMT->current.setting.format_float_out);
+		GMT_Report (API, GMT_MSG_VERBOSE, format, F.wesn[XLO], F.wesn[XHI], F.wesn[YLO], F.wesn[YHI],
+		            GMT->current.map.frame.axis[GMT_X].item[GMT_ANNOT_UPPER].interval,
+		            GMT->current.map.frame.axis[GMT_Y].item[GMT_ANNOT_UPPER].interval);
 	}
 
 	if (Ctrl->A.active) {	/* Must flip x and y axis */
 		struct GMT_PLOT_AXIS shelf;
 		double wesn[4];
 		unsigned int k;
-		GMT_memcpy (&shelf, &GMT->current.map.frame.axis[GMT_X], 1, struct GMT_PLOT_AXIS);
-		GMT_memcpy (&GMT->current.map.frame.axis[GMT_X], &GMT->current.map.frame.axis[GMT_Y], 1, struct GMT_PLOT_AXIS);
-		GMT_memcpy (&GMT->current.map.frame.axis[GMT_Y], &shelf, 1, struct GMT_PLOT_AXIS);
+		gmt_M_memcpy (&shelf, &GMT->current.map.frame.axis[GMT_X], 1, struct GMT_PLOT_AXIS);
+		gmt_M_memcpy (&GMT->current.map.frame.axis[GMT_X], &GMT->current.map.frame.axis[GMT_Y], 1, struct GMT_PLOT_AXIS);
+		gmt_M_memcpy (&GMT->current.map.frame.axis[GMT_Y], &shelf, 1, struct GMT_PLOT_AXIS);
 		/* But must update the ids of parents and children since x and y ids have been swapped too */
 		GMT->current.map.frame.axis[GMT_X].id = GMT_X;
 		GMT->current.map.frame.axis[GMT_Y].id = GMT_Y;
@@ -874,31 +926,34 @@ int GMT_pshistogram (void *V_API, int mode, void *args)
 		}
 		wesn[XLO] = F.wesn[YLO];	wesn[XHI] = F.wesn[YHI];
 		wesn[YLO] = F.wesn[XLO];	wesn[YHI] = F.wesn[XHI];
-		if (GMT_err_pass (GMT, GMT_map_setup (GMT, wesn), "")) Return (GMT_PROJECTION_ERROR);
+		if (gmt_M_err_pass (GMT, gmt_map_setup (GMT, wesn), "")) Return (GMT_PROJECTION_ERROR);
 	}
 	else {
-		if (GMT_err_pass (GMT, GMT_map_setup (GMT, F.wesn), "")) Return (GMT_PROJECTION_ERROR);
+		if (gmt_M_err_pass (GMT, gmt_map_setup (GMT, F.wesn), "")) {
+			gmt_M_free (GMT, data);
+			Return (GMT_PROJECTION_ERROR);
+		}
 	}
 
-	if ((PSL = GMT_plotinit (GMT, options)) == NULL) Return (GMT_RUNTIME_ERROR);
+	if ((PSL = gmt_plotinit (GMT, options)) == NULL) Return (GMT_RUNTIME_ERROR);
 
-	GMT_plane_perspective (GMT, GMT->current.proj.z_project.view_plane, GMT->current.proj.z_level);
-	GMT_plotcanvas (GMT);	/* Fill canvas if requested */
+	gmt_plane_perspective (GMT, GMT->current.proj.z_project.view_plane, GMT->current.proj.z_level);
+	gmt_plotcanvas (GMT);	/* Fill canvas if requested */
 
-	if (Ctrl->D.just == 0) GMT_map_clip_on (GMT, GMT->session.no_rgb, 3);
+	if (Ctrl->D.just == 0) gmt_map_clip_on (GMT, GMT->session.no_rgb, 3);
 	area = plot_boxes (GMT, PSL, P, &F, Ctrl->S.active, Ctrl->A.active, Ctrl->L.active, &Ctrl->L.pen, &Ctrl->G.fill, Ctrl->C.active, &Ctrl->D);
 	GMT_Report (API, GMT_MSG_VERBOSE, "Area under histogram is %g\n", area);
 
 	if (Ctrl->N.active) {	/* Want to draw one or more normal distributions; we use 101 points to do so */
 		unsigned int type, k, NP = 101U;
 		double f, z, xtmp, ytmp, inc;
-		double *xp = GMT_memory (GMT, NULL, NP, double);
-		double *yp = GMT_memory (GMT, NULL, NP, double);
+		double *xp = gmt_M_memory (GMT, NULL, NP, double);
+		double *yp = gmt_M_memory (GMT, NULL, NP, double);
 		inc = (F.wesn[XHI] - F.wesn[XLO]) / (NP - 1);
 		for (type = 0; type < 3; type++) {
 			if (!Ctrl->N.selected[type]) continue;
 			/* Draw this estimation of a normal distribution */
-			GMT_setpen (GMT, &Ctrl->N.pen[type]);
+			gmt_setpen (GMT, &Ctrl->N.pen[type]);
 			f = (Ctrl->Q.active) ? 0.5 : 1.0 / (stats[type+3] * sqrt (M_PI * 2.0));
 			f *= area;
 			for (k = 0; k < NP; k++) {
@@ -916,23 +971,23 @@ int GMT_pshistogram (void *V_API, int mode, void *args)
 					case PSHISTOGRAM_LOG10_FREQ_PCT:	yp[k] = d_log101p (GMT, 100.0 * yp[k] / F.n_counted);	break;
 				}
 
-				GMT_geo_to_xy (GMT, xp[k], yp[k], &xtmp, &ytmp);
+				gmt_geo_to_xy (GMT, xp[k], yp[k], &xtmp, &ytmp);
 				xp[k] = xtmp;	yp[k] = ytmp;
 			}
 			PSL_plotline (PSL, xp, yp, NP, PSL_MOVE + PSL_STROKE);
 		}
-		GMT_free (GMT, xp);
-		GMT_free (GMT, yp);
+		gmt_M_free (GMT, xp);
+		gmt_M_free (GMT, yp);
 	}
 
-	if (Ctrl->D.just == 0) GMT_map_clip_off (GMT);
+	if (Ctrl->D.just == 0) gmt_map_clip_off (GMT);
 
-	GMT_map_basemap (GMT);
-	GMT_plane_perspective (GMT, -1, 0.0);
-	GMT_plotend (GMT);
+	gmt_map_basemap (GMT);
+	gmt_plane_perspective (GMT, -1, 0.0);
+	gmt_plotend (GMT);
 
-	GMT_free (GMT, data);
-	GMT_free (GMT, F.boxh);
+	gmt_M_free (GMT, data);
+	gmt_M_free (GMT, F.boxh);
 
-	Return (GMT_OK);
+	Return (GMT_NOERROR);
 }
