@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: psimage.c 15178 2015-11-06 10:45:03Z fwobbe $
+ *	$Id: psimage.c 17224 2016-10-19 16:14:30Z remko $
  *
- *	Copyright (c) 1991-2015 by P. Wessel, W. H. F. Smith, R. Scharroo, J. Luis and F. Wobbe
+ *	Copyright (c) 1991-2016 by P. Wessel, W. H. F. Smith, R. Scharroo, J. Luis and F. Wobbe
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -28,7 +28,7 @@
 #define THIS_MODULE_NAME	"psimage"
 #define THIS_MODULE_LIB		"core"
 #define THIS_MODULE_PURPOSE	"Place images or EPS files on maps"
-#define THIS_MODULE_KEYS	"<II,>XO,RG-"
+#define THIS_MODULE_KEYS	"<I{,>X}"
 
 #include "gmt_dev.h"
 
@@ -39,7 +39,7 @@ struct PSIMAGE_CTRL {
 		bool active;
 		char *file;
 	} In;
-	struct PSIMG_D {	/* -D[g|j|n|x]<refpoint>+w[-]<width>[/<height>][+j<justify>][+n<nx>[/<ny>]][+o<off[GMT_X]>[/<dy>]][+r<dpi>] */
+	struct PSIMG_D {	/* -D[g|j|n|x]<refpoint>+w[-]<width>[/<height>][+j<justify>][+n<n_columns>[/<n_rows>]][+o<off[GMT_X]>[/<dy>]][+r<dpi>] */
 		bool active;
 		struct GMT_REFPOINT *refpoint;
 		double off[2];
@@ -47,7 +47,7 @@ struct PSIMAGE_CTRL {
 		bool interpolate;
 		double dim[2];
 		double dpi;
-		unsigned int nx, ny;
+		unsigned int n_columns, n_rows;
 	} D;
 	struct PSIMG_F {	/* -F[+c<clearance>][+g<fill>][+i[<off>/][<pen>]][+p[<pen>]][+r[<radius>]][+s[<dx>/<dy>/][<shade>]][+d] */
 		bool active;
@@ -67,65 +67,63 @@ struct PSIMAGE_CTRL {
 	} M;
 };
 
-void *New_psimage_Ctrl (struct GMT_CTRL *GMT) {	/* Allocate and initialize a new control structure */
+GMT_LOCAL void *New_Ctrl (struct GMT_CTRL *GMT) {	/* Allocate and initialize a new control structure */
 	struct PSIMAGE_CTRL *C;
 
-	C = GMT_memory (GMT, NULL, 1, struct PSIMAGE_CTRL);
+	C = gmt_M_memory (GMT, NULL, 1, struct PSIMAGE_CTRL);
 
 	/* Initialize values whose defaults are not 0/false/NULL */
 	C->G.f_rgb[0] = C->G.b_rgb[0] = C->G.t_rgb[0] = -2;
-	C->D.nx = C->D.ny = 1;
+	C->D.n_columns = C->D.n_rows = 1;
 	return (C);
 }
 
-void Free_psimage_Ctrl (struct GMT_CTRL *GMT, struct PSIMAGE_CTRL *C) {	/* Deallocate control structure */
+GMT_LOCAL void Free_Ctrl (struct GMT_CTRL *GMT, struct PSIMAGE_CTRL *C) {	/* Deallocate control structure */
 	if (!C) return;
-	if (C->In.file) free (C->In.file);
-	GMT_free_refpoint (GMT, &C->D.refpoint);
-	if (C->F.panel) GMT_free (GMT, C->F.panel);
-	GMT_free (GMT, C);
+	gmt_M_str_free (C->In.file);
+	gmt_free_refpoint (GMT, &C->D.refpoint);
+	gmt_M_free (GMT, C->F.panel);
+	gmt_M_free (GMT, C);
 }
 
-int GMT_psimage_usage (struct GMTAPI_CTRL *API, int level)
-{
+GMT_LOCAL int usage (struct GMTAPI_CTRL *API, int level) {
 	/* This displays the psimage synopsis and optionally full usage information */
 
-	GMT_show_name_and_purpose (API, THIS_MODULE_LIB, THIS_MODULE_NAME, THIS_MODULE_PURPOSE);
+	gmt_show_name_and_purpose (API, THIS_MODULE_LIB, THIS_MODULE_NAME, THIS_MODULE_PURPOSE);
 	if (level == GMT_MODULE_PURPOSE) return (GMT_NOERROR);
-	GMT_Message (API, GMT_TIME_NONE, "usage: psimage <imagefile> [%s] [-D%s+w[-]<width>[/<height>][+n<nx>[/<ny>]]%s+r<dpi>]\n", GMT_B_OPT, GMT_XYANCHOR, GMT_OFFSET);
+	GMT_Message (API, GMT_TIME_NONE, "usage: psimage <imagefile> [%s] [-D%s+w[-]<width>[/<height>][+n<n_columns>[/<n_rows>]]%s+r<dpi>]\n", GMT_B_OPT, GMT_XYANCHOR, GMT_OFFSET);
 	GMT_Message (API, GMT_TIME_NONE, "\t[%s]\n", GMT_PANEL);
 	GMT_Message (API, GMT_TIME_NONE, "\t[-G[b|f|t]<color>] [-I] [%s] [%s] [-K] [-M] [-O]\n", GMT_J_OPT, GMT_Jz_OPT);
 	GMT_Message (API, GMT_TIME_NONE, "\t[-P] [%s] [%s]\n", GMT_Rgeoz_OPT, GMT_U_OPT);
 	GMT_Message (API, GMT_TIME_NONE, "\t[%s] [%s] [%s] [%s]\n\t[%s] [%s]\n\n", GMT_V_OPT, GMT_X_OPT, GMT_Y_OPT, GMT_c_OPT, GMT_p_OPT, GMT_t_OPT);
 
-	if (level == GMT_SYNOPSIS) return (EXIT_FAILURE);
+	if (level == GMT_SYNOPSIS) return (GMT_MODULE_SYNOPSIS);
 
 	GMT_Message (API, GMT_TIME_NONE, "\t<imagefile> is an EPS or image file.\n");
 	GMT_Message (API, GMT_TIME_NONE, "\n\tOPTIONS:\n");
 	GMT_Option (API, "B");
-	GMT_refpoint_syntax (API->GMT, 'D', "Specify reference point for the image", GMT_ANCHOR_IMAGE, 3);
+	gmt_refpoint_syntax (API->GMT, 'D', "Specify reference point for the image", GMT_ANCHOR_IMAGE, 3);
 	GMT_Message (API, GMT_TIME_NONE, "\t   Set width (and height) of image with +w<width>/[/<height>].  If <height> = 0\n");
 	GMT_Message (API, GMT_TIME_NONE, "\t   then the original aspect ratio is maintained.  If <width> < 0\n");
 	GMT_Message (API, GMT_TIME_NONE, "\t   then we use absolute value as width and interpolate image in PostScript.\n");
 	GMT_Message (API, GMT_TIME_NONE, "\t   Alternatively, set image dpi (dots per inch) with +r.\n");
-	GMT_Message (API, GMT_TIME_NONE, "\t   Use +n to replicate image <nx> by <ny> times [Default is no replication].\n");
-	GMT_mappanel_syntax (API->GMT, 'F', "Specify a rectangular panel behind the image", 1);
+	GMT_Message (API, GMT_TIME_NONE, "\t   Use +n to replicate image <n_columns> by <n_rows> times [Default is no replication].\n");
+	gmt_mappanel_syntax (API->GMT, 'F', "Specify a rectangular panel behind the image", 1);
 	GMT_Message (API, GMT_TIME_NONE, "\t-Gb and -Gf (1-bit images only) sets the background and foreground color,\n");
 	GMT_Message (API, GMT_TIME_NONE, "\t   respectively. Set <color> = - for transparency [Default is black and white].\n");
 	GMT_Message (API, GMT_TIME_NONE, "\t-Gt (not for 1-bit images) indicate which color to be made transparent\n");
 	GMT_Message (API, GMT_TIME_NONE, "\t   [Default no transparency].\n");
 	GMT_Message (API, GMT_TIME_NONE, "\t-I Invert 1-bit images (does not affect 8 or 24-bit images).\n");
 	GMT_Option (API, "J-Z,K");
-	GMT_Message (API, GMT_TIME_NONE, "\t-M Force color -> monochrome image using GMT_YIQ-transformation.\n");
+	GMT_Message (API, GMT_TIME_NONE, "\t-M Force color -> monochrome image using gmt_M_yiq-transformation.\n");
 	GMT_Option (API, "O,P,R,U,V,X,c,p");
 	GMT_Message (API, GMT_TIME_NONE, "\t   (Requires -R and -J for proper functioning).\n");
 	GMT_Option (API, "t,.");
 
-	return (EXIT_FAILURE);
+	return (GMT_MODULE_USAGE);
 }
 
-int GMT_psimage_parse (struct GMT_CTRL *GMT, struct PSIMAGE_CTRL *Ctrl, struct GMT_OPTION *options)
-{
+GMT_LOCAL int parse (struct GMT_CTRL *GMT, struct PSIMAGE_CTRL *Ctrl, struct GMT_OPTION *options) {
 	/* This parses the options provided to psimage and sets parameters in Ctrl.
 	 * Note Ctrl has already been initialized and non-zero default values set.
 	 * Any GMT common options will override values set previously by other commands.
@@ -135,6 +133,7 @@ int GMT_psimage_parse (struct GMT_CTRL *GMT, struct PSIMAGE_CTRL *Ctrl, struct G
 
 	unsigned int n_errors = 0, n_files = 0;
 	int n;
+	bool p_fail = false;
 	char string[GMT_LEN256] = {""}, letter, *p = NULL;
 	char txt_a[GMT_LEN256] = {""}, txt_b[GMT_LEN256] = {""}, txt_c[4] = {""};
 	struct GMT_OPTION *opt = NULL;
@@ -144,7 +143,7 @@ int GMT_psimage_parse (struct GMT_CTRL *GMT, struct PSIMAGE_CTRL *Ctrl, struct G
 		switch (opt->option) {
 
 			case '<':	/* Input files */
-				if (n_files++ == 0 && GMT_check_filearg (GMT, '<', opt->arg, GMT_IN, GMT_IS_IMAGE))
+				if (n_files++ == 0 && gmt_check_filearg (GMT, '<', opt->arg, GMT_IN, GMT_IS_IMAGE))
 					Ctrl->In.file = strdup (opt->arg);
 				else
 					n_errors++;
@@ -160,33 +159,38 @@ int GMT_psimage_parse (struct GMT_CTRL *GMT, struct PSIMAGE_CTRL *Ctrl, struct G
 					strcat (string, "+j");
 					strcat (string, txt_c);
 				}
+				break;
 			case 'D':
 				Ctrl->D.active = true;
 				p = (string[0]) ? string : opt->arg;	/* If -C was used the string is set */
-				if ((Ctrl->D.refpoint = GMT_get_refpoint (GMT, p)) == NULL) n_errors++;	/* Failed basic parsing */
-				else {	/* args are now [+j<justify>][+o<off[GMT_X]>[/<dy>]][+n<nx>[/<ny>]][+r<dpi>] */
-					if (GMT_validate_modifiers (GMT, Ctrl->D.refpoint->args, 'D', "jnorw")) n_errors++;
+				if ((Ctrl->D.refpoint = gmt_get_refpoint (GMT, p)) == NULL) {	/* Failed basic parsing */
+					GMT_Report (GMT->parent, GMT_MSG_NORMAL, "Syntax error -D: Basic parsing of reference point in %s failed\n", opt->arg);
+					p_fail = true;
+					n_errors++;
+				}
+				else {	/* args are now [+j<justify>][+o<off[GMT_X]>[/<dy>]][+n<n_columns>[/<n_rows>]][+r<dpi>] */
+					if (gmt_validate_modifiers (GMT, Ctrl->D.refpoint->args, 'D', "jnorw")) n_errors++;
 					/* Required modifier +w OR +r */
-					if (GMT_get_modifier (Ctrl->D.refpoint->args, 'w', string)) {
-						if ((n = GMT_get_pair (GMT, string, GMT_PAIR_DIM_NODUP, Ctrl->D.dim)) < 0) n_errors++;
+					if (gmt_get_modifier (Ctrl->D.refpoint->args, 'w', string)) {
+						if ((n = gmt_get_pair (GMT, string, GMT_PAIR_DIM_NODUP, Ctrl->D.dim)) < 0) n_errors++;
 						if (Ctrl->D.dim[GMT_X] < 0.0) {	/* Negative width means PS interpolation */
 							Ctrl->D.dim[GMT_X] = -Ctrl->D.dim[GMT_X];
 							Ctrl->D.interpolate = true;
 						}
 					}
-					else if (GMT_get_modifier (Ctrl->D.refpoint->args, 'r', string))
+					else if (gmt_get_modifier (Ctrl->D.refpoint->args, 'r', string))
 						Ctrl->D.dpi = atof (string);
 					/* Optional modifiers +j, +n, +o */
-					if (GMT_get_modifier (Ctrl->D.refpoint->args, 'j', string))
-						Ctrl->D.justify = GMT_just_decode (GMT, string, PSL_NO_DEF);
+					if (gmt_get_modifier (Ctrl->D.refpoint->args, 'j', string))
+						Ctrl->D.justify = gmt_just_decode (GMT, string, PSL_NO_DEF);
 					else	/* With -Dj or -DJ, set default to reference (mirrored) justify point, else BL */
-						Ctrl->D.justify = GMT_just_default (GMT, Ctrl->D.refpoint, PSL_BL);
-					if (GMT_get_modifier (Ctrl->D.refpoint->args, 'n', string)) {
-						n = sscanf (string, "%d/%d", &Ctrl->D.nx, &Ctrl->D.ny);
-						if (n == 1) Ctrl->D.ny = Ctrl->D.nx;
+						Ctrl->D.justify = gmt_M_just_default (GMT, Ctrl->D.refpoint, PSL_BL);
+					if (gmt_get_modifier (Ctrl->D.refpoint->args, 'n', string)) {
+						n = sscanf (string, "%d/%d", &Ctrl->D.n_columns, &Ctrl->D.n_rows);
+						if (n == 1) Ctrl->D.n_rows = Ctrl->D.n_columns;
 					}
-					if (GMT_get_modifier (Ctrl->D.refpoint->args, 'o', string)) {
-						if ((n = GMT_get_pair (GMT, string, GMT_PAIR_DIM_DUP, Ctrl->D.off)) < 0) n_errors++;
+					if (gmt_get_modifier (Ctrl->D.refpoint->args, 'o', string)) {
+						if ((n = gmt_get_pair (GMT, string, GMT_PAIR_DIM_DUP, Ctrl->D.off)) < 0) n_errors++;
 					}
 				}
 				break;
@@ -198,25 +202,25 @@ int GMT_psimage_parse (struct GMT_CTRL *GMT, struct PSIMAGE_CTRL *Ctrl, struct G
 				break;
 			case 'F':	/* Specify frame pen */
 				Ctrl->F.active = true;
-				if (GMT_compat_check (GMT, 5) && opt->arg[0] != '+') /* Warn but process old -F<pen> */
+				if (gmt_M_compat_check (GMT, 5) && opt->arg[0] != '+') /* Warn but process old -F<pen> */
 					sprintf (string, "+c0+p%s", opt->arg);
 				else
-					strcpy (string, opt->arg);
-				if (GMT_getpanel (GMT, opt->option, string, &(Ctrl->F.panel))) {
-					GMT_mappanel_syntax (GMT, 'F', "Specify a rectangular panel behind the image", 1);
+					strncpy (string, opt->arg, GMT_LEN256-1);
+				if (gmt_getpanel (GMT, opt->option, string, &(Ctrl->F.panel))) {
+					gmt_mappanel_syntax (GMT, 'F', "Specify a rectangular panel behind the image", 1);
 					n_errors++;
 				}
 				break;
 			case 'G':	/* Background/foreground color for 1-bit images */
 				Ctrl->G.active = true;
-				letter = (GMT_colorname2index (GMT, opt->arg) >= 0) ? 'x' : opt->arg[0];	/* If we have -G<colorname>, the x is used to bypass the case f|b|t switching below */
+				letter = (gmt_colorname2index (GMT, opt->arg) >= 0) ? 'x' : opt->arg[0];	/* If we have -G<colorname>, the x is used to bypass the case f|b|t switching below */
 				switch (letter) {
 					case 'f':
 						/* Set color for foreground pixels */
 						if (opt->arg[1] == '-' && opt->arg[2] == '\0')
 							Ctrl->G.f_rgb[0] = -1;
-						else if (GMT_getrgb (GMT, &opt->arg[1], Ctrl->G.f_rgb)) {
-							GMT_rgb_syntax (GMT, 'G', " ");
+						else if (gmt_getrgb (GMT, &opt->arg[1], Ctrl->G.f_rgb)) {
+							gmt_rgb_syntax (GMT, 'G', " ");
 							n_errors++;
 						}
 						break;
@@ -224,23 +228,23 @@ int GMT_psimage_parse (struct GMT_CTRL *GMT, struct PSIMAGE_CTRL *Ctrl, struct G
 						/* Set color for background pixels */
 						if (opt->arg[1] == '-' && opt->arg[2] == '\0')
 							Ctrl->G.b_rgb[0] = -1;
-						else if (GMT_getrgb (GMT, &opt->arg[1], Ctrl->G.b_rgb)) {
-							GMT_rgb_syntax (GMT, 'G', " ");
+						else if (gmt_getrgb (GMT, &opt->arg[1], Ctrl->G.b_rgb)) {
+							gmt_rgb_syntax (GMT, 'G', " ");
 							n_errors++;
 						}
 						break;
 					case 't':
 						/* Set transparent color */
-						if (GMT_getrgb (GMT, &opt->arg[1], Ctrl->G.t_rgb)) {
-							GMT_rgb_syntax (GMT, 'G', " ");
+						if (gmt_getrgb (GMT, &opt->arg[1], Ctrl->G.t_rgb)) {
+							gmt_rgb_syntax (GMT, 'G', " ");
 							n_errors++;
 						}
 						break;
 					default:	/* Gave either -G<r/g/b>, -G-, or -G<colorname>; all treated as -Gf */
 						if (opt->arg[0] == '-' && opt->arg[1] == '\0')
 							Ctrl->G.f_rgb[0] = -1;
-						else if (GMT_getrgb (GMT, opt->arg, Ctrl->G.f_rgb)) {
-							GMT_rgb_syntax (GMT, 'G', " ");
+						else if (gmt_getrgb (GMT, opt->arg, Ctrl->G.f_rgb)) {
+							gmt_rgb_syntax (GMT, 'G', " ");
 							n_errors++;
 						}
 						break;
@@ -254,13 +258,13 @@ int GMT_psimage_parse (struct GMT_CTRL *GMT, struct PSIMAGE_CTRL *Ctrl, struct G
 				break;
 			case 'N':	/* Replicate image */
 				GMT_Report (GMT->parent, GMT_MSG_COMPAT, "Warning: -N option is deprecated; use -D modifier +n instead.\n");
-				n = sscanf (opt->arg, "%d/%d", &Ctrl->D.nx, &Ctrl->D.ny);
-				if (n == 1) Ctrl->D.ny = Ctrl->D.nx;
-				n_errors += GMT_check_condition (GMT, n < 1, "Syntax error -N option: Must give values for replication\n");
+				n = sscanf (opt->arg, "%d/%d", &Ctrl->D.n_columns, &Ctrl->D.n_rows);
+				if (n == 1) Ctrl->D.n_rows = Ctrl->D.n_columns;
+				n_errors += gmt_M_check_condition (GMT, n < 1, "Syntax error -N option: Must give values for replication\n");
 				break;
 			case 'W':	/* Image width */
 				GMT_Report (GMT->parent, GMT_MSG_COMPAT, "Warning: -W option is deprecated; use -D modifier +w instead.\n");
-				if ((n = GMT_get_pair (GMT, opt->arg, GMT_PAIR_DIM_NODUP, Ctrl->D.dim)) < 0) n_errors++;
+				if ((n = gmt_get_pair (GMT, opt->arg, GMT_PAIR_DIM_NODUP, Ctrl->D.dim)) < 0) n_errors++;
 				if (Ctrl->D.dim[GMT_X] < 0.0) {
 					Ctrl->D.dim[GMT_X] = -Ctrl->D.dim[GMT_X];
 					Ctrl->D.interpolate = true;
@@ -268,7 +272,7 @@ int GMT_psimage_parse (struct GMT_CTRL *GMT, struct PSIMAGE_CTRL *Ctrl, struct G
 				break;
 
 			default:	/* Report bad options */
-				n_errors += GMT_default_error (GMT, opt->option);
+				n_errors += gmt_default_error (GMT, opt->option);
 				break;
 		}
 	}
@@ -279,59 +283,59 @@ int GMT_psimage_parse (struct GMT_CTRL *GMT, struct PSIMAGE_CTRL *Ctrl, struct G
 	if (Ctrl->G.b_rgb[0] == -2) { Ctrl->G.b_rgb[0] = Ctrl->G.b_rgb[1] = Ctrl->G.b_rgb[2] = 1.0; }
 
 	if (!Ctrl->D.active) {	/* Old syntax without reference point implies -Dx0/0 */
-		Ctrl->D.refpoint = GMT_get_refpoint (GMT, "x0/0");	/* Default if no -D given */
+		Ctrl->D.refpoint = gmt_get_refpoint (GMT, "x0/0");	/* Default if no -D given */
 		Ctrl->D.active = true;
 	}
 	/* Check that the options selected are mutually consistent */
 
-	n_errors += GMT_check_condition (GMT, n_files != 1, "Syntax error: Must specify a single input raster or EPS file\n");
-	n_errors += GMT_check_condition (GMT, Ctrl->D.dim[GMT_X] <= 0.0 && Ctrl->D.dpi <= 0.0, "Syntax error -D option: Must specify image width (+w) or dpi (+e)\n");
-	n_errors += GMT_check_condition (GMT, Ctrl->D.nx < 1 || Ctrl->D.ny < 1,
+	n_errors += gmt_M_check_condition (GMT, n_files != 1, "Syntax error: Must specify a single input raster or EPS file\n");
+	n_errors += gmt_M_check_condition (GMT, !p_fail && Ctrl->D.dim[GMT_X] <= 0.0 && Ctrl->D.dpi <= 0.0, "Syntax error -D option: Must specify image width (+w) or dpi (+r)\n");
+	n_errors += gmt_M_check_condition (GMT, Ctrl->D.n_columns < 1 || Ctrl->D.n_rows < 1,
 			"Syntax error -D option: Must specify positive values for replication with +n\n");
-	n_errors += GMT_check_condition (GMT, Ctrl->G.f_rgb[0] < 0 && Ctrl->G.b_rgb[0] < 0,
+	n_errors += gmt_M_check_condition (GMT, Ctrl->G.f_rgb[0] < 0 && Ctrl->G.b_rgb[0] < 0,
 			"Syntax error -G option: Only one of fore/back-ground can be transparent for 1-bit images\n");
 
-	return (n_errors ? GMT_PARSE_ERROR : GMT_OK);
+	return (n_errors ? GMT_PARSE_ERROR : GMT_NOERROR);
 }
 
-int file_is_known (struct GMT_CTRL *GMT, char *file)
-{	/* Returns 1 if it is an EPS file, 2 if a Sun rasterfile; 0 for any other file.
+GMT_LOCAL int file_is_known (struct GMT_CTRL *GMT, char *file) {	/* Returns 1 if it is an EPS file, 2 if a Sun rasterfile; 0 for any other file.
        Returns -1 on read error */
 	FILE *fp = NULL;
 	unsigned char c[4], magic_ras[4] = {0x59, 0xa6, 0x6a, 0x95}, magic_ps[4] = {'%', '!', 'P', 'S'};
 	int j;
 
-	if (GMT_File_Is_Memory (file)) return (0);	/* Special passing of image */
+	if (gmt_M_file_is_memory (file)) return (0);	/* Special passing of image */
 	j = (int)strlen(file) - 1;
 	while (j && file[j] && file[j] != '+') j--;	/* See if we have a band request */
 	if (j && file[j+1] == 'b') file[j] = '\0';			/* Temporarily strip the band request string so that the opening test doesn't fail */
 
-	if ((fp = GMT_fopen (GMT, file, "rb")) == NULL) {
+	if ((fp = gmt_fopen (GMT, file, "rb")) == NULL) {
 		GMT_Report (GMT->parent, GMT_MSG_NORMAL, "Cannot open file %s\n", file);
 		return (-1);
 	}
-	if (GMT_fread (c, 1U, 4U, fp) != 4U) {
+	if (gmt_M_fread (c, 1U, 4U, fp) != 4U) {
 		GMT_Report (GMT->parent, GMT_MSG_NORMAL, "Could not read 4 bytes from file %s\n", file);
+		gmt_fclose (GMT, fp);
 		return (-1);
 	}
-	GMT_fclose (GMT, fp);
+	gmt_fclose (GMT, fp);
 	if (j) file[j] = '+';			/* Reset the band request string */
-	/* Note: cannot use GMT_same_rgb here, because that requires doubles */
+	/* Note: cannot use gmt_M_same_rgb here, because that requires doubles */
 	if (c[0] == magic_ps[0] && c[1] == magic_ps[1] && c[2] == magic_ps[2] && c[3] == magic_ps[3]) return(1);
 	if (c[0] == magic_ras[0] && c[1] == magic_ras[1] && c[2] == magic_ras[2] && c[3] == magic_ras[3]) return(2);
 	return (0);	/* Neither */
 }
 
-#define Return(code) {GMT_free (GMT, table); return (code);}
+#define Return(code) {gmt_M_free (GMT, table); return (code);}
 
-int find_unique_color (struct GMT_CTRL *GMT, unsigned char *rgba, size_t n, int *r, int *g, int *b)
-{
+#ifdef HAVE_GDAL
+GMT_LOCAL int find_unique_color (struct GMT_CTRL *GMT, unsigned char *rgba, size_t n, int *r, int *g, int *b) {
 	size_t i, j;
 	int idx;
 	bool trans = false;
 	unsigned char *table = NULL;
 
-	table = GMT_memory (GMT, NULL, 256*256*256, unsigned char);	/* Get table all initialized to zero */
+	table = gmt_M_memory (GMT, NULL, 256*256*256, unsigned char);	/* Get table all initialized to zero */
 
 	/* Check off all the non-transparent colors, store the transparent one */
 	*r = *g = *b = 0;
@@ -362,10 +366,13 @@ int find_unique_color (struct GMT_CTRL *GMT, unsigned char *rgba, size_t n, int
 	}
 	Return (3);
 }
+#endif
+
 #undef Return
 
-#define bailout(code) {GMT_Free_Options (mode); return (code);}
-#define Return(code) {Free_psimage_Ctrl (GMT, Ctrl); GMT_end_module (GMT, GMT_cpy); bailout (code);}
+#define bailout(code) {gmt_M_free_options (mode); return (code);}
+#define Return(code) {Free_Ctrl (GMT, Ctrl); gmt_end_module (GMT, GMT_cpy); bailout (code);}
+EXTERN_MSC unsigned char *psl_gray_encode (struct PSL_CTRL *PSL, int *nbytes, unsigned char *input);
 
 int GMT_psimage (void *V_API, int mode, void *args) {
 	int i, j, n, PS_interpolate = 1, PS_transparent = 1, known = 0, error = 0;
@@ -385,27 +392,27 @@ int GMT_psimage (void *V_API, int mode, void *args) {
 	struct GMT_OPTION *options = NULL;
 	struct PSL_CTRL *PSL = NULL;		/* General PSL interal parameters */
 #ifdef HAVE_GDAL
-	int k, r,g,b, has_trans = 0;
+	int k, r = 0, g = 0, b = 0, has_trans = 0;
 	unsigned char colormap[4*256];
 	struct GMT_IMAGE *I = NULL;		/* A GMT image datatype, if GDAL is used */
 #endif
-	struct GMTAPI_CTRL *API = GMT_get_API_ptr (V_API);	/* Cast from void to GMTAPI_CTRL pointer */
+	struct GMTAPI_CTRL *API = gmt_get_api_ptr (V_API);	/* Cast from void to GMTAPI_CTRL pointer */
 
 	/*----------------------- Standard module initialization and parsing ----------------------*/
 
 	if (API == NULL) return (GMT_NOT_A_SESSION);
-	if (mode == GMT_MODULE_PURPOSE) return (GMT_psimage_usage (API, GMT_MODULE_PURPOSE));	/* Return the purpose of program */
+	if (mode == GMT_MODULE_PURPOSE) return (usage (API, GMT_MODULE_PURPOSE));	/* Return the purpose of program */
 	options = GMT_Create_Options (API, mode, args);	if (API->error) return (API->error);	/* Set or get option list */
 
-	if (!options || options->option == GMT_OPT_USAGE) bailout (GMT_psimage_usage (API, GMT_USAGE));	/* Return the usage message */
-	if (options->option == GMT_OPT_SYNOPSIS) bailout (GMT_psimage_usage (API, GMT_SYNOPSIS));	/* Return the synopsis */
+	if (!options || options->option == GMT_OPT_USAGE) bailout (usage (API, GMT_USAGE));	/* Return the usage message */
+	if (options->option == GMT_OPT_SYNOPSIS) bailout (usage (API, GMT_SYNOPSIS));	/* Return the synopsis */
 
 	/* Parse the command-line arguments; return if errors are encountered */
 
-	GMT = GMT_begin_module (API, THIS_MODULE_LIB, THIS_MODULE_NAME, &GMT_cpy); /* Save current state */
+	GMT = gmt_begin_module (API, THIS_MODULE_LIB, THIS_MODULE_NAME, &GMT_cpy); /* Save current state */
 	if (GMT_Parse_Common (API, GMT_PROG_OPTIONS, options)) Return (API->error);
-	Ctrl = New_psimage_Ctrl (GMT);	/* Allocate and initialize a new control structure */
-	if ((error = GMT_psimage_parse (GMT, Ctrl, options)) != 0) Return (error);
+	Ctrl = New_Ctrl (GMT);	/* Allocate and initialize a new control structure */
+	if ((error = parse (GMT, Ctrl, options)) != 0) Return (error);
 
 	/*---------------------------- This is the psimage main code ----------------------------*/
 
@@ -414,39 +421,39 @@ int GMT_psimage (void *V_API, int mode, void *args) {
 	known = file_is_known (GMT, Ctrl->In.file);	/* Determine if this is an EPS file, Sun rasterfile, or other */
 	if (known < 0) {
 		GMT_Report (API, GMT_MSG_NORMAL, "Cannot find/open/read file %s\n", Ctrl->In.file);
-		Return (EXIT_FAILURE);
+		Return (GMT_RUNTIME_ERROR);
 	}
 
 	memset (&header, 0, sizeof(struct imageinfo)); /* initialize struct */
 	if (known) {	/* Read an EPS or Sun raster file */
 		GMT_Report (API, GMT_MSG_VERBOSE, "Processing input EPS or Sun rasterfile\n");
-		if (GMT_getdatapath (GMT, Ctrl->In.file, path, R_OK) == NULL) {
+		if (gmt_getdatapath (GMT, Ctrl->In.file, path, R_OK) == NULL) {
 			GMT_Report (API, GMT_MSG_NORMAL, "Cannot find/open file %s.\n", Ctrl->In.file);
-			Return (EXIT_FAILURE);
+			Return (GMT_FILE_NOT_FOUND);
 		}
 		if (PSL_loadimage (PSL, path, &header, &picture)) {
 			GMT_Report (API, GMT_MSG_NORMAL, "Trouble loading %s file %s!\n", format[known-1], path);
-			Return (EXIT_FAILURE);
+			Return (GMT_IMAGE_READ_ERROR);
 		}
 	}
 #ifdef HAVE_GDAL
 	else  {	/* Read a raster image */
 		GMT_Report (API, GMT_MSG_VERBOSE, "Processing input raster via GDAL\n");
-		GMT_set_pad (GMT, 0U);	/* Temporary turn off padding (and thus BC setting) since we will use image exactly as is */
+		gmt_set_pad (GMT, 0U);	/* Temporary turn off padding (and thus BC setting) since we will use image exactly as is */
 		if ((I = GMT_Read_Data (API, GMT_IS_IMAGE, GMT_IS_FILE, GMT_IS_SURFACE, GMT_GRID_ALL, NULL, Ctrl->In.file, NULL)) == NULL) {
 			Return (API->error);
 		}
-		GMT_set_pad (GMT, API->pad);	/* Reset to GMT default */
+		gmt_set_pad (GMT, API->pad);	/* Reset to GMT default */
 
 		/* Handle transparent images */
-		if (I->ColorMap != NULL) {	/* Image has a color map */
+		if (I->colormap != NULL) {	/* Image has a color map */
 			/* Convert colormap from integer to unsigned char and count colors */
-			for (n = 0; n < 4 * 256 && I->ColorMap[n] >= 0; n++) colormap[n] = (unsigned char)I->ColorMap[n];
+			for (n = 0; n < 4 * 256 && I->colormap[n] >= 0; n++) colormap[n] = (unsigned char)I->colormap[n];
 			n /= 4;
 			if (!Ctrl->G.active) has_trans = find_unique_color (GMT, colormap, n, &r, &g, &b);
 
 			/* Expand 8-bit indexed image to 24-bit image */
-			I->data = GMT_memory (GMT, I->data, 3 * I->header->nm, unsigned char);
+			I->data = gmt_M_memory (GMT, I->data, 3 * I->header->nm, unsigned char);
 			n = (int)(3 * I->header->nm - 1);
 			for (j = (int)I->header->nm - 1; j >= 0; j--) {
 				k = 4 * I->data[j] + 3;
@@ -477,14 +484,14 @@ int GMT_psimage (void *V_API, int mode, void *args) {
 		}
 
 		picture = (unsigned char *)I->data;
-		header.width = I->header->nx;
-		header.height = I->header->ny;
+		header.width = I->header->n_columns;
+		header.height = I->header->n_rows;
 		header.depth = (int)I->header->n_bands * 8;
 	}
 #else
 	else {	/* Without GDAL we can only read EPS and Sun raster */
 		GMT_Report (API, GMT_MSG_NORMAL, "Unsupported file format for file %s!\n", Ctrl->In.file);
-		Return (EXIT_FAILURE);
+		Return (GMT_RUNTIME_ERROR);
 	}
 #endif
 
@@ -496,7 +503,7 @@ int GMT_psimage (void *V_API, int mode, void *args) {
 		if (known) PSL_free (picture); /* EPS or Sun raster file */
 #ifdef HAVE_GDAL
 		else {	/* Got it via GMT_Read_Data */
-			if (GMT_Destroy_Data (API, &I) != GMT_OK) {
+			if (GMT_Destroy_Data (API, &I) != GMT_NOERROR) {
 				Return (API->error);
 			}
 		}
@@ -511,11 +518,11 @@ int GMT_psimage (void *V_API, int mode, void *args) {
 		PS_transparent = -1;
 		j = header.depth / 8;
 		n = j * (header.width * header.height + 1);
-		buffer = GMT_memory (GMT, NULL, n, unsigned char);
+		buffer = gmt_M_memory (GMT, NULL, n, unsigned char);
 		for (i = 0; i < j; i++) buffer[i] = (unsigned char)rint(255 * Ctrl->G.t_rgb[i]);
-		GMT_memcpy (&(buffer[j]), picture, n - j, unsigned char);
+		gmt_M_memcpy (&(buffer[j]), picture, n - j, unsigned char);
 #ifdef HAVE_GDAL
-		if (GMT_Destroy_Data (API, &I) != GMT_OK) {	/* If I is NULL then nothing is done */
+		if (GMT_Destroy_Data (API, &I) != GMT_NOERROR) {	/* If I is NULL then nothing is done */
 			Return (API->error);
 		}
 #else
@@ -532,43 +539,73 @@ int GMT_psimage (void *V_API, int mode, void *args) {
 
 	/* The following is needed to have psimage work correctly in perspective */
 
-	GMT_memset (wesn, 4, double);
+	gmt_M_memset (wesn, 4, double);
 	if (!(GMT->common.R.active && GMT->common.J.active)) {	/* When no projection specified, use fake linear projection */
 		GMT->common.R.active = true;
 		GMT->common.J.active = false;
-		GMT_parse_common_options (GMT, "J", 'J', "X1i");
-		GMT_adjust_refpoint (GMT, Ctrl->D.refpoint, Ctrl->D.dim, Ctrl->D.off, Ctrl->D.justify, PSL_BL);	/* Adjust refpoint to BL corner */
-		wesn[XHI] = Ctrl->D.refpoint->x + Ctrl->D.nx * Ctrl->D.dim[GMT_X];
-		wesn[YHI] = Ctrl->D.refpoint->y + Ctrl->D.ny * Ctrl->D.dim[GMT_Y];
-		if (GMT_err_pass (GMT, GMT_map_setup (GMT, wesn), "")) Return (GMT_PROJECTION_ERROR);
-		if ((PSL = GMT_plotinit (GMT, options)) == NULL) Return (GMT_RUNTIME_ERROR);
-		GMT_plane_perspective (GMT, GMT->current.proj.z_project.view_plane, GMT->current.proj.z_level);
+		gmt_parse_common_options (GMT, "J", 'J', "X1i");
+		gmt_adjust_refpoint (GMT, Ctrl->D.refpoint, Ctrl->D.dim, Ctrl->D.off, Ctrl->D.justify, PSL_BL);	/* Adjust refpoint to BL corner */
+		wesn[XHI] = Ctrl->D.refpoint->x + Ctrl->D.n_columns * Ctrl->D.dim[GMT_X];
+		wesn[YHI] = Ctrl->D.refpoint->y + Ctrl->D.n_rows * Ctrl->D.dim[GMT_Y];
+		if (gmt_M_err_pass (GMT, gmt_map_setup (GMT, wesn), "")) {
+			if (free_GMT)
+				gmt_M_free (GMT, picture);
+			else if (known || did_gray)
+				PSL_free (picture);
+			Return (GMT_PROJECTION_ERROR);
+		}
+		if ((PSL = gmt_plotinit (GMT, options)) == NULL) {
+			if (free_GMT)
+				gmt_M_free (GMT, picture);
+			else if (known || did_gray)
+				PSL_free (picture);
+			Return (GMT_RUNTIME_ERROR);
+		}
+		gmt_plane_perspective (GMT, GMT->current.proj.z_project.view_plane, GMT->current.proj.z_level);
 	}
 	else {	/* First use current projection, project, then use fake projection */
-		if (GMT_err_pass (GMT, GMT_map_setup (GMT, GMT->common.R.wesn), "")) Return (GMT_PROJECTION_ERROR);
-		GMT_set_refpoint (GMT, Ctrl->D.refpoint);	/* Finalize reference point plot coordinates, if needed */
-		GMT_adjust_refpoint (GMT, Ctrl->D.refpoint, Ctrl->D.dim, Ctrl->D.off, Ctrl->D.justify, PSL_BL);	/* Adjust refpoint to BL corner */
-		if ((PSL = GMT_plotinit (GMT, options)) == NULL) Return (GMT_RUNTIME_ERROR);
-		GMT_plane_perspective (GMT, GMT->current.proj.z_project.view_plane, GMT->current.proj.z_level);
-		GMT_plotcanvas (GMT);	/* Fill canvas if requested */
-		GMT_map_basemap (GMT);	/* Draw basemap if requested */
+		if (gmt_M_err_pass (GMT, gmt_map_setup (GMT, GMT->common.R.wesn), "")) {
+			if (free_GMT)
+				gmt_M_free (GMT, picture);
+			else if (known || did_gray)
+				PSL_free (picture);
+			Return (GMT_PROJECTION_ERROR);
+		}
+		gmt_set_refpoint (GMT, Ctrl->D.refpoint);	/* Finalize reference point plot coordinates, if needed */
+		gmt_adjust_refpoint (GMT, Ctrl->D.refpoint, Ctrl->D.dim, Ctrl->D.off, Ctrl->D.justify, PSL_BL);	/* Adjust refpoint to BL corner */
+		if ((PSL = gmt_plotinit (GMT, options)) == NULL) {
+			if (free_GMT)
+				gmt_M_free (GMT, picture);
+			else if (known || did_gray)
+				PSL_free (picture);
+			Return (GMT_RUNTIME_ERROR);
+		}
+		gmt_plane_perspective (GMT, GMT->current.proj.z_project.view_plane, GMT->current.proj.z_level);
+		gmt_plotcanvas (GMT);	/* Fill canvas if requested */
+		gmt_map_basemap (GMT);	/* Draw basemap if requested */
 		GMT->common.J.active = false;
-		GMT_parse_common_options (GMT, "J", 'J', "X1i");
-		wesn[XHI] = Ctrl->D.refpoint->x + Ctrl->D.nx * Ctrl->D.dim[GMT_X];
-		wesn[YHI] = Ctrl->D.refpoint->y + Ctrl->D.ny * Ctrl->D.dim[GMT_Y];
+		gmt_parse_common_options (GMT, "J", 'J', "X1i");
+		wesn[XHI] = Ctrl->D.refpoint->x + Ctrl->D.n_columns * Ctrl->D.dim[GMT_X];
+		wesn[YHI] = Ctrl->D.refpoint->y + Ctrl->D.n_rows * Ctrl->D.dim[GMT_Y];
 		GMT->common.R.active = GMT->common.J.active = true;
-		if (GMT_err_pass (GMT, GMT_map_setup (GMT, wesn), "")) Return (GMT_PROJECTION_ERROR);
+		if (gmt_M_err_pass (GMT, gmt_map_setup (GMT, wesn), "")) {
+			if (free_GMT)
+				gmt_M_free (GMT, picture);
+			else if (known || did_gray)
+				PSL_free (picture);
+			Return (GMT_PROJECTION_ERROR);
+		}
 	}
 
  	if (Ctrl->F.active) {	/* Draw frame, fill only */
-		Ctrl->F.panel->width = Ctrl->D.nx * Ctrl->D.dim[GMT_X];	Ctrl->F.panel->height = Ctrl->D.ny * Ctrl->D.dim[GMT_Y];
-		GMT_draw_map_panel (GMT, Ctrl->D.refpoint->x + 0.5 * Ctrl->F.panel->width, Ctrl->D.refpoint->y + 0.5 * Ctrl->F.panel->height, 1U, Ctrl->F.panel);
+		Ctrl->F.panel->width = Ctrl->D.n_columns * Ctrl->D.dim[GMT_X];	Ctrl->F.panel->height = Ctrl->D.n_rows * Ctrl->D.dim[GMT_Y];
+		gmt_draw_map_panel (GMT, Ctrl->D.refpoint->x + 0.5 * Ctrl->F.panel->width, Ctrl->D.refpoint->y + 0.5 * Ctrl->F.panel->height, 1U, Ctrl->F.panel);
  	}
 
-	for (row = 0; row < Ctrl->D.ny; row++) {
+	for (row = 0; row < Ctrl->D.n_rows; row++) {
 		y = Ctrl->D.refpoint->y + row * Ctrl->D.dim[GMT_Y];
-		if (Ctrl->D.ny > 1) GMT_Report (API, GMT_MSG_VERBOSE, "Replicating image %d times for row %d\n", Ctrl->D.nx, row);
-		for (col = 0; col < Ctrl->D.nx; col++) {
+		if (Ctrl->D.n_rows > 1) GMT_Report (API, GMT_MSG_VERBOSE, "Replicating image %d times for row %d\n", Ctrl->D.n_columns, row);
+		for (col = 0; col < Ctrl->D.n_columns; col++) {
 			x = Ctrl->D.refpoint->x + col * Ctrl->D.dim[GMT_X];
 			if (header.depth == 0)
 				PSL_plotepsimage (PSL, x, y, Ctrl->D.dim[GMT_X], Ctrl->D.dim[GMT_Y], PSL_BL, picture, &header);
@@ -587,21 +624,21 @@ int GMT_psimage (void *V_API, int mode, void *args) {
 		}
 	}
  	if (Ctrl->F.active)	/* Draw frame outlines */
-		GMT_draw_map_panel (GMT, Ctrl->D.refpoint->x + 0.5 * Ctrl->F.panel->width, Ctrl->D.refpoint->y + 0.5 * Ctrl->F.panel->height, 2U, Ctrl->F.panel);
+		gmt_draw_map_panel (GMT, Ctrl->D.refpoint->x + 0.5 * Ctrl->F.panel->width, Ctrl->D.refpoint->y + 0.5 * Ctrl->F.panel->height, 2U, Ctrl->F.panel);
 
-	GMT_plane_perspective (GMT, -1, 0.0);
-	GMT_plotend (GMT);
+	gmt_plane_perspective (GMT, -1, 0.0);
+	gmt_plotend (GMT);
 
 #ifdef HAVE_GDAL
-	if (I && GMT_Destroy_Data (API, &I) != GMT_OK) {
+	if (I && GMT_Destroy_Data (API, &I) != GMT_NOERROR) {
 		Return (API->error);	/* If I is NULL then nothing is done */
 	}
 #endif
 	if (free_GMT) {
-		GMT_free (GMT, picture);
+		gmt_M_free (GMT, picture);
 	}
 	else if (known || did_gray)
 		PSL_free (picture);
 
-	Return (GMT_OK);
+	Return (GMT_NOERROR);
 }
