@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: spectrum1d.c 15178 2015-11-06 10:45:03Z fwobbe $
+ *	$Id: spectrum1d.c 16835 2016-07-19 03:18:51Z pwessel $
  *
- *	Copyright (c) 1991-2015 by P. Wessel, W. H. F. Smith, R. Scharroo, J. Luis and F. Wobbe
+ *	Copyright (c) 1991-2016 by P. Wessel, W. H. F. Smith, R. Scharroo, J. Luis and F. Wobbe
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -38,8 +38,8 @@
 
 #define THIS_MODULE_NAME	"spectrum1d"
 #define THIS_MODULE_LIB		"core"
-#define THIS_MODULE_PURPOSE	"Compute auto- [and cross-] spectra from one [or two] timeseries"
-#define THIS_MODULE_KEYS	"<DI,>DO,T-o"
+#define THIS_MODULE_PURPOSE	"Compute auto- [and cross-] spectra from one [or two] time series"
+#define THIS_MODULE_KEYS	"<D{,>D},T-)"
 
 #include "gmt_dev.h"
 
@@ -83,7 +83,8 @@ struct SPECTRUM1D_CTRL {
 };
 
 struct SPECTRUM1D_INFO {	/* Control structure for spectrum1d */
-	int y_given, n_spec, window, window_2;
+	unsigned int y_given;
+	int n_spec, window, window_2;
 	float *datac;
 	double dt, x_variance, y_variance, d_n_windows, y_pow;
 	struct SPEC {
@@ -96,17 +97,15 @@ struct SPECTRUM1D_INFO {	/* Control structure for spectrum1d */
 	} *spec;
 };
 
-void alloc_arrays (struct GMT_CTRL *GMT, struct SPECTRUM1D_INFO *C)
-{
+GMT_LOCAL void alloc_arrays (struct GMT_CTRL *GMT, struct SPECTRUM1D_INFO *C) {
 	C->n_spec = C->window/2;	/* This means we skip zero frequency; data are detrended  */
 	C->window_2 = 2 * C->window;		/* This is for complex array stuff  */
 
-	C->spec = GMT_memory (GMT, NULL, C->n_spec, struct SPEC);
-	C->datac = GMT_memory (GMT, NULL, C->window_2, float);
+	C->spec = gmt_M_memory (GMT, NULL, C->n_spec, struct SPEC);
+	C->datac = gmt_M_memory (GMT, NULL, C->window_2, float);
 }
 
-void detrend_and_hanning (struct SPECTRUM1D_INFO *C, bool leave_trend, unsigned int mode)
-{
+GMT_LOCAL void detrend_and_hanning (struct SPECTRUM1D_INFO *C, bool leave_trend, unsigned int mode) {
 	/* If leave_trend is true we do not remove best-fitting LS trend.  Otherwise
 	 * we do, modulated by mode: 0: remove trend, 1: remove mean, 2: remove mid-value.
 	 * In all cases we apply the Hanning windowing */
@@ -179,8 +178,7 @@ void detrend_and_hanning (struct SPECTRUM1D_INFO *C, bool leave_trend, unsigned
 	}
 }
 
-int compute_spectra (struct GMT_CTRL *GMT, struct SPECTRUM1D_INFO *C, double *x, double *y, uint64_t n_data, bool leave_trend, unsigned int mode)
-{
+GMT_LOCAL int compute_spectra (struct GMT_CTRL *GMT, struct SPECTRUM1D_INFO *C, double *x, double *y, uint64_t n_data, bool leave_trend, unsigned int mode) {
 	int n_windows, w, i, t_start, t_stop, t, f;
 	double dw, spec_scale, x_varp, y_varp = 1.0, one_on_nw, co_quad;
 	double xreal, ximag, yreal, yimag, xpower, ypower, co_spec, quad_spec;
@@ -219,7 +217,7 @@ int compute_spectra (struct GMT_CTRL *GMT, struct SPECTRUM1D_INFO *C, double *x,
 		detrend_and_hanning (C, leave_trend, mode);
 
 		if (GMT_FFT_1D (GMT->parent, C->datac, C->window, GMT_FFT_FWD, GMT_FFT_COMPLEX))
-			return EXIT_FAILURE;
+			return GMT_RUNTIME_ERROR;
 
 		/* Get one-sided estimates */
 
@@ -259,7 +257,7 @@ int compute_spectra (struct GMT_CTRL *GMT, struct SPECTRUM1D_INFO *C, double *x,
 			x_varp *= (C->dt/C->n_spec);
 		}
 
-		if (GMT_is_verbose (GMT, GMT_MSG_VERBOSE)) {
+		if (gmt_M_is_verbose (GMT, GMT_MSG_VERBOSE)) {
 			C->y_pow = (C->y_given) ? C->y_variance/y_varp : 0.0;
 			GMT_Message (GMT->parent, GMT_TIME_NONE, "Window %d from %d to %d\n", w, t_start, t_stop);
 			sprintf(format, "X var: %s  X pow: %s  ratio: %s  Y var: %s  Y pow: %s  ratio: %s\n",
@@ -289,8 +287,8 @@ int compute_spectra (struct GMT_CTRL *GMT, struct SPECTRUM1D_INFO *C, double *x,
 	return 0;
 }
 
-int write_output_separate (struct GMT_CTRL *GMT, struct SPECTRUM1D_INFO *C, char *col, int n_outputs, int write_wavelength, char *namestem)
-{	/* Writes separate hardwired files for each output type.  Does NOT use GMT_Put_* functions */
+GMT_LOCAL int write_output_separate (struct GMT_CTRL *GMT, struct SPECTRUM1D_INFO *C, char *col, int n_outputs, int write_wavelength, char *namestem) {
+	/* Writes separate hardwired files for each output type.  Does NOT use GMT_Put_* functions */
 	int i, j;
 	double delta_f, eps_pow, out[3], *f_or_w = NULL;
 	char fname[GMT_LEN256] = {""};
@@ -299,7 +297,7 @@ int write_output_separate (struct GMT_CTRL *GMT, struct SPECTRUM1D_INFO *C, char
 	delta_f = 1.0 / (C->window * C->dt);
 	eps_pow = 1.0 / sqrt(C->d_n_windows);	/* Multiplicative error bars for power spectra  */
 
-	f_or_w = GMT_memory (GMT, NULL, C->n_spec, double);
+	f_or_w = gmt_M_memory (GMT, NULL, C->n_spec, double);
 	for (i = 0; i < C->n_spec; i++) f_or_w[i] = (write_wavelength) ? 1.0 / ((i + 1) * delta_f) : (i + 1) * delta_f;
 
 	/* loop through output choices */
@@ -307,9 +305,10 @@ int write_output_separate (struct GMT_CTRL *GMT, struct SPECTRUM1D_INFO *C, char
 		switch (col[j]) {
 		case 'x':		/* write x power [ B&P 2nd Ed. eqn. 9.32 ] */
 			sprintf (fname, "%s.xpower", namestem);
-			if ((fpout = GMT_fopen (GMT, fname, GMT->current.io.w_mode)) == NULL) {
+			if ((fpout = gmt_fopen (GMT, fname, GMT->current.io.w_mode)) == NULL) {
 				GMT_Report (GMT->parent, GMT_MSG_NORMAL, " Cannot open w %s\n", fname);
-				return (EXIT_FAILURE);
+				gmt_M_free (GMT, f_or_w);
+				return (GMT_ERROR_ON_FOPEN);
 			}
 			GMT_Report (GMT->parent, GMT_MSG_VERBOSE, " Writing %s\n", fname);
 			for (i = 0; i < C->n_spec; i++) {
@@ -318,14 +317,15 @@ int write_output_separate (struct GMT_CTRL *GMT, struct SPECTRUM1D_INFO *C, char
 				out[GMT_Z] = eps_pow * C->spec[i].xpow;
 				GMT->current.io.output (GMT, fpout, 3, out);
 			}
-			GMT_fclose (GMT, fpout);
+			gmt_fclose (GMT, fpout);
 			break;
 
 		case 'y':		/* Write y power [ B&P 2nd Ed. eqn. 9.32 ] */
 			sprintf (fname, "%s.ypower", namestem);
-			if ((fpout = GMT_fopen (GMT, fname, GMT->current.io.w_mode)) == NULL) {
+			if ((fpout = gmt_fopen (GMT, fname, GMT->current.io.w_mode)) == NULL) {
 				GMT_Report (GMT->parent, GMT_MSG_NORMAL, " Cannot open w %s\n", fname);
-				return (EXIT_FAILURE);
+				gmt_M_free (GMT, f_or_w);
+				return (GMT_ERROR_ON_FOPEN);
 			}
 			GMT_Report (GMT->parent, GMT_MSG_VERBOSE, " Writing %s\n", fname);
 			for (i = 0; i < C->n_spec; i++) {
@@ -334,13 +334,14 @@ int write_output_separate (struct GMT_CTRL *GMT, struct SPECTRUM1D_INFO *C, char
 				out[GMT_Z] = eps_pow * C->spec[i].ypow;
 				GMT->current.io.output (GMT, fpout, 3, out);
 			}
-			GMT_fclose (GMT, fpout);
+			gmt_fclose (GMT, fpout);
 			break;
 		case 'c':		/* Write Coherent Output power [ B&P 2nd Ed. eqn. 9.71 ] */
 			sprintf (fname, "%s.cpower", namestem);
-			if ((fpout = GMT_fopen (GMT, fname, GMT->current.io.w_mode)) == NULL) {
+			if ((fpout = gmt_fopen (GMT, fname, GMT->current.io.w_mode)) == NULL) {
 				GMT_Report (GMT->parent, GMT_MSG_NORMAL, " Cannot open w %s\n", fname);
-				return (EXIT_FAILURE);
+				gmt_M_free (GMT, f_or_w);
+				return (GMT_ERROR_ON_FOPEN);
 			}
 			GMT_Report (GMT->parent, GMT_MSG_VERBOSE, " Writing %s\n", fname);
 			for (i = 0; i < C->n_spec; i++) {
@@ -349,13 +350,14 @@ int write_output_separate (struct GMT_CTRL *GMT, struct SPECTRUM1D_INFO *C, char
 				out[GMT_Z] = out[GMT_Y] * eps_pow * sqrt ( (2.0 - C->spec[i].coh) / C->spec[i].coh);
 				GMT->current.io.output (GMT, fpout, 3, out);
 			}
-			GMT_fclose (GMT, fpout);
+			gmt_fclose (GMT, fpout);
 			break;
 		case 'n':		/* Write Noise Output power [ B&P 2nd Ed. eqn. 9.73 & Table 9.6 ] */
 			sprintf (fname, "%s.npower", namestem);
-			if ((fpout = GMT_fopen (GMT, fname, GMT->current.io.w_mode)) == NULL) {
+			if ((fpout = gmt_fopen (GMT, fname, GMT->current.io.w_mode)) == NULL) {
 				GMT_Report (GMT->parent, GMT_MSG_NORMAL, " Cannot open w %s\n", fname);
-				return (EXIT_FAILURE);
+				gmt_M_free (GMT, f_or_w);
+				return (GMT_ERROR_ON_FOPEN);
 			}
 			GMT_Report (GMT->parent, GMT_MSG_VERBOSE, " Writing %s\n", fname);
 			for (i = 0; i < C->n_spec; i++) {
@@ -364,13 +366,14 @@ int write_output_separate (struct GMT_CTRL *GMT, struct SPECTRUM1D_INFO *C, char
 				out[GMT_Z] = out[GMT_Y] * eps_pow;
 				GMT->current.io.output (GMT, fpout, 3, out);
 			}
-			GMT_fclose (GMT, fpout);
+			gmt_fclose (GMT, fpout);
 			break;
 		case 'g':		/* Write Gain spectrum [ B&P 2nd Ed. eqn. 9.90 & Table 9.6 ] */
 			sprintf (fname, "%s.gain", namestem);
-			if ((fpout = GMT_fopen (GMT, fname, GMT->current.io.w_mode)) == NULL) {
+			if ((fpout = gmt_fopen (GMT, fname, GMT->current.io.w_mode)) == NULL) {
 				GMT_Report (GMT->parent, GMT_MSG_NORMAL, " Cannot open w %s\n", fname);
-				return (EXIT_FAILURE);
+				gmt_M_free (GMT, f_or_w);
+				return (GMT_ERROR_ON_FOPEN);
 			}
 			GMT_Report (GMT->parent, GMT_MSG_VERBOSE, " Writing %s\n", fname);
 			for (i = 0; i < C->n_spec; i++) {
@@ -379,7 +382,7 @@ int write_output_separate (struct GMT_CTRL *GMT, struct SPECTRUM1D_INFO *C, char
 				out[GMT_Z] = out[GMT_Y] * eps_pow * sqrt( (1.0 - C->spec[i].coh) / (2.0 * C->spec[i].coh) );
 				GMT->current.io.output (GMT, fpout, 3, out);
 			}
-			GMT_fclose (GMT, fpout);
+			gmt_fclose (GMT, fpout);
 			break;
 		case 'a':		/* Write Real Admittance spectrum
 			We don't know the correct error estimate and it is not
@@ -391,9 +394,9 @@ int write_output_separate (struct GMT_CTRL *GMT, struct SPECTRUM1D_INFO *C, char
 			that for the gain spectrum:
 			*/
 			sprintf (fname, "%s.admit", namestem);
-			if ((fpout = GMT_fopen (GMT, fname, "w")) == NULL) {
+			if ((fpout = gmt_fopen (GMT, fname, "w")) == NULL) {
 				GMT_Report (GMT->parent, GMT_MSG_NORMAL, " Cannot open w %s\n", fname);
-				return (EXIT_FAILURE);
+				return (GMT_ERROR_ON_FOPEN);
 			}
 			GMT_Report (GMT->parent, GMT_MSG_VERBOSE, " Writing %s\n", fname);
 			for (i = 0; i < C->n_spec; i++) {
@@ -402,13 +405,14 @@ int write_output_separate (struct GMT_CTRL *GMT, struct SPECTRUM1D_INFO *C, char
 				out[GMT_Z] = fabs (eps_pow * sqrt( (1.0 - C->spec[i].coh) / (2.0 * C->spec[i].coh) ) * out[GMT_Y]);
 				GMT->current.io.output (GMT, fpout, 3, out);
 			}
-			GMT_fclose (GMT, fpout);
+			gmt_fclose (GMT, fpout);
 			break;
 		case 'p':		/* Write Phase spectrum [ B&P 2nd Ed. eqn. 9.91 & Table 9.6 ] */
 			sprintf (fname, "%s.phase", namestem);
-			if ((fpout = GMT_fopen (GMT, fname, GMT->current.io.w_mode)) == NULL) {
+			if ((fpout = gmt_fopen (GMT, fname, GMT->current.io.w_mode)) == NULL) {
 				GMT_Report (GMT->parent, GMT_MSG_NORMAL, " Cannot open w %s\n", fname);
-				return (EXIT_FAILURE);
+				gmt_M_free (GMT, f_or_w);
+				return (GMT_ERROR_ON_FOPEN);
 			}
 			GMT_Report (GMT->parent, GMT_MSG_VERBOSE, " Writing %s\n", fname);
 			for (i = 0; i < C->n_spec; i++) {
@@ -417,12 +421,14 @@ int write_output_separate (struct GMT_CTRL *GMT, struct SPECTRUM1D_INFO *C, char
 				out[GMT_Z] = eps_pow * sqrt( (1.0 - C->spec[i].coh) / (2.0 * C->spec[i].coh) );
 				GMT->current.io.output (GMT, fpout, 3, out);
 			}
-			GMT_fclose (GMT, fpout);
+			gmt_fclose (GMT, fpout);
+			break;
 		case 'o':		/* Write Coherency spectrum [ B&P 2nd Ed. eqn. 9.82 ] */
 			sprintf (fname, "%s.coh", namestem);
-			if ((fpout = GMT_fopen (GMT, fname, GMT->current.io.w_mode)) == NULL) {
+			if ((fpout = gmt_fopen (GMT, fname, GMT->current.io.w_mode)) == NULL) {
 				GMT_Report (GMT->parent, GMT_MSG_NORMAL, " Cannot open w %s\n", fname);
-				return (EXIT_FAILURE);
+				gmt_M_free (GMT, f_or_w);
+				return (GMT_ERROR_ON_FOPEN);
 			}
 			GMT_Report (GMT->parent, GMT_MSG_VERBOSE, " Writing %s\n", fname);
 			for (i = 0; i < C->n_spec; i++) {
@@ -431,24 +437,24 @@ int write_output_separate (struct GMT_CTRL *GMT, struct SPECTRUM1D_INFO *C, char
 				out[GMT_Z] = out[GMT_Y] * eps_pow * (1.0 - C->spec[i].coh) * sqrt(2.0 / C->spec[i].coh);
 				GMT->current.io.output (GMT, fpout, 3, out);
 			}
-			GMT_fclose (GMT, fpout);
+			gmt_fclose (GMT, fpout);
 			break;
 		}
 	}
 
-	GMT_free (GMT, f_or_w);
+	gmt_M_free (GMT, f_or_w);
 	return (0);
 }
 
-void assign_output_spectrum1d (struct GMT_CTRL *GMT, struct SPECTRUM1D_INFO *C, char *col, int n_outputs, int write_wavelength, double *out[])
-{	/* Fills out the 2-D table array given */
+GMT_LOCAL void assign_output_spectrum1d (struct GMT_CTRL *GMT, struct SPECTRUM1D_INFO *C, char *col, int n_outputs, int write_wavelength, double *out[]) {
+	/* Fills out the 2-D table array given */
 	int i, j, k;
 	double delta_f, eps_pow, tmp, *f_or_w;
 
 	delta_f = 1.0 / (C->window * C->dt);
 	eps_pow = 1.0 / sqrt(C->d_n_windows);	/* Multiplicative error bars for power spectra  */
 
-	f_or_w = GMT_memory (GMT, NULL, C->n_spec, double);
+	f_or_w = gmt_M_memory (GMT, NULL, C->n_spec, double);
 	for (i = 0; i < C->n_spec; i++) f_or_w[i] = (write_wavelength) ? 1.0 / ((i + 1) * delta_f) : (i + 1) * delta_f;
 
 	for (i = 0; i < C->n_spec; i++) {
@@ -500,19 +506,18 @@ void assign_output_spectrum1d (struct GMT_CTRL *GMT, struct SPECTRUM1D_INFO *C,
 		}
 	}
 	
-	GMT_free (GMT, f_or_w);
+	gmt_M_free (GMT, f_or_w);
 }
 
-void free_space_spectrum1d (struct GMT_CTRL *GMT, struct SPECTRUM1D_INFO *C)
-{
-	GMT_free (GMT, C->spec);
-	GMT_free (GMT, C->datac);
+GMT_LOCAL void free_space_spectrum1d (struct GMT_CTRL *GMT, struct SPECTRUM1D_INFO *C) {
+	gmt_M_free (GMT, C->spec);
+	gmt_M_free (GMT, C->datac);
 }
 
-void *New_spectrum1d_Ctrl (struct GMT_CTRL *GMT) {	/* Allocate and initialize a new control structure */
+GMT_LOCAL void *New_Ctrl (struct GMT_CTRL *GMT) {	/* Allocate and initialize a new control structure */
 	struct SPECTRUM1D_CTRL *C;
 	
-	C = GMT_memory (GMT, NULL, 1, struct SPECTRUM1D_CTRL);
+	C = gmt_M_memory (GMT, NULL, 1, struct SPECTRUM1D_CTRL);
 	
 	/* Initialize values whose defaults are not 0/false/NULL */
 	C->D.inc = 1.0;
@@ -528,20 +533,19 @@ void *New_spectrum1d_Ctrl (struct GMT_CTRL *GMT) {	/* Allocate and initialize a
 	return (C);
 }
 
-void Free_spectrum1d_Ctrl (struct GMT_CTRL *GMT, struct SPECTRUM1D_CTRL *C) {	/* Deallocate control structure */
+GMT_LOCAL void Free_Ctrl (struct GMT_CTRL *GMT, struct SPECTRUM1D_CTRL *C) {	/* Deallocate control structure */
 	if (!C) return;
-	if (C->N.name) free (C->N.name);	
-	GMT_free (GMT, C);	
+	gmt_M_str_free (C->N.name);	
+	gmt_M_free (GMT, C);	
 }
 
-int GMT_spectrum1d_usage (struct GMTAPI_CTRL *API, int level)
-{
-	GMT_show_name_and_purpose (API, THIS_MODULE_LIB, THIS_MODULE_NAME, THIS_MODULE_PURPOSE);
+GMT_LOCAL int usage (struct GMTAPI_CTRL *API, int level) {
+	gmt_show_name_and_purpose (API, THIS_MODULE_LIB, THIS_MODULE_NAME, THIS_MODULE_PURPOSE);
 	if (level == GMT_MODULE_PURPOSE) return (GMT_NOERROR);
 	GMT_Message (API, GMT_TIME_NONE, "usage: spectrum1d [<table>] -S<segment_size> [-C[<xycnpago>]] [-D<dt>] [-L[m|h]] [-N[<name_stem>]] [-T]\n");
 	GMT_Message (API, GMT_TIME_NONE, "\t[%s] [-W] [%s] [%s] [%s]\n\t[%s]\n\t[%s] [%s]\n\t[%s]\n\n", GMT_V_OPT, GMT_b_OPT, GMT_d_OPT, GMT_f_OPT, GMT_g_OPT, GMT_h_OPT, GMT_i_OPT, GMT_s_OPT);
 
-	if (level == GMT_SYNOPSIS) return (EXIT_FAILURE);
+	if (level == GMT_SYNOPSIS) return (GMT_MODULE_SYNOPSIS);
 
 	GMT_Message (API, GMT_TIME_NONE, "\t-S Use data subsets of <segment_size> elements.\n");
 	GMT_Message (API, GMT_TIME_NONE, "\t   <segment_size> must be radix 2;\n");
@@ -563,11 +567,10 @@ int GMT_spectrum1d_usage (struct GMTAPI_CTRL *API, int level)
 	GMT_Message (API, GMT_TIME_NONE, "\t-W Write Wavelength of spectral estimate in col 1 [Default = frequency].\n");
 	GMT_Option (API, "bi2,bo,d,f,g,h,i,s,.");
 	
-	return (EXIT_FAILURE);
+	return (GMT_MODULE_USAGE);
 }
 
-int GMT_spectrum1d_parse (struct GMT_CTRL *GMT, struct SPECTRUM1D_CTRL *Ctrl, struct GMT_OPTION *options)
-{
+GMT_LOCAL int parse (struct GMT_CTRL *GMT, struct SPECTRUM1D_CTRL *Ctrl, struct GMT_OPTION *options) {
 	/* This parses the options provided to spectrum1d and sets parameters in CTRL.
 	 * Any GMT common options will override values set previously by other commands.
 	 * It also replaces any file names specified as input or output with the data ID
@@ -583,11 +586,11 @@ int GMT_spectrum1d_parse (struct GMT_CTRL *GMT, struct SPECTRUM1D_CTRL *Ctrl, st
 		switch (opt->option) {
 
 			case '<':	/* Skip input files */
-				if (!GMT_check_filearg (GMT, '<', opt->arg, GMT_IN, GMT_IS_DATASET)) n_errors++;
+				if (!gmt_check_filearg (GMT, '<', opt->arg, GMT_IN, GMT_IS_DATASET)) n_errors++;
 				break;
 
 			case '>':	/* Got named output file */
-				if (n_files++ == 0 && GMT_check_filearg (GMT, '>', opt->arg, GMT_OUT, GMT_IS_DATASET))
+				if (n_files++ == 0 && gmt_check_filearg (GMT, '>', opt->arg, GMT_OUT, GMT_IS_DATASET))
 					Ctrl->Out.file = strdup (opt->arg);
 				else
 					n_errors++;
@@ -598,7 +601,7 @@ int GMT_spectrum1d_parse (struct GMT_CTRL *GMT, struct SPECTRUM1D_CTRL *Ctrl, st
 			case 'C':
 				Ctrl->C.active = true;
 				if (!opt->arg[0]) break;	/* Stay with the default order of output */
-				GMT_memset (Ctrl->C.col, SPECTRUM1D_N_OUTPUT_CHOICES, char);	/* Reset and read options */
+				gmt_M_memset (Ctrl->C.col, SPECTRUM1D_N_OUTPUT_CHOICES, char);	/* Reset and read options */
 				for (j = 0; opt->arg[j]; j++) {
 					if (j < SPECTRUM1D_N_OUTPUT_CHOICES) {
 						Ctrl->C.col[j] = opt->arg[j];
@@ -626,7 +629,7 @@ int GMT_spectrum1d_parse (struct GMT_CTRL *GMT, struct SPECTRUM1D_CTRL *Ctrl, st
 				Ctrl->N.active = true;
 				if (opt->arg[0]) {
 					if (opt->arg[0] == '+') {	/* Obsolete syntax */
-						if (GMT_compat_check (GMT, 5)) {
+						if (gmt_M_compat_check (GMT, 5)) {
 							GMT_Report (API, GMT_MSG_COMPAT, "Warning: Modifier -N+<file> is deprecated; use -N in the future to save to stdout.\n");
 							if (n_files++ == 0) Ctrl->Out.file = strdup (&opt->arg[1]);
 						}
@@ -636,7 +639,7 @@ int GMT_spectrum1d_parse (struct GMT_CTRL *GMT, struct SPECTRUM1D_CTRL *Ctrl, st
 						}
 					}
 					else {	/* Set name stem */
-						free (Ctrl->N.name);
+						gmt_M_str_free (Ctrl->N.name);
 						Ctrl->N.name = strdup (opt->arg);
 					}
 				}
@@ -646,7 +649,7 @@ int GMT_spectrum1d_parse (struct GMT_CTRL *GMT, struct SPECTRUM1D_CTRL *Ctrl, st
 			case 'S':
 				Ctrl->S.active = true;
 				sval = atoi (opt->arg);
-				n_errors += GMT_check_condition (GMT, sval <= 0, "Syntax error -S option: segment size must be positive\n");
+				n_errors += gmt_M_check_condition (GMT, sval <= 0, "Syntax error -S option: segment size must be positive\n");
 				Ctrl->S.size = sval;
 				while (window_test < Ctrl->S.size) {
 					window_test += window_test;
@@ -660,25 +663,24 @@ int GMT_spectrum1d_parse (struct GMT_CTRL *GMT, struct SPECTRUM1D_CTRL *Ctrl, st
 				break;
 
 			default:	/* Report bad options */
-				n_errors += GMT_default_error (GMT, opt->option);
+				n_errors += gmt_default_error (GMT, opt->option);
 				break;
 		}
 	}
 
-	n_errors += GMT_check_condition (GMT, window_test != Ctrl->S.size, "Syntax error -S option: Segment size not radix 2.  Try %d or %d\n", (window_test/2), window_test);
-	n_errors += GMT_check_condition (GMT, Ctrl->D.inc <= 0.0, "Syntax error -D option: Sampling interval must be positive\n");
-	n_errors += GMT_check_binary_io (GMT, Ctrl->C.active + 1);
-	n_errors += GMT_check_condition (GMT, n_files > 1, "Syntax error: Only one output destination can be specified\n");
-	n_errors += GMT_check_condition (GMT, Ctrl->N.mode == 1 && Ctrl->T.active, "Syntax error: Cannot use both -T and -N as no output would be produced\n");
+	n_errors += gmt_M_check_condition (GMT, window_test != Ctrl->S.size, "Syntax error -S option: Segment size not radix 2.  Try %d or %d\n", (window_test/2), window_test);
+	n_errors += gmt_M_check_condition (GMT, Ctrl->D.inc <= 0.0, "Syntax error -D option: Sampling interval must be positive\n");
+	n_errors += gmt_check_binary_io (GMT, Ctrl->C.active + 1);
+	n_errors += gmt_M_check_condition (GMT, n_files > 1, "Syntax error: Only one output destination can be specified\n");
+	n_errors += gmt_M_check_condition (GMT, Ctrl->N.mode == 1 && Ctrl->T.active, "Syntax error: Cannot use both -T and -N as no output would be produced\n");
 
-	return (n_errors ? GMT_PARSE_ERROR : GMT_OK);
+	return (n_errors ? GMT_PARSE_ERROR : GMT_NOERROR);
 }
 
-#define bailout(code) {GMT_Free_Options (mode); return (code);}
-#define Return(code) {Free_spectrum1d_Ctrl (GMT, Ctrl); GMT_end_module (GMT, GMT_cpy); bailout (code);}
+#define bailout(code) {gmt_M_free_options (mode); return (code);}
+#define Return(code) {Free_Ctrl (GMT, Ctrl); gmt_end_module (GMT, GMT_cpy); bailout (code);}
 
-int GMT_spectrum1d (void *V_API, int mode, void *args)
-{
+int GMT_spectrum1d (void *V_API, int mode, void *args) {
 	int error = 0;
 	unsigned int k, n_outputs;
 	
@@ -692,28 +694,28 @@ int GMT_spectrum1d (void *V_API, int mode, void *args)
 	struct SPECTRUM1D_CTRL *Ctrl = NULL;
 	struct GMT_CTRL *GMT = NULL, *GMT_cpy = NULL;
 	struct GMT_OPTION *options = NULL;
-	struct GMTAPI_CTRL *API = GMT_get_API_ptr (V_API);	/* Cast from void to GMTAPI_CTRL pointer */
+	struct GMTAPI_CTRL *API = gmt_get_api_ptr (V_API);	/* Cast from void to GMTAPI_CTRL pointer */
 
 	/*----------------------- Standard module initialization and parsing ----------------------*/
 
 	if (API == NULL) return (GMT_NOT_A_SESSION);
-	if (mode == GMT_MODULE_PURPOSE) return (GMT_spectrum1d_usage (API, GMT_MODULE_PURPOSE));	/* Return the purpose of program */
+	if (mode == GMT_MODULE_PURPOSE) return (usage (API, GMT_MODULE_PURPOSE));	/* Return the purpose of program */
 	options = GMT_Create_Options (API, mode, args);	if (API->error) return (API->error);	/* Set or get option list */
 
-	if (!options || options->option == GMT_OPT_USAGE) bailout (GMT_spectrum1d_usage (API, GMT_USAGE));/* Return the usage message */
-	if (options->option == GMT_OPT_SYNOPSIS) bailout (GMT_spectrum1d_usage (API, GMT_SYNOPSIS));	/* Return the synopsis */
+	if (!options || options->option == GMT_OPT_USAGE) bailout (usage (API, GMT_USAGE));/* Return the usage message */
+	if (options->option == GMT_OPT_SYNOPSIS) bailout (usage (API, GMT_SYNOPSIS));	/* Return the synopsis */
 
 	/* Parse the command-line arguments */
 
-	GMT = GMT_begin_module (API, THIS_MODULE_LIB, THIS_MODULE_NAME, &GMT_cpy); /* Save current state */
+	GMT = gmt_begin_module (API, THIS_MODULE_LIB, THIS_MODULE_NAME, &GMT_cpy); /* Save current state */
 	if (GMT_Parse_Common (API, GMT_PROG_OPTIONS, options)) Return (API->error);
-	Ctrl = New_spectrum1d_Ctrl (GMT);	/* Allocate and initialize a new control structure */
-	if ((error = GMT_spectrum1d_parse (GMT, Ctrl, options)) != 0) Return (error);
+	Ctrl = New_Ctrl (GMT);	/* Allocate and initialize a new control structure */
+	if ((error = parse (GMT, Ctrl, options)) != 0) Return (error);
 
 	/*---------------------------- This is the spectrum1d main code ----------------------------*/
 
 	GMT_Report (API, GMT_MSG_VERBOSE, "Processing input table data\n");
-	GMT_memset (&C, 1, struct SPECTRUM1D_INFO);
+	gmt_M_memset (&C, 1, struct SPECTRUM1D_INFO);
 	
 	C.dt = Ctrl->D.inc;
 	C.y_given = Ctrl->C.active;
@@ -726,15 +728,19 @@ int GMT_spectrum1d (void *V_API, int mode, void *args)
 		Ctrl->C.active = true;
 	}
 
-	if ((error = GMT_set_cols (GMT, GMT_IN, 1 + C.y_given)) != GMT_OK) {
+	if ((error = gmt_set_cols (GMT, GMT_IN, 1 + C.y_given)) != GMT_NOERROR) {
 		Return (error);
 	}
-	if (GMT_Init_IO (API, GMT_IS_DATASET, GMT_IS_NONE, GMT_IN, GMT_ADD_DEFAULT, 0, options) != GMT_OK) {	/* Establishes data input */
+	if (GMT_Init_IO (API, GMT_IS_DATASET, GMT_IS_NONE, GMT_IN, GMT_ADD_DEFAULT, 0, options) != GMT_NOERROR) {	/* Establishes data input */
 		Return (API->error);
 	}
 	if ((Din = GMT_Read_Data (API, GMT_IS_DATASET, GMT_IS_FILE, 0, GMT_READ_NORMAL, NULL, NULL, NULL)) == NULL) {
 		Return (API->error);
 	}
+	if (Din->n_columns < (1 + C.y_given)) {
+		GMT_Report (API, GMT_MSG_NORMAL, "Input data have %d column(s) but at least %d are needed\n", (int)Din->n_columns, 1 + C.y_given);
+		Return (GMT_DIM_TOO_SMALL);
+	}
 
 	alloc_arrays (GMT, &C);
 
@@ -750,35 +756,34 @@ int GMT_spectrum1d (void *V_API, int mode, void *args)
 	}
 	for (tbl = 0; tbl < Din->n_tables; tbl++) {
 		if (!Ctrl->T.active) {
-			GMT_free_table (GMT, Dout->table[tbl], Dout->alloc_mode);	/* Free it, then allocate separately */
-			Dout->table[tbl] = Tout = GMT_create_table (GMT, Din->table[tbl]->n_segments, C.n_spec, n_cols_tot, false);
+			gmt_free_table (GMT, Dout->table[tbl]);	/* Free it, then allocate separately */
+			Dout->table[tbl] = Tout = gmt_create_table (GMT, Din->table[tbl]->n_segments, C.n_spec, n_cols_tot, false);
 		}
 		for (seg = 0; seg < Din->table[tbl]->n_segments; seg++) {
 			S = Din->table[tbl]->segment[seg];	/* Current segment */
 			GMT_Report (API, GMT_MSG_VERBOSE, "Read %" PRIu64 " data points.\n", S->n_rows);
 
-			y = (C.y_given) ? S->coord[GMT_Y] : NULL;
-			if (compute_spectra (GMT, &C, S->coord[GMT_X], y, S->n_rows, Ctrl->L.active, Ctrl->L.mode)) {
-				GMT_exit (GMT, EXIT_FAILURE); return EXIT_FAILURE;
+			y = (C.y_given) ? S->data[GMT_Y] : NULL;
+			if (compute_spectra (GMT, &C, S->data[GMT_X], y, S->n_rows, Ctrl->L.active, Ctrl->L.mode)) {
+				GMT_exit (GMT, GMT_RUNTIME_ERROR); return GMT_RUNTIME_ERROR;
 			}
 
 			if (!Ctrl->T.active) {
-				Sout = Tout->segment[seg];	/* Current output segment */
-				GMT_alloc_segment (GMT, Sout, C.n_spec, Tout->n_columns, false);
-				assign_output_spectrum1d (GMT, &C, Ctrl->C.col, n_outputs, Ctrl->W.active, Sout->coord);
+				Sout = GMT_Alloc_Segment (GMT->parent, GMT_IS_DATASET, C.n_spec, Tout->n_columns, NULL, Tout->segment[seg]);
+				assign_output_spectrum1d (GMT, &C, Ctrl->C.col, n_outputs, Ctrl->W.active, Sout->data);
 			}
 			if (Ctrl->N.mode == 0) {	/* Write separate tables */
 				if (write_output_separate (GMT, &C, Ctrl->C.col, n_outputs, Ctrl->W.active, Ctrl->N.name))
-					Return (EXIT_FAILURE);
+					Return (GMT_RUNTIME_ERROR);
 			}
 		}
 	}
 	
 	free_space_spectrum1d (GMT, &C);
 	
-	if (!Ctrl->T.active && GMT_Write_Data (API, GMT_IS_DATASET, GMT_IS_FILE, GMT_IS_NONE, Dout->io_mode, NULL, Ctrl->Out.file, Dout) != GMT_OK) {
+	if (!Ctrl->T.active && GMT_Write_Data (API, GMT_IS_DATASET, GMT_IS_FILE, GMT_IS_NONE, Dout->io_mode, NULL, Ctrl->Out.file, Dout) != GMT_NOERROR) {
 		Return (API->error);
 	}
 
-	Return (GMT_OK);
+	Return (GMT_NOERROR);
 }
