@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *    $Id: sph2grd.c 15178 2015-11-06 10:45:03Z fwobbe $
+ *    $Id: sph2grd.c 16706 2016-07-04 02:52:44Z pwessel $
  *
- *	Copyright (c) 1991-2015 by P. Wessel, W. H. F. Smith, R. Scharroo, J. Luis and F. Wobbe
+ *	Copyright (c) 1991-2016 by P. Wessel, W. H. F. Smith, R. Scharroo, J. Luis and F. Wobbe
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -16,7 +16,7 @@
  *	Contact info: gmt.soest.hawaii.edu
  *--------------------------------------------------------------------*/
 /*
- * sph2grd evalutes a grid using a spherical harmonics model
+ * sph2grd evaluates a grid using a spherical harmonics model
  *
  * Author:	Paul Wessel
  * Date:	1-JUN-2013
@@ -25,7 +25,7 @@
 #define THIS_MODULE_NAME	"sph2grd"
 #define THIS_MODULE_LIB		"core"
 #define THIS_MODULE_PURPOSE	"Compute grid from spherical harmonic coefficients"
-#define THIS_MODULE_KEYS	"<DI,GGO,RG-"
+#define THIS_MODULE_KEYS	"<D{,GG}"
 
 #include "gmt_dev.h"
 
@@ -72,10 +72,10 @@ struct SPH2GRD_CTRL {	/* All control options for this program (except common arg
 	} Q;
 };
 
-void *New_sph2grd_Ctrl (struct GMT_CTRL *GMT) {	/* Allocate and initialize a new control structure */
+GMT_LOCAL void *New_Ctrl (struct GMT_CTRL *GMT) {	/* Allocate and initialize a new control structure */
 	struct SPH2GRD_CTRL *C = NULL;
 	
-	C = GMT_memory (GMT, NULL, 1, struct SPH2GRD_CTRL);
+	C = gmt_M_memory (GMT, NULL, 1, struct SPH2GRD_CTRL);
 	
 	/* Initialize values whose defaults are not 0/false/NULL */
 	C->F.hc = C->F.hp = DBL_MAX;	/* No high-cutting is the default */
@@ -86,21 +86,20 @@ void *New_sph2grd_Ctrl (struct GMT_CTRL *GMT) {	/* Allocate and initialize a new
 	return (C);
 }
 
-void Free_sph2grd_Ctrl (struct GMT_CTRL *GMT, struct SPH2GRD_CTRL *C) {	/* Deallocate control structure */
+GMT_LOCAL void Free_Ctrl (struct GMT_CTRL *GMT, struct SPH2GRD_CTRL *C) {	/* Deallocate control structure */
 	if (!C) return;
-	if (C->G.file) free (C->G.file);	
-	GMT_free (GMT, C);	
+	gmt_M_str_free (C->G.file);	
+	gmt_M_free (GMT, C);	
 }
 
-int GMT_sph2grd_usage (struct GMTAPI_CTRL *API, int level)
-{
-	GMT_show_name_and_purpose (API, THIS_MODULE_LIB, THIS_MODULE_NAME, THIS_MODULE_PURPOSE);
+GMT_LOCAL int usage (struct GMTAPI_CTRL *API, int level) {
+	gmt_show_name_and_purpose (API, THIS_MODULE_LIB, THIS_MODULE_NAME, THIS_MODULE_PURPOSE);
 	if (level == GMT_MODULE_PURPOSE) return (GMT_NOERROR);
 	GMT_Message (API, GMT_TIME_NONE, "usage: sph2grd [coeff_file] -G<grdfile> %s\n", GMT_I_OPT);
 	GMT_Message (API, GMT_TIME_NONE, "\t%s [-Dg|n] [-E] [-F[k]<filter>] [-N<norm>] [-Q]\n\t[%s] [%s]\n\t[%s] [%s]\n\t[%s] [%s]%s\n\n",
 		GMT_Rgeo_OPT, GMT_V_OPT, GMT_bi_OPT, GMT_h_OPT, GMT_i_OPT, GMT_r_OPT, GMT_s_OPT, GMT_x_OPT);
 
-	if (level == GMT_SYNOPSIS) return (EXIT_FAILURE);
+	if (level == GMT_SYNOPSIS) return (GMT_MODULE_SYNOPSIS);
 
 	GMT_Message (API, GMT_TIME_NONE, "\t-G filename for output grid file.\n");
 	GMT_Option (API, "I,Rg");
@@ -125,11 +124,10 @@ int GMT_sph2grd_usage (struct GMTAPI_CTRL *API, int level)
 	GMT_Message (API, GMT_TIME_NONE, "\t-Q Coefficients have phase convention from physics, i.e., the (-1)^m factor\n");
 	GMT_Option (API, "V,bi4,h,i,r,s,x,.");
 	
-	return (EXIT_FAILURE);
+	return (GMT_MODULE_USAGE);
 }
 
-int GMT_sph2grd_parse (struct GMT_CTRL *GMT, struct SPH2GRD_CTRL *Ctrl, struct GMT_OPTION *options)
-{
+GMT_LOCAL int parse (struct GMT_CTRL *GMT, struct SPH2GRD_CTRL *Ctrl, struct GMT_OPTION *options) {
 	/* This parses the options provided to sph2grd and sets parameters in CTRL.
 	 * Any GMT common options will override values set previously by other commands.
 	 * It also replaces any file names specified as input or output with the data ID
@@ -145,7 +143,7 @@ int GMT_sph2grd_parse (struct GMT_CTRL *GMT, struct SPH2GRD_CTRL *Ctrl, struct G
 		switch (opt->option) {
 
 			case '<':	/* Skip input files */
-				if (!GMT_check_filearg (GMT, '<', opt->arg, GMT_IN, GMT_IS_DATASET)) n_errors++;
+				if (!gmt_check_filearg (GMT, '<', opt->arg, GMT_IN, GMT_IS_DATASET)) n_errors++;
 				break;
 
 			/* Processes program-specific parameters */
@@ -182,15 +180,15 @@ int GMT_sph2grd_parse (struct GMT_CTRL *GMT, struct SPH2GRD_CTRL *Ctrl, struct G
 				}
 				break;
 			case 'G':
-				if ((Ctrl->G.active = GMT_check_filearg (GMT, 'G', opt->arg, GMT_OUT, GMT_IS_GRID)))
+				if ((Ctrl->G.active = gmt_check_filearg (GMT, 'G', opt->arg, GMT_OUT, GMT_IS_GRID)))
 					Ctrl->G.file = strdup (opt->arg);
 				else
 					n_errors++;
 				break;
 			case 'I':
 				Ctrl->I.active = true;
-				if (GMT_getinc (GMT, opt->arg, Ctrl->I.inc)) {
-					GMT_inc_syntax (GMT, 'I', 1);
+				if (gmt_getinc (GMT, opt->arg, Ctrl->I.inc)) {
+					gmt_inc_syntax (GMT, 'I', 1);
 					n_errors++;
 				}
 				break;
@@ -203,30 +201,29 @@ int GMT_sph2grd_parse (struct GMT_CTRL *GMT, struct SPH2GRD_CTRL *Ctrl, struct G
 				break;
 
 			default:	/* Report bad options */
-				n_errors += GMT_default_error (GMT, opt->option);
+				n_errors += gmt_default_error (GMT, opt->option);
 				break;
 		}
 	}
 
-	GMT_check_lattice (GMT, Ctrl->I.inc, &GMT->common.r.registration, &Ctrl->I.active);
+	gmt_check_lattice (GMT, Ctrl->I.inc, &GMT->common.r.registration, &Ctrl->I.active);
 
-	n_errors += GMT_check_condition (GMT, !GMT->common.R.active, "Syntax error: Must specify -R option\n");
-	n_errors += GMT_check_condition (GMT, !Ctrl->G.file, "Syntax error: Must specify output grid file\n");
-	n_errors += GMT_check_condition (GMT, Ctrl->D.active && !(Ctrl->D.mode == 'g' || Ctrl->D.mode == 'n'), "Syntax error -D option: Must append g or n\n");
-	n_errors += GMT_check_condition (GMT, strchr ("mgs", Ctrl->N.mode) == NULL, "Syntax error: -N Normalization must be one of m, g, or s\\n");
+	n_errors += gmt_M_check_condition (GMT, !GMT->common.R.active, "Syntax error: Must specify -R option\n");
+	n_errors += gmt_M_check_condition (GMT, !Ctrl->G.file, "Syntax error: Must specify output grid file\n");
+	n_errors += gmt_M_check_condition (GMT, Ctrl->D.active && !(Ctrl->D.mode == 'g' || Ctrl->D.mode == 'n'), "Syntax error -D option: Must append g or n\n");
+	n_errors += gmt_M_check_condition (GMT, strchr ("mgs", Ctrl->N.mode) == NULL, "Syntax error: -N Normalization must be one of m, g, or s\\n");
 
-	return (n_errors ? GMT_PARSE_ERROR : GMT_OK);
+	return (n_errors ? GMT_PARSE_ERROR : GMT_NOERROR);
 }
 
 #define LM_index(L,M) ((L)*((L)+1)/2+(M))	/* Index into the packed P_LM array given L, M */
 
-#define bailout(code) {GMT_Free_Options (mode); return (code);}
-#define Return(code) {Free_sph2grd_Ctrl (GMT, Ctrl); GMT_end_module (GMT, GMT_cpy); bailout (code);}
+#define bailout(code) {gmt_M_free_options (mode); return (code);}
+#define Return(code) {Free_Ctrl (GMT, Ctrl); gmt_end_module (GMT, GMT_cpy); bailout (code);}
 
-int GMT_sph2grd (void *V_API, int mode, void *args)
-{
+int GMT_sph2grd (void *V_API, int mode, void *args) {
 	bool ortho = false, duplicate_col;
-	int row, col, nx, error, L_sign = 1, L, L_min = 0, L_max = 0, M, M_max = 0, kk = 0;
+	int row, col, n_columns, error, L_sign = 1, L, L_min = 0, L_max = 0, M, M_max = 0, kk = 0;
 	unsigned int n_PLM, n_CS, n_CS_nx, next_10_percent = 10;
 	uint64_t tbl, seg, drow, node, k;
 	char text[GMT_LEN32] = {""};
@@ -239,40 +236,44 @@ int GMT_sph2grd (void *V_API, int mode, void *args)
 	struct SPH2GRD_CTRL *Ctrl = NULL;
 	struct GMT_CTRL *GMT = NULL, *GMT_cpy = NULL;
 	struct GMT_OPTION *options = NULL;
-	struct GMTAPI_CTRL *API = GMT_get_API_ptr (V_API);	/* Cast from void to GMTAPI_CTRL pointer */
+	struct GMTAPI_CTRL *API = gmt_get_api_ptr (V_API);	/* Cast from void to GMTAPI_CTRL pointer */
 
 	/*----------------------- Standard module initialization and parsing ----------------------*/
 
 	if (API == NULL) return (GMT_NOT_A_SESSION);
-	if (mode == GMT_MODULE_PURPOSE) return (GMT_sph2grd_usage (API, GMT_MODULE_PURPOSE));	/* Return the purpose of program */
+	if (mode == GMT_MODULE_PURPOSE) return (usage (API, GMT_MODULE_PURPOSE));	/* Return the purpose of program */
 	options = GMT_Create_Options (API, mode, args);	if (API->error) return (API->error);	/* Set or get option list */
 
-	if (!options || options->option == GMT_OPT_USAGE) bailout (GMT_sph2grd_usage (API, GMT_USAGE));/* Return the usage message */
-	if (options->option == GMT_OPT_SYNOPSIS) bailout (GMT_sph2grd_usage (API, GMT_SYNOPSIS));	/* Return the synopsis */
+	if (!options || options->option == GMT_OPT_USAGE) bailout (usage (API, GMT_USAGE));/* Return the usage message */
+	if (options->option == GMT_OPT_SYNOPSIS) bailout (usage (API, GMT_SYNOPSIS));	/* Return the synopsis */
 
 	/* Parse the command-line arguments */
 
-	GMT = GMT_begin_module (API, THIS_MODULE_LIB, THIS_MODULE_NAME, &GMT_cpy); /* Save current state */
+	GMT = gmt_begin_module (API, THIS_MODULE_LIB, THIS_MODULE_NAME, &GMT_cpy); /* Save current state */
 	if (GMT_Parse_Common (API, GMT_PROG_OPTIONS, options)) Return (API->error);
-	Ctrl = New_sph2grd_Ctrl (GMT);	/* Allocate and initialize a new control structure */
-	if ((error = GMT_sph2grd_parse (GMT, Ctrl, options)) != 0) Return (error);
+	Ctrl = New_Ctrl (GMT);	/* Allocate and initialize a new control structure */
+	if ((error = parse (GMT, Ctrl, options)) != 0) Return (error);
 	
 	/*---------------------------- This is the sph2grd main code ----------------------------*/
 
-	GMT_enable_threads (GMT);	/* Set number of active threads, if supported */
+	gmt_enable_threads (GMT);	/* Set number of active threads, if supported */
 	GMT_Report (API, GMT_MSG_VERBOSE, "Process input coefficients\n");
 	for (col = 0; col < 4; col++) GMT->current.io.col_type[GMT_IN][col] = GMT_IS_FLOAT;	/* Not reading lon,lat in this program */
 	
-	if ((error = GMT_set_cols (GMT, GMT_IN, 4)) != GMT_OK) {
+	if ((error = gmt_set_cols (GMT, GMT_IN, 4)) != GMT_NOERROR) {
 		Return (error);
 	}
-	if (GMT_Init_IO (API, GMT_IS_DATASET, GMT_IS_NONE, GMT_IN,  GMT_ADD_DEFAULT, 0, options) != GMT_OK) {	/* Establishes data input */
+	if (GMT_Init_IO (API, GMT_IS_DATASET, GMT_IS_NONE, GMT_IN,  GMT_ADD_DEFAULT, 0, options) != GMT_NOERROR) {	/* Establishes data input */
 		Return (API->error);
 	}
 	if ((D = GMT_Read_Data (API, GMT_IS_DATASET, GMT_IS_FILE, 0, GMT_READ_NORMAL, NULL, NULL, NULL)) == NULL) {
 		Return (API->error);
 	}
-	GMT_set_geographic (GMT, GMT_IN);	/* But x and y are really lon,lat in the rest of the program */
+	if (D->n_columns < 4) {
+		GMT_Report (API, GMT_MSG_NORMAL, "Input data have %d column(s) but at least 4 are needed\n", (int)D->n_columns);
+		Return (GMT_DIM_TOO_SMALL);
+	}
+	gmt_set_geographic (GMT, GMT_IN);	/* But x and y are really lon,lat in the rest of the program */
 	
 	if (Ctrl->F.active && Ctrl->F.km) {	/* Convert cutoffs to harmonic degrees */
 		double scale = 360.0 * GMT->current.proj.DIST_KM_PR_DEG;
@@ -287,8 +288,8 @@ int GMT_sph2grd (void *V_API, int mode, void *args)
 	for (tbl = 0; tbl < D->n_tables; tbl++) for (seg = 0; seg < D->table[tbl]->n_segments; seg++) {
 		T = D->table[tbl]->segment[seg];
 		for (drow = 0; drow < T->n_rows; drow++) {
-			L = irint (T->coord[0][drow]);
-			M = irint (T->coord[1][drow]);
+			L = irint (T->data[0][drow]);
+			M = irint (T->data[1][drow]);
 			if (L > L_max) L_max = L;
 			if (M > M_max) M_max = M;
 		}
@@ -296,7 +297,7 @@ int GMT_sph2grd (void *V_API, int mode, void *args)
 
 	if (M_max > L_max) {
 		GMT_Report (API, GMT_MSG_VERBOSE, "M_max = %d exceeds L_max = %d, wrong column order?\n", M_max, L_max);
-		Return (EXIT_FAILURE);
+		Return (GMT_RUNTIME_ERROR);
 	}
 	GMT_Report (API, GMT_MSG_VERBOSE, "Coefficient file has L_max = %d and M_max = %d\n", L_max, M_max);
 	
@@ -314,20 +315,20 @@ int GMT_sph2grd (void *V_API, int mode, void *args)
 	}
 	
 	/* Allocate C[L][M] and S[L][M] arrays to simplify accessing the coefficients in the big loop */
-	GMT_malloc2 (GMT, C, S, L_max + 1, NULL, double *);
-	for (L = 0; L <= L_max; L++) GMT_malloc2 (GMT, C[L], S[L], L_max + 1, NULL, double);
+	gmt_M_malloc2 (GMT, C, S, L_max + 1, NULL, double *);
+	for (L = 0; L <= L_max; L++) gmt_M_malloc2 (GMT, C[L], S[L], L_max + 1, NULL, double);
 
 	/* Place the coefficients into the C and S arrays and apply filtering, if selected */
 
 	for (tbl = 0; tbl < D->n_tables; tbl++) for (seg = 0; seg < D->table[tbl]->n_segments; seg++) {
 		T = D->table[tbl]->segment[seg];	/* Short-hand notation for current segment */
 		for (drow = 0; drow < T->n_rows; drow++) {
-			L = irint (T->coord[0][drow]);
+			L = irint (T->data[0][drow]);
 			if (L > L_max) continue;	/* Skip stuff beyond the high cut-off filter */
 			if (L < L_min) continue;	/* Skip stuff beyond the low cut-off filter */
-			M = irint (T->coord[1][drow]);
-			C[L][M]  = T->coord[2][drow];
-			S[L][M]  = T->coord[3][drow];
+			M = irint (T->data[1][drow]);
+			C[L][M]  = T->data[2][drow];
+			S[L][M]  = T->data[3][drow];
 			if (!Ctrl->F.active) continue;	/* No filtering selected */
 			if (Ctrl->F.mode == SPH2GRD_BANDPASS) {	/* Note: L_min/L_max have already taken care of the low-cut and high-cut */
 				if (L < Ctrl->F.lp)	/* Taper the low order components */
@@ -348,7 +349,7 @@ int GMT_sph2grd (void *V_API, int mode, void *args)
 	}
 
 	/* We are done with the input table; remove it to free up memory */
-	if (GMT_Destroy_Data (API, &D) != GMT_OK) {
+	if (GMT_Destroy_Data (API, &D) != GMT_NOERROR) {
 		Return (API->error);
 	}
 	
@@ -371,28 +372,28 @@ int GMT_sph2grd (void *V_API, int mode, void *args)
 
 	n_PLM = LM_index (L_max + 1, L_max + 1);	/* Number of P_lm terms needed */
 	n_CS = L_max + 1;				/* Number of Cos,Sin terms needed for each longitude */
-	n_CS_nx = n_CS * Grid->header->nx;		/* Number of Cos,Sin terms needed for all longitudes */
-	P_lm  = GMT_memory (GMT, NULL, n_PLM, double);
-	GMT_malloc2 (GMT, Cosmx, Sinmx, n_CS_nx, NULL, double);
-	GMT_malloc2 (GMT, Cosm,  Sinm,  Grid->header->nx, NULL, double *);
+	n_CS_nx = n_CS * Grid->header->n_columns;		/* Number of Cos,Sin terms needed for all longitudes */
+	P_lm  = gmt_M_memory (GMT, NULL, n_PLM, double);
+	gmt_M_malloc2 (GMT, Cosmx, Sinmx, n_CS_nx, NULL, double);
+	gmt_M_malloc2 (GMT, Cosm,  Sinm,  Grid->header->n_columns, NULL, double *);
 	
 	/* Evaluate longitude terms once and for all to avoid doing it repeatedly in the big loop.
 	 * We compute a matrix with rows representing order M and columns representing longitude.
 	 * Then, we allocate a set of pointers assigned to each row to enable 2-D indexing.*/
 
-	GMT_Report (API, GMT_MSG_VERBOSE, "Evaluate exp (i*m*lon) for all M [%d] and all lon [%u]\n", M_max+1, Grid->header->nx);
+	GMT_Report (API, GMT_MSG_VERBOSE, "Evaluate exp (i*m*lon) for all M [%d] and all lon [%u]\n", M_max+1, Grid->header->n_columns);
 	k = 0;
-	GMT_col_loop2 (GMT, Grid, col) {	/* Evaluate all sin, cos terms */
-		lon = GMT_grd_col_to_x (GMT, col, Grid->header);	/* Current longitude */
+	gmt_M_col_loop2 (GMT, Grid, col) {	/* Evaluate all sin, cos terms */
+		lon = gmt_M_grd_col_to_x (GMT, col, Grid->header);	/* Current longitude */
 		for (M = 0; M <= L_max; M++, k++) sincosd (lon * M, &Sinmx[k], &Cosmx[k]);
 	}
 	GMT_Report (API, GMT_MSG_DEBUG, "Array sizes: n_PLM = %u, n_CS = %u n_CS_nx = %u\n", n_PLM, n_CS, n_CS_nx);
-	GMT_col_loop2 (GMT, Grid, col) {	/* Assign pointers for 2-D indexing */
+	gmt_M_col_loop2 (GMT, Grid, col) {	/* Assign pointers for 2-D indexing */
 		k = col * (L_max + 1);	/* Start 1-D array index in Cosmx/Sinmx for this longitude */
 		Cosm[col] = &Cosmx[k];	/* Cosm[col][M] has cos(M*lon) terms for all lon[col], fixed M <= L_max */
 		Sinm[col] = &Sinmx[k];	/* Sinm[col][M] has sin(M*lon) terms for all lon[col], fixed M <= L_max */
 	}
-	if (GMT_is_verbose (GMT, GMT_MSG_LONG_VERBOSE)) {	/* Memory reporting */
+	if (gmt_M_is_verbose (GMT, GMT_MSG_LONG_VERBOSE)) {	/* Memory reporting */
 		unsigned int kind = 0;
 		size_t n_bytes = sizeof (struct GMT_GRID);
 		double mem;
@@ -402,15 +403,15 @@ int GMT_sph2grd (void *V_API, int mode, void *args)
 		n_bytes += 2 * (L_max + 1) * (L_max + 1) * sizeof (double);	/* C[] and S[] contents */
 		n_bytes += n_PLM * sizeof (double);				/* P_lm */
 		n_bytes += 2 * n_CS_nx * sizeof (double);			/* Sinmx and Cosmn */
-		n_bytes += 2 * Grid->header->nx * sizeof (double *);		/* Sinm and Cosm pointers */
+		n_bytes += 2 * Grid->header->n_columns * sizeof (double *);		/* Sinm and Cosm pointers */
 		
 		mem = n_bytes / 1024.0;	/* Report kbytes unless it is too much */
 		while (mem > 1024.0 && kind < 2) { mem /= 1024.0;	kind++; }	/* Goto next higher unit */
 		GMT_Report (API, GMT_MSG_LONG_VERBOSE, "Using a total of %.3g %cb for grid and all arrays.\n", mem, unit[kind]);
 	}
-	percent_inc = 100.0 / Grid->header->ny;	/* Percentage of whole grid represented by one row */
-	duplicate_col = (GMT_360_RANGE (Grid->header->wesn[XLO], Grid->header->wesn[XHI]) && Grid->header->registration == GMT_GRID_NODE_REG);	/* E.g., lon = 0 column should match lon = 360 column */
-	nx = (duplicate_col) ? Grid->header->nx - 1 : Grid->header->nx;
+	percent_inc = 100.0 / Grid->header->n_rows;	/* Percentage of whole grid represented by one row */
+	duplicate_col = (gmt_M_360_range (Grid->header->wesn[XLO], Grid->header->wesn[XHI]) && Grid->header->registration == GMT_GRID_NODE_REG);	/* E.g., lon = 0 column should match lon = 360 column */
+	n_columns = (duplicate_col) ? Grid->header->n_columns - 1 : Grid->header->n_columns;
 	
 	GMT_Report (API, GMT_MSG_VERBOSE, "Start evaluating the spherical harmonic series\n");
 	
@@ -421,23 +422,23 @@ int GMT_sph2grd (void *V_API, int mode, void *args)
 	 * the n_threads, split 10/n_treads into nearest integer.
 	 */
 	
-	GMT_row_loop (GMT, Grid, row) {					/* For each output latitude */
-		lat = GMT_grd_row_to_y (GMT, row, Grid->header);	/* Current latitude */
-		/* Compute all P_lm needed for this latitude at once via GMT_plm_bar_all */
-		GMT_plm_bar_all (GMT, L_sign * L_max, sind (lat), ortho, P_lm);	/* sind(lat) = cosine of colatitude */
-		if (GMT_is_verbose (GMT, GMT_MSG_LONG_VERBOSE)) {	/* Give user feedback on progress every 10 percent */
+	gmt_M_row_loop (GMT, Grid, row) {					/* For each output latitude */
+		lat = gmt_M_grd_row_to_y (GMT, row, Grid->header);	/* Current latitude */
+		/* Compute all P_lm needed for this latitude at once via gmt_plm_bar_all */
+		gmt_plm_bar_all (GMT, L_sign * L_max, sind (lat), ortho, P_lm);	/* sind(lat) = cosine of colatitude */
+		if (gmt_M_is_verbose (GMT, GMT_MSG_LONG_VERBOSE)) {	/* Give user feedback on progress every 10 percent */
 			percent += percent_inc;
 			if (percent > (double)next_10_percent) {
 				GMT_Report (API, GMT_MSG_LONG_VERBOSE, "Finished %3.3d %% of evaluation\n", next_10_percent);
 				next_10_percent = urint (ceil (percent / 10.0)) * 10;
 			}
-			GMT_ascii_format_col (GMT, text, lat, GMT_OUT, GMT_Y);
+			gmt_ascii_format_col (GMT, text, lat, GMT_OUT, GMT_Y);
 			GMT_Report (API, GMT_MSG_DEBUG, "Working on latitude: %s\n", text);
 		}
 #ifdef _OPENMP
-#pragma omp parallel for private(col,node,sum,kk,L,M) shared(Grid,row,nx,L_min,L_max,P_lm,C,Cosm,S,Sinm)
+#pragma omp parallel for private(col,node,sum,kk,L,M) shared(Grid,row,n_columns,L_min,L_max,P_lm,C,Cosm,S,Sinm)
 #endif
-		for (col = 0; col < nx; col++) {	/* For each longitude along this parallel */
+		for (col = 0; col < n_columns; col++) {	/* For each longitude along this parallel */
 			sum = 0.0;	/* Initialize sum to zero for new output node */
 			kk = (L_min) ? LM_index (L_min, 0) : 0;	/* Set start index for P_lm packed array */
 			for (L = L_min; L <= L_max; L++) {	/* For all degrees */
@@ -445,39 +446,40 @@ int GMT_sph2grd (void *V_API, int mode, void *args)
 					sum += P_lm[kk] * (C[L][M] * Cosm[col][M] + S[L][M] * Sinm[col][M]);
 				}
 			}
-			node = GMT_IJP (Grid->header, row, col);
+			node = gmt_M_ijp (Grid->header, row, col);
 			Grid->data[node] = (float)sum;	/* Assign total to the grid, cast as float */
 		}
 	}
 	if (duplicate_col) {	/* Just copy over what we found on the western boundary to the repeated eastern boundary */
 		uint64_t node_L, node_R;
-		GMT_row_loop (GMT, Grid, row) {	/* For each output latitude */
-			node_L = GMT_IJP (Grid->header, row, 0);	/* West */
-			node_R = node_L + Grid->header->nx - 1;		/* East */
+		gmt_M_row_loop (GMT, Grid, row) {	/* For each output latitude */
+			node_L = gmt_M_ijp (Grid->header, row, 0);	/* West */
+			node_R = node_L + Grid->header->n_columns - 1;		/* East */
 			Grid->data[node_R] = Grid->data[node_L];
 		}
 	}
 	GMT_Report (API, GMT_MSG_LONG_VERBOSE, "Finished 100 %% of evaluation\n");
 	
 	GMT_Report (API, GMT_MSG_VERBOSE, "Write grid to file\n");
-	if (GMT_Write_Data (API, GMT_IS_GRID, GMT_IS_FILE, GMT_IS_SURFACE, GMT_GRID_ALL, NULL, Ctrl->G.file, Grid) != GMT_OK) {
-		Return (API->error);
-	}
+	if (GMT_Write_Data (API, GMT_IS_GRID, GMT_IS_FILE, GMT_IS_SURFACE, GMT_GRID_ALL, NULL, Ctrl->G.file, Grid) != GMT_NOERROR)
+		error = API->error;
+	else
+		error = 0;
 	
 	/* Clear up by freeing memory */
 	
-	GMT_free (GMT, P_lm);
-	GMT_free (GMT, Cosm);
-	GMT_free (GMT, Sinm);
-	GMT_free (GMT, Cosmx);
-	GMT_free (GMT, Sinmx);
+	gmt_M_free (GMT, P_lm);
+	gmt_M_free (GMT, Cosm);
+	gmt_M_free (GMT, Sinm);
+	gmt_M_free (GMT, Cosmx);
+	gmt_M_free (GMT, Sinmx);
 	for (L = 0; L <= L_max; L++) {
-		GMT_free (GMT, C[L]);
-		GMT_free (GMT, S[L]);
+		gmt_M_free (GMT, C[L]);
+		gmt_M_free (GMT, S[L]);
 	}
-	GMT_free (GMT, C);
-	GMT_free (GMT, S);
+	gmt_M_free (GMT, C);
+	gmt_M_free (GMT, S);
 	
 	GMT_Report (API, GMT_MSG_VERBOSE, "Completed\n");
-	Return (EXIT_SUCCESS);
+	Return ((error) ? error : EXIT_SUCCESS);
 }
