@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: sphdistance.c 15186 2015-11-06 21:01:51Z pwessel $
+ *	$Id: sphdistance.c 16895 2016-08-12 02:52:43Z pwessel $
  *
- *	Copyright (c) 2008-2015 by P. Wessel, W. H. F. Smith, R. Scharroo, J. Luis and F. Wobbe
+ *	Copyright (c) 2008-2016 by P. Wessel, W. H. F. Smith, R. Scharroo, J. Luis and F. Wobbe
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -38,7 +38,7 @@
 #define THIS_MODULE_NAME	"sphdistance"
 #define THIS_MODULE_LIB		"core"
 #define THIS_MODULE_PURPOSE	"Create Voronoi distance, node, or nearest-neighbor grid on a sphere"
-#define THIS_MODULE_KEYS	"<DI,NDi,QDi,GGO,RG-,Q-i"
+#define THIS_MODULE_KEYS	"<D{,ND(,QD(,GG},Q-("
 
 #include "gmt_dev.h"
 #include "gmt_sph.h"
@@ -86,24 +86,23 @@ struct SPHDISTANCE_CTRL {
 	} Q;
 };
 
-void prepare_polygon (struct GMT_CTRL *GMT, struct GMT_DATASEGMENT *P)
-{
+GMT_LOCAL void prepare_polygon (struct GMT_CTRL *GMT, struct GMT_DATASEGMENT *P) {
 	/* Set the min/max extent of this polygon and determine if it
 	 * is a polar cap; if so set the required metadata flags */
 	uint64_t row;
 	double lon_sum = 0.0, lat_sum = 0.0, dlon;
 
-	GMT_set_seg_minmax (GMT, P);	/* Set the domain of the segment */
+	gmt_set_seg_minmax (GMT, P);	/* Set the domain of the segment */
 
 	/* Then loop over points to accumulate sums */
 
 	for (row = 1; row < P->n_rows; row++) {	/* Start at row = 1 since (a) 0'th point is repeated at end and (b) we are doing differences */
-		GMT_set_delta_lon (P->coord[GMT_X][row-1], P->coord[GMT_X][row], dlon);
+		gmt_M_set_delta_lon (P->data[GMT_X][row-1], P->data[GMT_X][row], dlon);
 		lon_sum += dlon;
-		lat_sum += P->coord[GMT_Y][row];
+		lat_sum += P->data[GMT_Y][row];
 	}
 	P->pole = 0;
-	if (GMT_360_RANGE (lon_sum, 0.0)) {	/* Contains a pole */
+	if (gmt_M_360_range (lon_sum, 0.0)) {	/* Contains a pole */
 		if (lat_sum < 0.0) { /* S */
 			P->pole = -1;
 			P->lat_limit = P->min[GMT_Y];
@@ -119,32 +118,32 @@ void prepare_polygon (struct GMT_CTRL *GMT, struct GMT_DATASEGMENT *P)
 	}
 }
 
-void *New_sphdistance_Ctrl (struct GMT_CTRL *GMT) {	/* Allocate and initialize a new control structure */
+GMT_LOCAL void *New_Ctrl (struct GMT_CTRL *GMT) {	/* Allocate and initialize a new control structure */
 	struct SPHDISTANCE_CTRL *C;
 
-	C = GMT_memory (GMT, NULL, 1, struct SPHDISTANCE_CTRL);
+	C = gmt_M_memory (GMT, NULL, 1, struct SPHDISTANCE_CTRL);
 	C->E.dist = 1.0;	/* Default is 1 degree Voronoi edge resampling */
 	C->L.unit = 'e';	/* Default is meter distances */
 	return (C);
 }
 
-void Free_sphdistance_Ctrl (struct GMT_CTRL *GMT, struct SPHDISTANCE_CTRL *C) {	/* Deallocate control structure */
+GMT_LOCAL void Free_Ctrl (struct GMT_CTRL *GMT, struct SPHDISTANCE_CTRL *C) {	/* Deallocate control structure */
 	if (!C) return;
-	if (C->G.file) free (C->G.file);
-	if (C->N.file) free (C->N.file);
-	if (C->Q.file) free (C->Q.file);
-	GMT_free (GMT, C);
+	gmt_M_str_free (C->G.file);
+	gmt_M_str_free (C->N.file);
+	gmt_M_str_free (C->Q.file);
+	gmt_M_free (GMT, C);
 }
 
-int GMT_sphdistance_usage (struct GMTAPI_CTRL *API, int level) {
-	GMT_show_name_and_purpose (API, THIS_MODULE_LIB, THIS_MODULE_NAME, THIS_MODULE_PURPOSE);
+GMT_LOCAL int usage (struct GMTAPI_CTRL *API, int level) {
+	gmt_show_name_and_purpose (API, THIS_MODULE_LIB, THIS_MODULE_NAME, THIS_MODULE_PURPOSE);
 	if (level == GMT_MODULE_PURPOSE) return (GMT_NOERROR);
 	GMT_Message (API, GMT_TIME_NONE, "==> The hard work is done by algorithms 772 (STRIPACK) & 773 (SSRFPACK) by R. J. Renka [1997] <==\n\n");
 	GMT_Message (API, GMT_TIME_NONE, "usage: sphdistance [<table>] -G<outgrid> %s [-C] [-En|z|d[<dr>]]\n", GMT_I_OPT);
-	GMT_Message (API, GMT_TIME_NONE, "\t[-L<unit>] [-N<nodetable>] [-Q<voronoitable>] [%s] [%s] [%s]\n", GMT_V_OPT, GMT_bi_OPT, GMT_di_OPT);
+	GMT_Message (API, GMT_TIME_NONE, "\t[-L<unit>] [-N<nodetable>] [-Q<voronoitable>] [%s] [%s] [%s] [%s]\n", GMT_Rgeo_OPT, GMT_V_OPT, GMT_bi_OPT, GMT_di_OPT);
 	GMT_Message (API, GMT_TIME_NONE, "\t[%s] [%s]\n\t[%s] [%s] [%s]\n\n", GMT_h_OPT, GMT_i_OPT, GMT_r_OPT, GMT_s_OPT, GMT_colon_OPT);
 
-	if (level == GMT_SYNOPSIS) return (EXIT_FAILURE);
+	if (level == GMT_SYNOPSIS) return (GMT_MODULE_SYNOPSIS);
 
 	GMT_Message (API, GMT_TIME_NONE, "\t-G Specify file name for output distance grid file.\n");
 	GMT_Option (API, "I");
@@ -161,7 +160,7 @@ int GMT_sphdistance_usage (struct GMTAPI_CTRL *API, int level) {
 	GMT_Message (API, GMT_TIME_NONE, "\t   -Ez The z-value of the Voronoi center node (NN gridding).\n");
 	GMT_Message (API, GMT_TIME_NONE, "\t   -Ed The distance to the nearest data point [Default].\n");
 	GMT_Message (API, GMT_TIME_NONE, "\t   Optionally append resampling interval in spherical degrees for polygon arcs [1].\n");
-	GMT_Message (API, GMT_TIME_NONE, "\t-L Set distance unit arc (d)egree, m(e)ter, (f)eet, (k)m, arc (m)inute, (M)ile, (n)autical mile,\n\tor arc (s)econd [e].\n");
+	GMT_Message (API, GMT_TIME_NONE, "\t-L Set distance unit arc (d)egree, m(e)ter, (f)eet, (k)m, arc (m)inute, (M)ile, (n)autical mile,\n\t   or arc (s)econd [e].\n");
 	GMT_Message (API, GMT_TIME_NONE, "\t   PROJ_ELLIPSOID determines if geodesic or great-circle distances are used.\n");
 	GMT_Message (API, GMT_TIME_NONE, "\t-N Specify node filename for the Voronoi polygons (sphtriangulate -N output).\n");
 	GMT_Message (API, GMT_TIME_NONE, "\t-Q Specify table with Voronoi polygons in sphtriangulate -Qv format\n");
@@ -170,10 +169,10 @@ int GMT_sphdistance_usage (struct GMTAPI_CTRL *API, int level) {
 	GMT_Message (API, GMT_TIME_NONE, "\t   If no region is specified we default to the entire world [-Rg].\n");
 	GMT_Option (API, "V,bi2,di,h,i,r,s,:,.");
 
-	return (EXIT_FAILURE);
+	return (GMT_MODULE_USAGE);
 }
 
-int GMT_sphdistance_parse (struct GMT_CTRL *GMT, struct SPHDISTANCE_CTRL *Ctrl, struct GMT_OPTION *options) {
+GMT_LOCAL int parse (struct GMT_CTRL *GMT, struct SPHDISTANCE_CTRL *Ctrl, struct GMT_OPTION *options) {
 	/* This parses the options provided to sphdistance and sets parameters in CTRL.
 	 * Any GMT common options will override values set previously by other commands.
 	 * It also replaces any file names specified as input or output with the data ID
@@ -188,7 +187,7 @@ int GMT_sphdistance_parse (struct GMT_CTRL *GMT, struct SPHDISTANCE_CTRL *Ctrl,
 		switch (opt->option) {
 
 			case '<':	/* Skip input files */
-				if (!GMT_check_filearg (GMT, '<', opt->arg, GMT_IN, GMT_IS_DATASET)) n_errors++;
+				if (!gmt_check_filearg (GMT, '<', opt->arg, GMT_IN, GMT_IS_DATASET)) n_errors++;
 				break;
 
 			/* Processes program-specific parameters */
@@ -197,10 +196,10 @@ int GMT_sphdistance_parse (struct GMT_CTRL *GMT, struct SPHDISTANCE_CTRL *Ctrl,
 				Ctrl->C.active = true;
 				break;
 			case 'D':
-				if (GMT_compat_check (GMT, 4))
+				if (gmt_M_compat_check (GMT, 4))
 					GMT_Report (API, GMT_MSG_COMPAT, "Warning: -D option is deprecated; duplicates are automatically removed.\n");
 				else
-					n_errors += GMT_default_error (GMT, opt->option);
+					n_errors += gmt_default_error (GMT, opt->option);
 				break;
 			case 'E':
 				Ctrl->E.active = true;
@@ -213,15 +212,15 @@ int GMT_sphdistance_parse (struct GMT_CTRL *GMT, struct SPHDISTANCE_CTRL *Ctrl,
 				if (opt->arg[k]) Ctrl->E.dist = atof (&opt->arg[k]);
 				break;
 			case 'G':
-				if ((Ctrl->G.active = GMT_check_filearg (GMT, 'G', opt->arg, GMT_OUT, GMT_IS_GRID)) != 0)
+				if ((Ctrl->G.active = gmt_check_filearg (GMT, 'G', opt->arg, GMT_OUT, GMT_IS_GRID)) != 0)
 					Ctrl->G.file = strdup (opt->arg);
 				else
 					n_errors++;
 				break;
 			case 'I':
 				Ctrl->I.active = true;
-				if (GMT_getinc (GMT, opt->arg, Ctrl->I.inc)) {
-					GMT_inc_syntax (GMT, 'I', 1);
+				if (gmt_getinc (GMT, opt->arg, Ctrl->I.inc)) {
+					gmt_inc_syntax (GMT, 'I', 1);
 					n_errors++;
 				}
 				break;
@@ -243,25 +242,25 @@ int GMT_sphdistance_parse (struct GMT_CTRL *GMT, struct SPHDISTANCE_CTRL *Ctrl,
 				Ctrl->Q.file = strdup (opt->arg);
 				break;
 			default:	/* Report bad options */
-				n_errors += GMT_default_error (GMT, opt->option);
+				n_errors += gmt_default_error (GMT, opt->option);
 				break;
 		}
 	}
 
-	GMT_check_lattice (GMT, Ctrl->I.inc, &GMT->common.r.registration, &Ctrl->I.active);
+	gmt_check_lattice (GMT, Ctrl->I.inc, &GMT->common.r.registration, &Ctrl->I.active);
 
 	if (GMT->common.b.active[GMT_IN] && GMT->common.b.ncol[GMT_IN] == 0) GMT->common.b.ncol[GMT_IN] = 3;
-	n_errors += GMT_check_condition (GMT, GMT->common.b.active[GMT_IN] && GMT->common.b.ncol[GMT_IN] < 3, "Syntax error: Binary input data (-bi) must have at least 3 columns\n");
-	n_errors += GMT_check_condition (GMT, Ctrl->I.inc[GMT_X] <= 0.0 || Ctrl->I.inc[GMT_Y] <= 0.0, "Syntax error -I option: Must specify positive increment(s)\n");
-	n_errors += GMT_check_condition (GMT, Ctrl->Q.active && GMT->common.b.active[GMT_IN] && !Ctrl->N.active, "Syntax error: Binary input data (-bi) with -Q also requires -N.\n");
-	n_errors += GMT_check_condition (GMT, Ctrl->I.inc[GMT_X] <= 0.0 || Ctrl->I.inc[GMT_Y] <= 0.0, "Syntax error -I option: Must specify positive increment(s)\n");
-	n_errors += GMT_check_condition (GMT, !Ctrl->G.file, "Syntax error -G: Must specify output file\n");
+	n_errors += gmt_M_check_condition (GMT, GMT->common.b.active[GMT_IN] && GMT->common.b.ncol[GMT_IN] < 3, "Syntax error: Binary input data (-bi) must have at least 3 columns\n");
+	n_errors += gmt_M_check_condition (GMT, Ctrl->I.inc[GMT_X] <= 0.0 || Ctrl->I.inc[GMT_Y] <= 0.0, "Syntax error -I option: Must specify positive increment(s)\n");
+	n_errors += gmt_M_check_condition (GMT, Ctrl->Q.active && GMT->common.b.active[GMT_IN] && !Ctrl->N.active, "Syntax error: Binary input data (-bi) with -Q also requires -N.\n");
+	n_errors += gmt_M_check_condition (GMT, Ctrl->I.inc[GMT_X] <= 0.0 || Ctrl->I.inc[GMT_Y] <= 0.0, "Syntax error -I option: Must specify positive increment(s)\n");
+	n_errors += gmt_M_check_condition (GMT, !Ctrl->G.file, "Syntax error -G: Must specify output file\n");
 
-	return (n_errors ? GMT_PARSE_ERROR : GMT_OK);
+	return (n_errors ? GMT_PARSE_ERROR : GMT_NOERROR);
 }
 
-#define bailout(code) {GMT_Free_Options (mode); return (code);}
-#define Return(code) {Free_sphdistance_Ctrl (GMT, Ctrl); GMT_end_module (GMT, GMT_cpy); bailout (code);}
+#define bailout(code) {gmt_M_free_options (mode); return (code);}
+#define Return(code) {Free_Ctrl (GMT, Ctrl); gmt_end_module (GMT, GMT_cpy); bailout (code);}
 
 int GMT_sphdistance (void *V_API, int mode, void *args) {
 	bool first = false, periodic, duplicate_col;
@@ -288,30 +287,30 @@ int GMT_sphdistance (void *V_API, int mode, void *args) {
 	struct STRIPACK_VORONOI *V = NULL;
 	struct GMT_CTRL *GMT = NULL, *GMT_cpy = NULL;
 	struct GMT_OPTION *options = NULL;
-	struct GMTAPI_CTRL *API = GMT_get_API_ptr (V_API);	/* Cast from void to GMTAPI_CTRL pointer */
+	struct GMTAPI_CTRL *API = gmt_get_api_ptr (V_API);	/* Cast from void to GMTAPI_CTRL pointer */
 
 	/*----------------------- Standard module initialization and parsing ----------------------*/
 
 	if (API == NULL) return (GMT_NOT_A_SESSION);
-	if (mode == GMT_MODULE_PURPOSE) return (GMT_sphdistance_usage (API, GMT_MODULE_PURPOSE));	/* Return the purpose of program */
+	if (mode == GMT_MODULE_PURPOSE) return (usage (API, GMT_MODULE_PURPOSE));	/* Return the purpose of program */
 	options = GMT_Create_Options (API, mode, args);	if (API->error) return (API->error);	/* Set or get option list */
 
-	if (!options || options->option == GMT_OPT_USAGE) bailout (GMT_sphdistance_usage (API, GMT_USAGE));/* Return the usage message */
-	if (options->option == GMT_OPT_SYNOPSIS) bailout (GMT_sphdistance_usage (API, GMT_SYNOPSIS));	/* Return the synopsis */
+	if (!options || options->option == GMT_OPT_USAGE) bailout (usage (API, GMT_USAGE));/* Return the usage message */
+	if (options->option == GMT_OPT_SYNOPSIS) bailout (usage (API, GMT_SYNOPSIS));	/* Return the synopsis */
 
 	/* Parse the command-line arguments */
 
-	GMT = GMT_begin_module (API, THIS_MODULE_LIB, THIS_MODULE_NAME, &GMT_cpy); /* Save current state */
-	GMT_parse_common_options (GMT, "f", 'f', "g"); /* Implicitly set -fg since this is spherical triangulation */
+	GMT = gmt_begin_module (API, THIS_MODULE_LIB, THIS_MODULE_NAME, &GMT_cpy); /* Save current state */
+	gmt_parse_common_options (GMT, "f", 'f', "g"); /* Implicitly set -fg since this is spherical triangulation */
 	if (GMT_Parse_Common (API, GMT_PROG_OPTIONS, options)) Return (API->error);
-	Ctrl = New_sphdistance_Ctrl (GMT);	/* Allocate and initialize a new control structure */
-	if ((error = GMT_sphdistance_parse (GMT, Ctrl, options)) != 0) Return (error);
+	Ctrl = New_Ctrl (GMT);	/* Allocate and initialize a new control structure */
+	if ((error = parse (GMT, Ctrl, options)) != 0) Return (error);
 
 	/*---------------------------- This is the sphdistance main code ----------------------------*/
 
-	GMT_memset (&T, 1, struct STRIPACK);
+	gmt_M_memset (&T, 1, struct STRIPACK);
 
-	GMT_init_distaz (GMT, Ctrl->L.unit, GMT_sph_mode (GMT), GMT_MAP_DIST);
+	gmt_init_distaz (GMT, Ctrl->L.unit, gmt_M_sph_mode (GMT), GMT_MAP_DIST);
 
 	if (!GMT->common.R.active) {	/* Default to a global grid */
 		GMT->common.R.wesn[XLO] = 0.0;	GMT->common.R.wesn[XHI] = 360.0;	GMT->common.R.wesn[YLO] = -90.0;	GMT->common.R.wesn[YHI] = 90.0;
@@ -321,23 +320,35 @@ int GMT_sphdistance (void *V_API, int mode, void *args) {
 
 	if (Ctrl->Q.active) {	/* Expect a single file with Voronoi polygons */
 		GMT_Report (API, GMT_MSG_VERBOSE, "Read Volonoi polygons from %s ...", Ctrl->Q.file);
+		gmt_disable_i_opt (GMT);	/* Do not want any -i to affect the reading from -Q files */
 		if ((Qin = GMT_Read_Data (API, GMT_IS_DATASET, GMT_IS_FILE, GMT_IS_POLY, GMT_READ_NORMAL, NULL, Ctrl->Q.file, NULL)) == NULL) {
 			Return (API->error);
 		}
+		if (Qin->n_columns < 2) {
+			GMT_Report (API, GMT_MSG_NORMAL, "Input file %s has %d column(s) but at least 2 are needed\n", Ctrl->Q.file, (int)Qin->n_columns);
+			Return (GMT_DIM_TOO_SMALL);
+		}
+		gmt_reenable_i_opt (GMT);	/* Recover settings provided by user (if -i was used at all) */
 		Table = Qin->table[0];	/* Only one table in a file */
 		GMT_Report (API, GMT_MSG_VERBOSE, "Found %" PRIu64 " segments\n", Table->n_segments);
-	 	lon = GMT_memory (GMT, NULL, Table->n_segments, double);
-	 	lat = GMT_memory (GMT, NULL, Table->n_segments, double);
+	 	lon = gmt_M_memory (GMT, NULL, Table->n_segments, double);
+	 	lat = gmt_M_memory (GMT, NULL, Table->n_segments, double);
 		if (Ctrl->N.active) {	/* Must get nodes from separate file */
 			struct GMT_DATASET *Nin = NULL;
 			struct GMT_DATATABLE *NTable = NULL;
-			if ((error = GMT_set_cols (GMT, GMT_IN, 3)) != GMT_OK) {
+			if ((error = gmt_set_cols (GMT, GMT_IN, 3)) != GMT_NOERROR) {
 				Return (error);
 			}
 			GMT_Report (API, GMT_MSG_VERBOSE, "Read Nodes from %s ...", Ctrl->N.file);
+			gmt_disable_i_opt (GMT);	/* Do not want any -i to affect the reading from -N files */
 			if ((Nin = GMT_Read_Data (API, GMT_IS_DATASET, GMT_IS_FILE, GMT_IS_POINT, GMT_READ_NORMAL, NULL, Ctrl->N.file, NULL)) == NULL) {
 				Return (API->error);
 			}
+			if (Nin->n_columns < 2) {
+				GMT_Report (API, GMT_MSG_NORMAL, "Input file %s has %d column(s) but at least 2 are needed\n", Ctrl->N.file, (int)Nin->n_columns);
+				Return (GMT_DIM_TOO_SMALL);
+			}
+			gmt_reenable_i_opt (GMT);	/* Recover settings provided by user (if -i was used at all) */
 			NTable = Nin->table[0];	/* Only one table in a file with a single segment */
 			if (NTable->n_segments != 1) {
 				GMT_Report (API, GMT_MSG_NORMAL, "File %s can only have 1 segment!\n", Ctrl->N.file);
@@ -347,9 +358,9 @@ int GMT_sphdistance (void *V_API, int mode, void *args) {
 				GMT_Report (API, GMT_MSG_NORMAL, "Files %s and %s do not have same number of items!\n", Ctrl->Q.file, Ctrl->N.file);
 				Return (GMT_RUNTIME_ERROR);
 			}
-			GMT_memcpy (lon, NTable->segment[0]->coord[GMT_X], NTable->n_records, double);
-			GMT_memcpy (lat, NTable->segment[0]->coord[GMT_Y], NTable->n_records, double);
-			if (GMT_Destroy_Data (API, &Nin) != GMT_OK) {
+			gmt_M_memcpy (lon, NTable->segment[0]->data[GMT_X], NTable->n_records, double);
+			gmt_M_memcpy (lat, NTable->segment[0]->data[GMT_Y], NTable->n_records, double);
+			if (GMT_Destroy_Data (API, &Nin) != GMT_NOERROR) {
 				Return (API->error);
 			}
 			GMT_Report (API, GMT_MSG_VERBOSE, "Found %" PRIu64 " records\n", NTable->n_records);
@@ -369,40 +380,40 @@ int GMT_sphdistance (void *V_API, int mode, void *args) {
 	}
 	else {	/* Must process input point/line data */
 		n_in = (Ctrl->E.mode == SPHD_VALUES) ? 3 : 2;
-		if ((error = GMT_set_cols (GMT, GMT_IN, n_in)) != GMT_OK) {
+		if ((error = gmt_set_cols (GMT, GMT_IN, n_in)) != GMT_NOERROR) {
 			Return (error);
 		}
-		if (GMT_Init_IO (API, GMT_IS_DATASET, GMT_IS_POINT, GMT_IN, GMT_ADD_DEFAULT, 0, options) != GMT_OK) {	/* Registers default input sources, unless already set */
+		if (GMT_Init_IO (API, GMT_IS_DATASET, GMT_IS_POINT, GMT_IN, GMT_ADD_DEFAULT, 0, options) != GMT_NOERROR) {	/* Registers default input sources, unless already set */
 			Return (API->error);
 		}
-		if (GMT_Begin_IO (API, GMT_IS_DATASET, GMT_IN, GMT_HEADER_ON) != GMT_OK) {
+		if (GMT_Begin_IO (API, GMT_IS_DATASET, GMT_IN, GMT_HEADER_ON) != GMT_NOERROR) {
 			Return (API->error);	/* Enables data input and sets access mode */
 		}
 
 		GMT->session.min_meminc = GMT_INITIAL_MEM_ROW_ALLOC;	/* Start by allocating a 32 Mb chunk */ 
 
 		n_alloc = 0;
-		if (!Ctrl->C.active) GMT_malloc2 (GMT, lon, lat, 0, &n_alloc, double);
+		if (!Ctrl->C.active) gmt_M_malloc2 (GMT, lon, lat, 0, &n_alloc, double);
 		n_alloc = 0;
-		GMT_malloc3 (GMT, xx, yy, zz, 0, &n_alloc, double);
-		if (Ctrl->E.mode == SPHD_VALUES) z_val = GMT_memory (GMT, NULL, n_alloc, float);
+		gmt_M_malloc3 (GMT, xx, yy, zz, 0, &n_alloc, double);
+		if (Ctrl->E.mode == SPHD_VALUES) z_val = gmt_M_memory (GMT, NULL, n_alloc, float);
 
 		n = 0;
 		do {	/* Keep returning records until we reach EOF */
 			if ((in = GMT_Get_Record (API, GMT_READ_DOUBLE, NULL)) == NULL) {	/* Read next record, get NULL if special case */
-				if (GMT_REC_IS_ERROR (GMT)) 		/* Bail if there are any read errors */
+				if (gmt_M_rec_is_error (GMT)) 		/* Bail if there are any read errors */
 					Return (GMT_RUNTIME_ERROR);
-				if (GMT_REC_IS_TABLE_HEADER (GMT)) 	/* Skip all table headers */
+				if (gmt_M_rec_is_table_header (GMT)) 	/* Skip all table headers */
 					continue;
-				if (GMT_REC_IS_EOF (GMT)) 		/* Reached end of file */
+				if (gmt_M_rec_is_eof (GMT)) 		/* Reached end of file */
 					break;
-				else if (GMT_REC_IS_SEGMENT_HEADER (GMT)) {			/* Parse segment headers */
+				else if (gmt_M_rec_is_segment_header (GMT)) {			/* Parse segment headers */
 					first = true;
 					continue;
 				}
 			}
 
-			/* Data record to process - avoid duplicate points as stripack_lists cannot handle that */
+			/* Data record to process - avoid duplicate points as gmt_stripack_lists cannot handle that */
 
 			if (first) {	/* Beginning of new segment; keep track of the very first coordinate in case of duplicates */
 				first_x = prev_x = in[GMT_X];	first_y = prev_y = in[GMT_Y];
@@ -420,7 +431,7 @@ int GMT_sphdistance (void *V_API, int mode, void *args) {
 			}
 
 			/* Convert lon,lat in degrees to Cartesian x,y,z triplets */
-			GMT_geo_to_cart (GMT, in[GMT_Y], in[GMT_X], X, true);
+			gmt_geo_to_cart (GMT, in[GMT_Y], in[GMT_X], X, true);
 
 			xx[n] = X[GMT_X];	yy[n] = X[GMT_Y];	zz[n] = X[GMT_Z];
 			if (!Ctrl->C.active) {
@@ -429,30 +440,30 @@ int GMT_sphdistance (void *V_API, int mode, void *args) {
 			if (Ctrl->E.mode == SPHD_VALUES) z_val[n] = (float)in[GMT_Z];
 
 			if (++n == n_alloc) {	/* Get more memory */
-				if (!Ctrl->C.active) { size_t n_tmp = n_alloc; GMT_malloc2 (GMT, lon, lat, n, &n_tmp, double); }
-				GMT_malloc3 (GMT, xx, yy, zz, n, &n_alloc, double);
-				if (Ctrl->E.mode == SPHD_VALUES) z_val = GMT_memory (GMT, z_val, n_alloc, float);
+				if (!Ctrl->C.active) { size_t n_tmp = n_alloc; gmt_M_malloc2 (GMT, lon, lat, n, &n_tmp, double); }
+				gmt_M_malloc3 (GMT, xx, yy, zz, n, &n_alloc, double);
+				if (Ctrl->E.mode == SPHD_VALUES) z_val = gmt_M_memory (GMT, z_val, n_alloc, float);
 			}
 			first = false;
 		} while (true);
 
 		n_alloc = n;
-		if (!Ctrl->C.active) GMT_malloc2 (GMT, lon, lat, 0, &n_alloc, double);
-		GMT_malloc3 (GMT, xx, yy, zz, 0, &n_alloc, double);
+		if (!Ctrl->C.active) gmt_M_malloc2 (GMT, lon, lat, 0, &n_alloc, double);
+		gmt_M_malloc3 (GMT, xx, yy, zz, 0, &n_alloc, double);
 
 		if (n_dup) GMT_Report (API, GMT_MSG_VERBOSE, "Skipped %" PRIu64 " duplicate points in segments\n", n_dup);
 		GMT_Report (API, GMT_MSG_VERBOSE, "Do Voronoi construction using %" PRIu64 " points\n", n);
 
 		T.mode = VORONOI;
-		stripack_lists (GMT, n, xx, yy, zz, &T);	/* Do the basic triangulation */
-		GMT_free (GMT, T.D.tri);	/* Don't need the triangulation */
+		gmt_stripack_lists (GMT, n, xx, yy, zz, &T);	/* Do the basic triangulation */
+		gmt_M_free (GMT, T.D.tri);	/* Don't need the triangulation */
 		if (Ctrl->C.active) {	/* Recompute lon,lat and set pointers */
-			cart_to_geo (GMT, n, xx, yy, zz, xx, yy);	/* Revert to lon, lat */
+			gmt_n_cart_to_geo (GMT, n, xx, yy, zz, xx, yy);	/* Revert to lon, lat */
 			lon = xx;
 			lat = yy;
 		}
-		GMT_free (GMT,  zz);
-		if (GMT_End_IO (API, GMT_IN, 0) != GMT_OK) {	/* Disables further data input */
+		gmt_M_free (GMT,  zz);
+		if (GMT_End_IO (API, GMT_IN, 0) != GMT_NOERROR) {	/* Disables further data input */
 			Return (API->error);
 		}
 		GMT->session.min_meminc = GMT_MIN_MEMINC;		/* Reset to the default value */
@@ -464,11 +475,11 @@ int GMT_sphdistance (void *V_API, int mode, void *args) {
 		GMT_GRID_DEFAULT_REG, GMT_NOTSET, NULL)) == NULL) Return (API->error);
 	GMT_Report (API, GMT_MSG_VERBOSE, "Start processing distance grid\n");
 
-	grid_lon = GMT_grd_coord (GMT, Grid->header, GMT_X);
-	grid_lat = GMT_grd_coord (GMT, Grid->header, GMT_Y);
+	grid_lon = gmt_grd_coord (GMT, Grid->header, GMT_X);
+	grid_lat = gmt_grd_coord (GMT, Grid->header, GMT_Y);
 
-	nx1 = (Grid->header->registration == GMT_GRID_PIXEL_REG) ? Grid->header->nx : Grid->header->nx - 1;
-	periodic = GMT_360_RANGE (GMT->common.R.wesn[XLO], GMT->common.R.wesn[XHI]);
+	nx1 = (Grid->header->registration == GMT_GRID_PIXEL_REG) ? Grid->header->n_columns : Grid->header->n_columns - 1;
+	periodic = gmt_M_360_range (GMT->common.R.wesn[XLO], GMT->common.R.wesn[XHI]);
 	duplicate_col = (periodic && Grid->header->registration == GMT_GRID_NODE_REG);	/* E.g., lon = 0 column should match lon = 360 column */
 
 	if (Ctrl->Q.active)	/* Pre-chewed, just get number of nodes */
@@ -476,10 +487,6 @@ int GMT_sphdistance (void *V_API, int mode, void *args) {
 	else
 		V = &T.V;
 
-#ifdef _OPENMP_NOTWORKINGYET
-#pragma omp parallel for private(node,P,p_alloc,node_new,node_stop,vertex_new,vertex,node_last,vertex_last,f_val,south_row,north_row,\
-w_col,west_col,e_col,east_col,s_row,row,p_col,col,side,ij) shared(API,GMT,Ctrl,Table,V,Grid,n,nx1,grid_lon,grid_lat,lon,lat,n_set,duplicate_col)
-#endif
 	for (node = 0; node < n; node++) {
 		GMT_Report (API, GMT_MSG_VERBOSE, "Processing polygon %7ld\r", node);
 		if (Ctrl->Q.active) {	/* Just point to next polygon */
@@ -487,12 +494,12 @@ w_col,west_col,e_col,east_col,s_row,row,p_col,col,side,ij) shared(API,GMT,Ctrl,T
 		}
 		else {	/* Obtain current polygon from Voronoi listings */
 			if (P == NULL) {	/* Need a single polygon structure that we reuse for each polygon */
-				P = GMT_memory (GMT, NULL, 1, struct GMT_DATASEGMENT);	/* Needed as pointer below */
-				P->coord = GMT_memory (GMT, NULL, 2, double *);	/* Needed as pointers below */
-				P->min = GMT_memory (GMT, NULL, 2, double);	/* Needed to hold min lon/lat */
-				P->max = GMT_memory (GMT, NULL, 2, double);	/* Needed to hold max lon/lat */
+				P = gmt_M_memory (GMT, NULL, 1, struct GMT_DATASEGMENT);	/* Needed as pointer below */
+				P->data = gmt_M_memory (GMT, NULL, 2, double *);	/* Needed as pointers below */
+				P->min = gmt_M_memory (GMT, NULL, 2, double);	/* Needed to hold min lon/lat */
+				P->max = gmt_M_memory (GMT, NULL, 2, double);	/* Needed to hold max lon/lat */
 				P->n_columns = 2;	p_alloc = 0;
-				GMT_malloc2 (GMT, P->coord[GMT_X], P->coord[GMT_Y], GMT_TINY_CHUNK, &p_alloc, double);
+				gmt_M_malloc2 (GMT, P->data[GMT_X], P->data[GMT_Y], GMT_TINY_CHUNK, &p_alloc, double);
 			}
 			node_new = node_stop = V->lend[node];
 			vertex_new = V->listc[node_new];
@@ -507,18 +514,18 @@ w_col,west_col,e_col,east_col,s_row,row,p_col,col,side,ij) shared(API,GMT,Ctrl,T
 				vertex_last = vertex_new;
 				vertex_new = V->listc[node_new];
 
-				P->coord[GMT_X][vertex] = V->lon[vertex_last];
-				P->coord[GMT_Y][vertex] = V->lat[vertex_last];
-				if (P->coord[GMT_X][vertex] < 0.0) P->coord[GMT_X][vertex] += 360.0;
-				if (P->coord[GMT_X][vertex] == 360.0) P->coord[GMT_X][vertex] = 0.0;
+				P->data[GMT_X][vertex] = V->lon[vertex_last];
+				P->data[GMT_Y][vertex] = V->lat[vertex_last];
+				if (P->data[GMT_X][vertex] < 0.0) P->data[GMT_X][vertex] += 360.0;
+				if (P->data[GMT_X][vertex] == 360.0) P->data[GMT_X][vertex] = 0.0;
 				vertex++;
-				if (vertex == p_alloc) GMT_malloc2 (GMT, P->coord[GMT_X], P->coord[GMT_Y], vertex, &p_alloc, double);
+				if (vertex == p_alloc) gmt_M_malloc2 (GMT, P->data[GMT_X], P->data[GMT_Y], vertex, &p_alloc, double);
 
 				/* When we reach the vertex where we started, we are done with this polygon */
 			} while (node_new != node_stop);
-			P->coord[GMT_X][vertex] = P->coord[GMT_X][0];	/* Close polygon explicitly */
-			P->coord[GMT_Y][vertex] = P->coord[GMT_Y][0];
-			if ((++vertex) == p_alloc) GMT_malloc2 (GMT, P->coord[GMT_X], P->coord[GMT_Y], vertex, &p_alloc, double);
+			P->data[GMT_X][vertex] = P->data[GMT_X][0];	/* Close polygon explicitly */
+			P->data[GMT_Y][vertex] = P->data[GMT_Y][0];
+			if ((++vertex) == p_alloc) gmt_M_malloc2 (GMT, P->data[GMT_X], P->data[GMT_Y], vertex, &p_alloc, double);
 			P->n_rows = vertex;
 			switch (Ctrl->E.mode) {
 				case SPHD_NODES:	f_val = (float)node;	break;
@@ -530,23 +537,23 @@ w_col,west_col,e_col,east_col,s_row,row,p_col,col,side,ij) shared(API,GMT,Ctrl,T
 
 		/* Here we have the polygon in P */
 
-		P->n_rows = GMT_fix_up_path (GMT, &P->coord[GMT_X], &P->coord[GMT_Y], P->n_rows, Ctrl->E.dist, GMT_STAIRS_OFF);
+		P->n_rows = gmt_fix_up_path (GMT, &P->data[GMT_X], &P->data[GMT_Y], P->n_rows, Ctrl->E.dist, GMT_STAIRS_OFF);
 		prepare_polygon (GMT, P);	/* Determine the enclosing sector */
 
-		south_row = (int)GMT_grd_y_to_row (GMT, P->min[GMT_Y], Grid->header);
-		north_row = (int)GMT_grd_y_to_row (GMT, P->max[GMT_Y], Grid->header);
-		w_col  = (int)GMT_grd_x_to_col (GMT, P->min[GMT_X], Grid->header);
+		south_row = (int)gmt_M_grd_y_to_row (GMT, P->min[GMT_Y], Grid->header);
+		north_row = (int)gmt_M_grd_y_to_row (GMT, P->max[GMT_Y], Grid->header);
+		w_col  = (int)gmt_M_grd_x_to_col (GMT, P->min[GMT_X], Grid->header);
 		while (w_col < 0) w_col += nx1;
 		west_col = w_col;
-		e_col = (int)GMT_grd_x_to_col (GMT, P->max[GMT_X], Grid->header);
+		e_col = (int)gmt_M_grd_x_to_col (GMT, P->max[GMT_X], Grid->header);
 		while (e_col < w_col) e_col += nx1;
 		east_col = e_col;
 		/* So here, any polygon will have a positive (or 0) west_col with an east_col >= west_col */
 		for (s_row = north_row; s_row <= south_row; s_row++) {	/* For each scanline intersecting this polygon */
 			if (s_row < 0) continue;	/* North of region */
-			row = s_row; if (row >= Grid->header->ny) continue;	/* South of region */
+			row = s_row; if (row >= Grid->header->n_rows) continue;	/* South of region */
 			for (p_col = west_col; p_col <= east_col; p_col++) {	/* March along the scanline using col >= 0 */
-				if (p_col >= Grid->header->nx) {	/* Off the east end of the grid */
+				if (p_col >= Grid->header->n_columns) {	/* Off the east end of the grid */
 					if (periodic)	/* Just shuffle to the corresponding point inside the global grid */
 						col = p_col - nx1;
 					else		/* Sorry, really outside the region */
@@ -554,11 +561,12 @@ w_col,west_col,e_col,east_col,s_row,row,p_col,col,side,ij) shared(API,GMT,Ctrl,T
 				}
 				else
 					col = p_col;
-				side = GMT_inonout_sphpol (GMT, grid_lon[col], grid_lat[row], P);	/* No holes to worry about here */
+				side = gmt_inonout (GMT, grid_lon[col], grid_lat[row], P);
+				
 				if (side == 0) continue;	/* Outside spherical polygon */
-				ij = GMT_IJP (Grid->header, row, col);
+				ij = gmt_M_ijp (Grid->header, row, col);
 				if (Ctrl->E.mode == SPHD_DIST)
-					f_val = (float)GMT_distance (GMT, grid_lon[col], grid_lat[row], lon[node], lat[node]);
+					f_val = (float)gmt_distance (GMT, grid_lon[col], grid_lat[row], lon[node], lat[node]);
 				Grid->data[ij] = f_val;
 				n_set++;
 				if (duplicate_col) {	/* Duplicate the repeating column on the other side of this one */
@@ -571,34 +579,34 @@ w_col,west_col,e_col,east_col,s_row,row,p_col,col,side,ij) shared(API,GMT,Ctrl,T
 	GMT_Report (API, GMT_MSG_VERBOSE, "Processing polygon %7ld\n", node);
 
 	if (!Ctrl->Q.active) {
-		GMT_free (GMT, P->coord[GMT_X]);
-		GMT_free (GMT, P->coord[GMT_Y]);
-		GMT_free (GMT, P->min);
-		GMT_free (GMT, P->max);
-		GMT_free (GMT, P->coord);
-		GMT_free (GMT, P);
-		GMT_free (GMT, T.V.lon);
-		GMT_free (GMT, T.V.lat);
-		GMT_free (GMT, T.V.lend);
-		GMT_free (GMT, T.V.listc);
-		GMT_free (GMT, T.V.lptr);
-		GMT_free (GMT, xx);
-		GMT_free (GMT, yy);
+		gmt_M_free (GMT, P->data[GMT_X]);
+		gmt_M_free (GMT, P->data[GMT_Y]);
+		gmt_M_free (GMT, P->min);
+		gmt_M_free (GMT, P->max);
+		gmt_M_free (GMT, P->data);
+		gmt_M_free (GMT, P);
+		gmt_M_free (GMT, T.V.lon);
+		gmt_M_free (GMT, T.V.lat);
+		gmt_M_free (GMT, T.V.lend);
+		gmt_M_free (GMT, T.V.listc);
+		gmt_M_free (GMT, T.V.lptr);
+		gmt_M_free (GMT, xx);
+		gmt_M_free (GMT, yy);
 	}
-	GMT_free (GMT, grid_lon);	GMT_free (GMT, grid_lat);
+	gmt_M_free (GMT, grid_lon);	gmt_M_free (GMT, grid_lat);
 	if (!Ctrl->C.active) {
-		GMT_free (GMT, lon);
-		GMT_free (GMT, lat);
+		gmt_M_free (GMT, lon);
+		gmt_M_free (GMT, lat);
 	}
-	if (Ctrl->E.mode == SPHD_VALUES) GMT_free (GMT, z_val);
+	if (Ctrl->E.mode == SPHD_VALUES) gmt_M_free (GMT, z_val);
 
 	if (GMT_Set_Comment (API, GMT_IS_GRID, GMT_COMMENT_IS_OPTION | GMT_COMMENT_IS_COMMAND, options, Grid)) Return (API->error);
-	if (GMT_Write_Data (API, GMT_IS_GRID, GMT_IS_FILE, GMT_IS_SURFACE, GMT_GRID_ALL, NULL, Ctrl->G.file, Grid) != GMT_OK) {
+	if (GMT_Write_Data (API, GMT_IS_GRID, GMT_IS_FILE, GMT_IS_SURFACE, GMT_GRID_ALL, NULL, Ctrl->G.file, Grid) != GMT_NOERROR) {
 		Return (API->error);
 	}
 
 	if (n_set > Grid->header->nm) n_set = Grid->header->nm;	/* Not confuse the public */
 	GMT_Report (API, GMT_MSG_VERBOSE, "Spherical distance calculation completed, %" PRIu64 " nodes visited (at least once)\n", n_set);
 
-	Return (GMT_OK);
+	Return (GMT_NOERROR);
 }
