@@ -1,7 +1,7 @@
 /*-----------------------------------------------------------------
- *	$Id: x2sys_binlist.c 15178 2015-11-06 10:45:03Z fwobbe $
+ *	$Id: x2sys_binlist.c 16555 2016-06-16 22:49:46Z pwessel $
  *
- *      Copyright (c) 1999-2015 by P. Wessel
+ *      Copyright (c) 1999-2016 by P. Wessel
  *      See LICENSE.TXT file for copying and redistribution conditions.
  *
  *      This program is free software; you can redistribute it and/or modify
@@ -29,7 +29,7 @@
 #define THIS_MODULE_NAME	"x2sys_binlist"
 #define THIS_MODULE_LIB		"x2sys"
 #define THIS_MODULE_PURPOSE	"Create bin index listing from track data files"
-#define THIS_MODULE_KEYS	">TO"
+#define THIS_MODULE_KEYS	">T}"
 
 #include "x2sys.h"
 
@@ -56,28 +56,28 @@ struct BINCROSS {
 	double x, y, d;
 };
 
-void *New_x2sys_binlist_Ctrl (struct GMT_CTRL *GMT) {	/* Allocate and initialize a new control structure */
+GMT_LOCAL void *New_Ctrl (struct GMT_CTRL *GMT) {	/* Allocate and initialize a new control structure */
 	struct X2SYS_BINLIST_CTRL *C;
 
-	C = GMT_memory (GMT, NULL, 1, struct X2SYS_BINLIST_CTRL);
+	C = gmt_M_memory (GMT, NULL, 1, struct X2SYS_BINLIST_CTRL);
 
 	/* Initialize values whose defaults are not 0/false/NULL */
 
 	return (C);
 }
 
-void Free_x2sys_binlist_Ctrl (struct GMT_CTRL *GMT, struct X2SYS_BINLIST_CTRL *C) {	/* Deallocate control structure */
+GMT_LOCAL void Free_Ctrl (struct GMT_CTRL *GMT, struct X2SYS_BINLIST_CTRL *C) {	/* Deallocate control structure */
 	if (!C) return;
-	if (C->T.TAG) free (C->T.TAG);
-	GMT_free (GMT, C);
+	gmt_M_str_free (C->T.TAG);
+	gmt_M_free (GMT, C);
 }
 
-int GMT_x2sys_binlist_usage (struct GMTAPI_CTRL *API, int level) {
-	GMT_show_name_and_purpose (API, THIS_MODULE_LIB, THIS_MODULE_NAME, THIS_MODULE_PURPOSE);
+GMT_LOCAL int usage (struct GMTAPI_CTRL *API, int level) {
+	gmt_show_name_and_purpose (API, THIS_MODULE_LIB, THIS_MODULE_NAME, THIS_MODULE_PURPOSE);
 	if (level == GMT_MODULE_PURPOSE) return (GMT_NOERROR);
 	GMT_Message (API, GMT_TIME_NONE, "usage: x2sys_binlist <files> -T<TAG> [-D] [-E] [%s]\n\n", GMT_V_OPT);
 
-	if (level == GMT_SYNOPSIS) return (EXIT_FAILURE);
+	if (level == GMT_SYNOPSIS) return (GMT_MODULE_SYNOPSIS);
 
 	GMT_Message (API, GMT_TIME_NONE, "\t<files> is one or more datafiles, or give =<files.lis> for a file with a list of datafiles.\n");
 	GMT_Message (API, GMT_TIME_NONE, "\t-T <TAG> is the system tag for this compilation.\n");
@@ -86,10 +86,10 @@ int GMT_x2sys_binlist_usage (struct GMTAPI_CTRL *API, int level) {
 	GMT_Message (API, GMT_TIME_NONE, "\t-E Bin tracks using equal-area bins (with -D only).\n");
 	GMT_Option (API, "V,.");
 	
-	return (EXIT_FAILURE);
+	return (GMT_MODULE_USAGE);
 }
 
-int GMT_x2sys_binlist_parse (struct GMT_CTRL *GMT, struct X2SYS_BINLIST_CTRL *Ctrl, struct GMT_OPTION *options) {
+GMT_LOCAL int parse (struct GMT_CTRL *GMT, struct X2SYS_BINLIST_CTRL *Ctrl, struct GMT_OPTION *options) {
 
 	/* This parses the options provided to grdcut and sets parameters in CTRL.
 	 * Any GMT common options will override values set previously by other commands.
@@ -97,7 +97,7 @@ int GMT_x2sys_binlist_parse (struct GMT_CTRL *GMT, struct X2SYS_BINLIST_CTRL *Ct
 	 * returned when registering these sources/destinations with the API.
 	 */
 
-	unsigned int n_errors = 0;
+	unsigned int n_errors = 0, n_files[2] = {0, 0};
 	struct GMT_OPTION *opt = NULL;
 
 	for (opt = options; opt; opt = opt->next) {	/* Process all the options given */
@@ -105,8 +105,11 @@ int GMT_x2sys_binlist_parse (struct GMT_CTRL *GMT, struct X2SYS_BINLIST_CTRL *Ct
 		switch (opt->option) {
 			/* Common parameters */
 
-			case '<':	/* Skip input files */
-				if (!GMT_check_filearg (GMT, '<', opt->arg, GMT_IN, GMT_IS_DATASET)) n_errors++;
+			case '<':	/* Skip input files since their paths depend on tag */
+				n_files[GMT_IN]++;
+				break;
+			case '>':	/* Got named output file */
+				n_files[GMT_OUT]++;
 				break;
 
 			/* Processes program-specific parameters */
@@ -122,19 +125,20 @@ int GMT_x2sys_binlist_parse (struct GMT_CTRL *GMT, struct X2SYS_BINLIST_CTRL *Ct
 				Ctrl->T.TAG = strdup (opt->arg);
 				break;
 			default:	/* Report bad options */
-				n_errors += GMT_default_error (GMT, opt->option);
+				n_errors += gmt_default_error (GMT, opt->option);
 				break;
 		}
 	}
 
-	n_errors += GMT_check_condition (GMT, Ctrl->E.active && !Ctrl->D.active, "Syntax error: -E requires -D\n");
-	n_errors += GMT_check_condition (GMT, !Ctrl->T.active || !Ctrl->T.TAG, "Syntax error: -T must be used to set the TAG\n");
+	n_errors += gmt_M_check_condition (GMT, n_files[GMT_IN] == 0, "Syntax error: No track files given\n");
+	n_errors += gmt_M_check_condition (GMT, n_files[GMT_OUT] > 1, "Syntax error: More than one output file given\n");
+	n_errors += gmt_M_check_condition (GMT, Ctrl->E.active && !Ctrl->D.active, "Syntax error: -E requires -D\n");
+	n_errors += gmt_M_check_condition (GMT, !Ctrl->T.active || !Ctrl->T.TAG, "Syntax error: -T must be used to set the TAG\n");
 	
-	return (n_errors ? GMT_PARSE_ERROR : GMT_OK);
+	return (n_errors ? GMT_PARSE_ERROR : GMT_NOERROR);
 }
 
-int outside (double x, double y, struct X2SYS_BIX *B, int geo)
-{
+GMT_LOCAL int outside (double x, double y, struct X2SYS_BIX *B, int geo) {
 	if (y < B->wesn[YLO] || y > B->wesn[YHI]) return (1);
 	if (geo) {	/* Geographic data with periodic longitudes */
 		while (x < B->wesn[XLO]) x += 360.0;
@@ -147,18 +151,16 @@ int outside (double x, double y, struct X2SYS_BIX *B, int geo)
 	return (0);	/* Inside */
 }
 
-unsigned int get_data_flag (double *data[], uint64_t j, struct X2SYS_INFO *s)
-{
+GMT_LOCAL unsigned int get_data_flag (double *data[], uint64_t j, struct X2SYS_INFO *s) {
 	unsigned int i, bit, flag;
 	for (i = flag = 0, bit = 1; i < s->n_fields; i++, bit <<= 1) {
-		if (GMT_is_dnan (data[i][j])) continue;	/* NaN, so no data here */
+		if (gmt_M_is_dnan (data[i][j])) continue;	/* NaN, so no data here */
 		flag |= bit;
 	}
 	return (flag);
 }
 
-int comp_bincross (const void *p1, const void *p2)
-{
+GMT_LOCAL int comp_bincross (const void *p1, const void *p2) {
 	const struct BINCROSS *a = p1, *b = p2;
 
 	if (a->d < b->d) return (-1);
@@ -166,14 +168,13 @@ int comp_bincross (const void *p1, const void *p2)
 	return (0);
 }
 
-#define bailout(code) {GMT_Free_Options (mode); return (code);}
-#define Return(code) {Free_x2sys_binlist_Ctrl (GMT, Ctrl); GMT_end_module (GMT, GMT_cpy); bailout (code);}
+#define bailout(code) {gmt_M_free_options (mode); return (code);}
+#define Return(code) {Free_Ctrl (GMT, Ctrl); gmt_end_module (GMT, GMT_cpy); bailout (code);}
 
-int GMT_x2sys_binlist (void *V_API, int mode, void *args)
-{
+int GMT_x2sys_binlist (void *V_API, int mode, void *args) {
 	char **trk_name = NULL, record[GMT_BUFSIZ] = {""}, text[GMT_LEN64] = {""};
 
-	uint64_t this_bin_index, index, last_bin_index, row;
+	uint64_t this_bin_index, index, last_bin_index, row, col;
 	unsigned int trk, curr_x_pt, prev_x_pt, n_tracks;
 	int ii_notused, jj_notused, bcol, brow, start_col, end_col, jump_180, jump_360;
 	int this_bin_col;	/* This col node for bin */
@@ -195,44 +196,46 @@ int GMT_x2sys_binlist (void *V_API, int mode, void *args)
 	struct X2SYS_BINLIST_CTRL *Ctrl = NULL;
 	struct GMT_CTRL *GMT = NULL, *GMT_cpy = NULL;
 	struct GMT_OPTION *options = NULL;
-	struct GMTAPI_CTRL *API = GMT_get_API_ptr (V_API);	/* Cast from void to GMTAPI_CTRL pointer */
+	struct GMTAPI_CTRL *API = gmt_get_api_ptr (V_API);	/* Cast from void to GMTAPI_CTRL pointer */
 
 	/*----------------------- Standard module initialization and parsing ----------------------*/
 
 	if (API == NULL) return (GMT_NOT_A_SESSION);
-	if (mode == GMT_MODULE_PURPOSE) return (GMT_x2sys_binlist_usage (API, GMT_MODULE_PURPOSE));	/* Return the purpose of program */
+	if (mode == GMT_MODULE_PURPOSE) return (usage (API, GMT_MODULE_PURPOSE));	/* Return the purpose of program */
 	options = GMT_Create_Options (API, mode, args);	if (API->error) return (API->error);	/* Set or get option list */
 
-	if (!options || options->option == GMT_OPT_USAGE) bailout (GMT_x2sys_binlist_usage (API, GMT_USAGE));	/* Return the usage message */
-	if (options->option == GMT_OPT_SYNOPSIS) bailout (GMT_x2sys_binlist_usage (API, GMT_SYNOPSIS));	/* Return the synopsis */
+	if (!options || options->option == GMT_OPT_USAGE) bailout (usage (API, GMT_USAGE));	/* Return the usage message */
+	if (options->option == GMT_OPT_SYNOPSIS) bailout (usage (API, GMT_SYNOPSIS));	/* Return the synopsis */
 
 	/* Parse the command-line arguments */
 
-	GMT = GMT_begin_module (API, THIS_MODULE_LIB, THIS_MODULE_NAME, &GMT_cpy); /* Save current state */
+	GMT = gmt_begin_module (API, THIS_MODULE_LIB, THIS_MODULE_NAME, &GMT_cpy); /* Save current state */
 	if (GMT_Parse_Common (API, GMT_PROG_OPTIONS, options)) Return (API->error);
-	Ctrl = New_x2sys_binlist_Ctrl (GMT);	/* Allocate and initialize a new control structure */
-	if ((error = GMT_x2sys_binlist_parse (GMT, Ctrl, options)) != 0) Return (error);
+	Ctrl = New_Ctrl (GMT);	/* Allocate and initialize a new control structure */
+	if ((error = parse (GMT, Ctrl, options)) != 0) Return (error);
 
 	/*---------------------------- This is the x2sys_binlist main code ----------------------------*/
 
 	if ((n_tracks = x2sys_get_tracknames (GMT, options, &trk_name, &cmdline_files)) == 0) {
 		GMT_Report (API, GMT_MSG_NORMAL, "No datafiles given!\n");
-		Return (EXIT_FAILURE);		
+		Return (GMT_RUNTIME_ERROR);		
 	}
 
 	x2sys_err_fail (GMT, x2sys_set_system (GMT, Ctrl->T.TAG, &s, &B, &GMT->current.io), Ctrl->T.TAG);
 
 	if (Ctrl->E.active && !s->geographic) {
 		GMT_Report (API, GMT_MSG_NORMAL, "-E requires geographic data; your TAG implies Cartesian\n");
-		Return (EXIT_FAILURE);		
+		x2sys_end (GMT, s);
+		x2sys_free_list (GMT, trk_name, n_tracks);
+		Return (GMT_RUNTIME_ERROR);		
 	}
 
 	if (s->geographic) {
-		GMT_set_geographic (GMT, GMT_OUT);
+		gmt_set_geographic (GMT, GMT_OUT);
 		GMT->current.io.geo.range = s->geodetic;
 	}
 	else
-		GMT_set_cartesian (GMT, GMT_OUT);
+		gmt_set_cartesian (GMT, GMT_OUT);
 	GMT->current.io.col_type[GMT_OUT][GMT_Z] = GMT_IS_FLOAT;
 	
 	MGD77_Set_Unit (GMT, s->unit[X2SYS_DIST_SELECTION], &dist_scale, -1);	/* Gets scale which multiplies meters to chosen distance unit */
@@ -244,16 +247,24 @@ int GMT_x2sys_binlist (void *V_API, int mode, void *args)
 		if (!(doubleAlmostEqual (B.wesn[XHI] - B.wesn[XLO], 360.0)
 					&& doubleAlmostEqualZero (B.wesn[YHI] - B.wesn[YLO], 180.0))) {
 			GMT_Report (API, GMT_MSG_NORMAL, "-E requires a global region (-Rg or -Rd)");
-			Return (EXIT_FAILURE);
+			x2sys_free_list (GMT, trk_name, n_tracks);
+			x2sys_end (GMT, s);
+			Return (GMT_RUNTIME_ERROR);
 		}
-		GMT->current.setting.proj_ellipsoid = GMT_get_ellipsoid (GMT, "Sphere");	/* Make sure we use a spherical projection */
+		GMT->current.setting.proj_ellipsoid = gmt_get_ellipsoid (GMT, "Sphere");	/* Make sure we use a spherical projection */
 		mid = 0.5 * (B.wesn[XHI] + B.wesn[XLO]);	/* Central longitude to use */
-		GMT_Report (API, GMT_MSG_VERBOSE, "To undo equal-area projection, use -R%g/%g/%g/%g -JY%g/%s/360i\n", B.wesn[XLO], B.wesn[XHI], B.wesn[YLO], B.wesn[YHI], mid, EA_LAT);
+		GMT_Report (API, GMT_MSG_VERBOSE,
+		            "To undo equal-area projection, use -R%g/%g/%g/%g -JY%g/%s/360i\n",
+		            B.wesn[XLO], B.wesn[XHI], B.wesn[YLO], B.wesn[YHI], mid, EA_LAT);
 		sprintf (proj, "Y%g/%s/360", mid, EA_LAT);
-		GMT_parse_common_options (GMT, "J", 'J', proj);
-		if (GMT_err_pass (GMT, GMT_map_setup (GMT, B.wesn), "")) Return (GMT_PROJECTION_ERROR);
-		GMT_geo_to_xy (GMT, B.wesn[XLO], B.wesn[YLO], &B.wesn[XLO], &B.wesn[YLO]);
-		GMT_geo_to_xy (GMT, B.wesn[XHI], B.wesn[YHI], &B.wesn[XHI], &B.wesn[YHI]);
+		gmt_parse_common_options (GMT, "J", 'J', proj);
+		if (gmt_M_err_pass (GMT, gmt_map_setup (GMT, B.wesn), "")) {
+			x2sys_free_list (GMT, trk_name, n_tracks);
+			x2sys_end (GMT, s);
+			Return (GMT_PROJECTION_ERROR);
+		}
+		gmt_geo_to_xy (GMT, B.wesn[XLO], B.wesn[YLO], &B.wesn[XLO], &B.wesn[YLO]);
+		gmt_geo_to_xy (GMT, B.wesn[XHI], B.wesn[YHI], &B.wesn[XHI], &B.wesn[YHI]);
 		y_max = B.wesn[YHI];
 	}
 	
@@ -262,21 +273,27 @@ int GMT_x2sys_binlist (void *V_API, int mode, void *args)
 	jump_180 = irint (180.0 / B.inc[GMT_X]);
 	jump_360 = irint (360.0 / B.inc[GMT_X]);
 
-	X = GMT_memory (GMT, NULL, nx_alloc, struct BINCROSS);
+	X = gmt_M_memory (GMT, NULL, nx_alloc, struct BINCROSS);
 	
 	if (Ctrl->D.active) {
-		GMT_init_distaz (GMT, s->unit[X2SYS_DIST_SELECTION][0], s->dist_flag, GMT_MAP_DIST);
-		dist_bin = GMT_memory (GMT, NULL, B.nm_bin, double);
+		gmt_init_distaz (GMT, s->unit[X2SYS_DIST_SELECTION][0], s->dist_flag, GMT_MAP_DIST);
+		dist_bin = gmt_M_memory (GMT, NULL, B.nm_bin, double);
 	}
 
-	if (GMT_Init_IO (API, GMT_IS_TEXTSET, GMT_IS_POINT, GMT_OUT, GMT_ADD_DEFAULT, 0, options) != GMT_OK) {	/* Establishes data output */
+	if (GMT_Init_IO (API, GMT_IS_TEXTSET, GMT_IS_POINT, GMT_OUT, GMT_ADD_DEFAULT, 0, options) != GMT_NOERROR) {	/* Establishes data output */
+		gmt_M_free (GMT, X);
+		if (Ctrl->D.active) gmt_M_free (GMT, dist_bin);
+		x2sys_free_list (GMT, trk_name, n_tracks);
 		Return (API->error);
 	}
-	if (GMT_Begin_IO (API, GMT_IS_TEXTSET, GMT_OUT, GMT_HEADER_ON) != GMT_OK) {	/* Enables data output and sets access mode */
+	if (GMT_Begin_IO (API, GMT_IS_TEXTSET, GMT_OUT, GMT_HEADER_ON) != GMT_NOERROR) {	/* Enables data output and sets access mode */
+		gmt_M_free (GMT, X);
+		if (Ctrl->D.active) gmt_M_free (GMT, dist_bin);
+		x2sys_free_list (GMT, trk_name, n_tracks);
 		Return (API->error);
 	}
-	GMT_set_tableheader (GMT, GMT_OUT, true);	/* Turn on -ho explicitly */
-	GMT_set_segmentheader (GMT, GMT_OUT, true);	/* Turn on segment headers on output */
+	gmt_set_tableheader (GMT, GMT_OUT, true);	/* Turn on -ho explicitly */
+	gmt_set_segmentheader (GMT, GMT_OUT, true);	/* Turn on segment headers on output */
 	sprintf (record, " %s", Ctrl->T.TAG);	/* Preserve the leading space for backwards compatibility */
 	GMT_Put_Record (API, GMT_WRITE_TABLE_HEADER, record);
 
@@ -287,17 +304,23 @@ int GMT_x2sys_binlist (void *V_API, int mode, void *args)
 		x2sys_err_fail (GMT, (s->read_file) (GMT, trk_name[trk], &data, s, &p, &GMT->current.io, &row), trk_name[trk]);
 		GMT_Report (API, GMT_MSG_VERBOSE, "[%s]\n", s->path);
 		
+		if (p.n_rows == 0) {
+			GMT_Report (API, GMT_MSG_VERBOSE, "No data records found - skipping %s\n", trk_name[trk]);
+			x2sys_free_data (GMT, data, s->n_fields, &p);
+			continue;
+		}
+		
 		if (Ctrl->E.active) {	/* Project coordinates */
-			for (row = 0; row < p.n_rows; row++) GMT_geo_to_xy (GMT, data[s->x_col][row], data[s->y_col][row], &data[s->x_col][row], &data[s->y_col][row]);
+			for (row = 0; row < p.n_rows; row++) gmt_geo_to_xy (GMT, data[s->x_col][row], data[s->y_col][row], &data[s->x_col][row], &data[s->y_col][row]);
 		}
 		
 		/* Reset bin flags */
 
-		GMT_memset (B.binflag, B.nm_bin, unsigned int);
+		gmt_M_memset (B.binflag, B.nm_bin, unsigned int);
 		if (Ctrl->D.active) {
 			int signed_flag = s->dist_flag;
-			GMT_memset (dist_bin, B.nm_bin, double);
-			if ((dist_km = GMT_dist_array_2 (GMT, data[s->x_col], data[s->y_col], p.n_rows, dist_scale, -signed_flag)) == NULL) GMT_err_fail (GMT, GMT_MAP_BAD_DIST_FLAG, "");	/* -ve gives increments */
+			gmt_M_memset (dist_bin, B.nm_bin, double);
+			if ((dist_km = gmt_dist_array_2 (GMT, data[s->x_col], data[s->y_col], p.n_rows, dist_scale, -signed_flag)) == NULL) gmt_M_err_fail (GMT, GMT_MAP_BAD_DIST_FLAG, "");	/* -ve gives increments */
 		}
 
 		last_bin_index = UINT_MAX;
@@ -322,7 +345,7 @@ int GMT_x2sys_binlist (void *V_API, int mode, void *args)
 			if (row > 0) { /* Can check for gaps starting with 1st to 2nd point */
 				gap = false;
 				if (s->t_col >= 0) {	/* There is a time column in the data*/
-					if (GMT_is_dnan (data[s->t_col][row])&& (dist_km[row] - dist_km[row-1]) > B.dist_gap) /* but time = NaN, so test for gaps based on distance */
+					if (gmt_M_is_dnan (data[s->t_col][row])&& (dist_km[row] - dist_km[row-1]) > B.dist_gap) /* but time = NaN, so test for gaps based on distance */
 						gap = true;
 			   		else if ((data[s->t_col][row] - data[s->t_col][row-1]) > B.time_gap)	/* We have a time data gap so we skip this interval */
 						gap = true;
@@ -374,13 +397,13 @@ int GMT_x2sys_binlist (void *V_API, int mode, void *args)
 					nx++;
 					if (nx == nx_alloc) {
 						nx_alloc <<= 1;
-						X = GMT_memory (GMT, X, nx_alloc, struct BINCROSS);
+						X = gmt_M_memory (GMT, X, nx_alloc, struct BINCROSS);
 					}
 				}
 				for (bcol = start_col; bcol <= end_col; bcol++) {	/* If we go in here we think dx is non-zero (we do a last-ditch dx check just in case) */
 					x = B.wesn[XLO] + bcol * B.inc[GMT_X];
 					if (s->geographic && x >= 360.0) x -= 360.0;
-					GMT_set_delta_lon (data[s->x_col][row-1], x, del_x);
+					gmt_M_set_delta_lon (data[s->x_col][row-1], x, del_x);
 					del_y = (dx == 0.0) ? 0.5 * (data[s->y_col][row] - data[s->y_col][row-1]) : del_x * (data[s->y_col][row] - data[s->y_col][row-1]) / dx;
 					y = data[s->y_col][row-1] + del_y;
 					if (s->geographic && fabs (y) > y_max) {
@@ -391,7 +414,7 @@ int GMT_x2sys_binlist (void *V_API, int mode, void *args)
 					nx++;
 					if (nx == nx_alloc) {
 						nx_alloc <<= 1;
-						X = GMT_memory (GMT, X, nx_alloc, struct BINCROSS);
+						X = gmt_M_memory (GMT, X, nx_alloc, struct BINCROSS);
 					}
 				}
 				
@@ -410,7 +433,7 @@ int GMT_x2sys_binlist (void *V_API, int mode, void *args)
 					y = 0.5 * (X[curr_x_pt].y + X[prev_x_pt].y);
 					if (s->geographic && fabs (y) > y_max) y = copysign (y_max, y);
 					x2sys_err_fail (GMT, x2sys_bix_get_index (GMT, x, y, &ii_notused, &jj_notused, &B, &index), "");
-					dist_bin[index] += GMT_distance (GMT, X[curr_x_pt].x, X[curr_x_pt].y, X[prev_x_pt].x, X[prev_x_pt].y);
+					dist_bin[index] += gmt_distance (GMT, X[curr_x_pt].x, X[curr_x_pt].y, X[prev_x_pt].x, X[prev_x_pt].y);
 					B.binflag[index] |= nav_flag;		/* Only update nav flags we have not been here already */
 				}
 			}
@@ -425,35 +448,37 @@ int GMT_x2sys_binlist (void *V_API, int mode, void *args)
 
 		GMT_Put_Record (API, GMT_WRITE_SEGMENT_HEADER, trk_name[trk]);
 		for (index = 0; index < B.nm_bin; index++) {
+			row = index / B.nx_bin;	/* To hold the row number */
+			col = index % B.nx_bin;	/* To hold the col number */
 			if (B.binflag[index] == 0) continue;
-			x = B.wesn[XLO] + ((index % B.nx_bin) + 0.5) * B.inc[GMT_X];
-			y = B.wesn[YLO] + ((index / B.nx_bin) + 0.5) * B.inc[GMT_Y];
-			GMT_ascii_format_col (GMT, record, x, GMT_OUT, GMT_X);
+			x = B.wesn[XLO] + (col + 0.5) * B.inc[GMT_X];
+			y = B.wesn[YLO] + (row + 0.5) * B.inc[GMT_Y];
+			gmt_ascii_format_col (GMT, record, x, GMT_OUT, GMT_X);
 			strcat (record, GMT->current.setting.io_col_separator);
-			GMT_ascii_format_col (GMT, text, y, GMT_OUT, GMT_Y);
+			gmt_ascii_format_col (GMT, text, y, GMT_OUT, GMT_Y);
 			strcat (record, text);
 			sprintf (text, "%s%" PRIu64 "%s%u", GMT->current.setting.io_col_separator, index, GMT->current.setting.io_col_separator, B.binflag[index]);
 			strcat (record, text);
 			if (Ctrl->D.active) {
 				strcat (record, GMT->current.setting.io_col_separator);
-				GMT_ascii_format_col (GMT, text, dist_bin[index], GMT_OUT, GMT_Z);
+				gmt_ascii_format_col (GMT, text, dist_bin[index], GMT_OUT, GMT_Z);
 				strcat (record, text);
 			}
 			GMT_Put_Record (API, GMT_WRITE_TEXT, record);
 		}
 
-		if (Ctrl->D.active) GMT_free (GMT, dist_km);
+		if (Ctrl->D.active) gmt_M_free (GMT, dist_km);
 	}
 	
-	if (GMT_End_IO (API, GMT_OUT, 0) != GMT_OK) {	/* Disables further data output */
+	if (GMT_End_IO (API, GMT_OUT, 0) != GMT_NOERROR) {	/* Disables further data output */
 		Return (API->error);
 	}
 
-	GMT_free (GMT, X);
+	gmt_M_free (GMT, X);
 	x2sys_end (GMT, s);
-	GMT_free (GMT, B.binflag);
-	if (Ctrl->D.active) GMT_free (GMT, dist_bin);
+	gmt_M_free (GMT, B.binflag);
+	if (Ctrl->D.active) gmt_M_free (GMT, dist_bin);
 	x2sys_free_list (GMT, trk_name, n_tracks);
 
-	Return (GMT_OK);
+	Return (GMT_NOERROR);
 }
