@@ -1,7 +1,7 @@
 /*-----------------------------------------------------------------
- *	$Id: x2sys_report.c 15178 2015-11-06 10:45:03Z fwobbe $
+ *	$Id: x2sys_report.c 17104 2016-09-18 01:33:17Z jluis $
  *
- *      Copyright (c) 1999-2015 by P. Wessel
+ *      Copyright (c) 1999-2016 by P. Wessel
  *      See LICENSE.TXT file for copying and redistribution conditions.
  *
  *      This program is free software; you can redistribute it and/or modify
@@ -28,12 +28,15 @@
 #define THIS_MODULE_NAME	"x2sys_report"
 #define THIS_MODULE_LIB		"x2sys"
 #define THIS_MODULE_PURPOSE	"Report statistics from crossover data base"
-#define THIS_MODULE_KEYS	"LTi,ITi,>TO,RG-"
+#define THIS_MODULE_KEYS	">T}"
 
 #include "x2sys.h"
 
 #define GMT_PROG_OPTIONS "->RV"
 
+#define XREPORT_EXTERNAL	1
+#define XREPORT_INTERNAL	2
+
 struct X2SYS_REPORT_CTRL {
 	struct In {
 		bool active;
@@ -90,34 +93,32 @@ struct COE_ADJLIST {	/* Array with the growing arrays of COE_ADJUST per track */
 	size_t n_alloc;
 };
 
-void *New_x2sys_report_Ctrl (struct GMT_CTRL *GMT) {	/* Allocate and initialize a new control structure */
+GMT_LOCAL void *New_Ctrl (struct GMT_CTRL *GMT) {	/* Allocate and initialize a new control structure */
 	struct X2SYS_REPORT_CTRL *C;
 
-	C = GMT_memory (GMT, NULL, 1, struct X2SYS_REPORT_CTRL);
-
-	/* Initialize values whose defaults are not 0/false/NULL */
+	C = gmt_M_memory (GMT, NULL, 1, struct X2SYS_REPORT_CTRL);
 
 	return (C);
 }
 
-void Free_x2sys_report_Ctrl (struct GMT_CTRL *GMT, struct X2SYS_REPORT_CTRL *C) {	/* Deallocate control structure */
+GMT_LOCAL void Free_Ctrl (struct GMT_CTRL *GMT, struct X2SYS_REPORT_CTRL *C) {	/* Deallocate control structure */
 	if (!C) return;
-	if (C->In.file) free (C->In.file);
-	if (C->C.col) free (C->C.col);
-	if (C->I.file) free (C->I.file);
-	if (C->L.file) free (C->L.file);
-	if (C->S.file) free (C->S.file);
-	if (C->T.TAG) free (C->T.TAG);
-	GMT_free (GMT, C);
+	gmt_M_str_free (C->In.file);
+	gmt_M_str_free (C->C.col);
+	gmt_M_str_free (C->I.file);
+	gmt_M_str_free (C->L.file);
+	gmt_M_str_free (C->S.file);
+	gmt_M_str_free (C->T.TAG);
+	gmt_M_free (GMT, C);
 }
 
-int GMT_x2sys_report_usage (struct GMTAPI_CTRL *API, int level) {
-	GMT_show_name_and_purpose (API, THIS_MODULE_LIB, THIS_MODULE_NAME, THIS_MODULE_PURPOSE);
+GMT_LOCAL int usage (struct GMTAPI_CTRL *API, int level) {
+	gmt_show_name_and_purpose (API, THIS_MODULE_LIB, THIS_MODULE_NAME, THIS_MODULE_PURPOSE);
 	if (level == GMT_MODULE_PURPOSE) return (GMT_NOERROR);
 	GMT_Message (API, GMT_TIME_NONE, "usage: x2sys_report -C<column> -T<TAG> [<COEdbase>] [-A] [-I<ignorelist>] [-L[<corrtable.txt>]]\n");
 	GMT_Message (API, GMT_TIME_NONE, "\t[-N<nx_min>] [-Qe|i] [-S<track>] [%s] [%s]\n\n", GMT_Rgeo_OPT, GMT_V_OPT);
 
-	if (level == GMT_SYNOPSIS) return (EXIT_FAILURE);
+	if (level == GMT_SYNOPSIS) return (GMT_MODULE_SYNOPSIS);
 
 	GMT_Message (API, GMT_TIME_NONE, "\t-C <column> is the name of the data column whose crossovers we want.\n");
 	GMT_Message (API, GMT_TIME_NONE, "\t-T <TAG> is the system tag for the data set.\n");
@@ -135,10 +136,10 @@ int GMT_x2sys_report_usage (struct GMTAPI_CTRL *API, int level) {
 	GMT_Message (API, GMT_TIME_NONE, "\t-S Return only crossovers involving this track [Use all tracks].\n");
 	GMT_Option (API, "V,.");
 	
-	return (EXIT_FAILURE);
+	return (GMT_MODULE_USAGE);
 }
 
-int GMT_x2sys_report_parse (struct GMT_CTRL *GMT, struct X2SYS_REPORT_CTRL *Ctrl, struct GMT_OPTION *options) {
+GMT_LOCAL int parse (struct GMT_CTRL *GMT, struct X2SYS_REPORT_CTRL *Ctrl, struct GMT_OPTION *options) {
 
 	/* This parses the options provided to grdcut and sets parameters in CTRL.
 	 * Any GMT common options will override values set previously by other commands.
@@ -181,7 +182,7 @@ int GMT_x2sys_report_parse (struct GMT_CTRL *GMT, struct X2SYS_REPORT_CTRL *Ctrl
 				Ctrl->N.active = true;
 				Ctrl->N.min = atoi (opt->arg);
 				break;
-			case 'Q':	/* Specify internal or external only */
+			case 'Q':	/* Specify internal or external only [Default is both] */
 				Ctrl->Q.active = true;
 				if (opt->arg[0] == 'e') Ctrl->Q.mode = 1;
 				else if (opt->arg[0] == 'i') Ctrl->Q.mode = 2;
@@ -197,19 +198,19 @@ int GMT_x2sys_report_parse (struct GMT_CTRL *GMT, struct X2SYS_REPORT_CTRL *Ctrl
 				break;
 
 			default:	/* Report bad options */
-				n_errors += GMT_default_error (GMT, opt->option);
+				n_errors += gmt_default_error (GMT, opt->option);
 				break;
 		}
 	}
 
-	n_errors += GMT_check_condition (GMT, !Ctrl->T.active || !Ctrl->T.TAG, "Syntax error: -T must be used to set the TAG\n");
-	n_errors += GMT_check_condition (GMT, !Ctrl->C.active || !Ctrl->C.col, "Syntax error: Must use -C to specify observation of interest\n");
-	n_errors += GMT_check_condition (GMT, Ctrl->Q.mode == 3, "Syntax error: Only one of -Qe -Qi can be specified!\n");
+	n_errors += gmt_M_check_condition (GMT, !Ctrl->T.active || !Ctrl->T.TAG, "Syntax error: -T must be used to set the TAG\n");
+	n_errors += gmt_M_check_condition (GMT, !Ctrl->C.active || !Ctrl->C.col, "Syntax error: Must use -C to specify observation of interest\n");
+	n_errors += gmt_M_check_condition (GMT, Ctrl->Q.mode == 3, "Syntax error: Only one of -Qe -Qi can be specified!\n");
 
-	return (n_errors ? GMT_PARSE_ERROR : GMT_OK);
+	return (n_errors ? GMT_PARSE_ERROR : GMT_NOERROR);
 }
 
-int comp_structs (const void *point_1, const void *point_2) { /* Sort ADJ structure on distance */
+GMT_LOCAL int comp_structs (const void *point_1, const void *point_2) { /* Sort ADJ structure on distance */
         if ( ((struct COE_ADJUST *)point_1)->d < ((struct COE_ADJUST *)point_2)->d)
                 return(-1);
         else if ( ((struct COE_ADJUST *)point_1)->d > ((struct COE_ADJUST *)point_2)->d)
@@ -218,11 +219,10 @@ int comp_structs (const void *point_1, const void *point_2) { /* Sort ADJ struct
                 return(0);
 }
 
-#define bailout(code) {GMT_Free_Options (mode); return (code);}
-#define Return(code) {Free_x2sys_report_Ctrl (GMT, Ctrl); GMT_end_module (GMT, GMT_cpy); bailout (code);}
+#define bailout(code) {gmt_M_free_options (mode); return (code);}
+#define Return(code) {Free_Ctrl (GMT, Ctrl); gmt_end_module (GMT, GMT_cpy); bailout (code);}
 
-int GMT_x2sys_report (void *V_API, int mode, void *args)
-{
+int GMT_x2sys_report (void *V_API, int mode, void *args) {
 	char **trk_name = NULL, *c = NULL, fmt[GMT_BUFSIZ] = {""}, record[GMT_BUFSIZ] = {""}, word[GMT_BUFSIZ] = {""};
 	struct X2SYS_INFO *s = NULL;
 	struct X2SYS_BIX B;
@@ -241,23 +241,23 @@ int GMT_x2sys_report (void *V_API, int mode, void *args)
 	struct X2SYS_REPORT_CTRL *Ctrl = NULL;
 	struct GMT_CTRL *GMT = NULL, *GMT_cpy = NULL;
 	struct GMT_OPTION *options = NULL;
-	struct GMTAPI_CTRL *API = GMT_get_API_ptr (V_API);	/* Cast from void to GMTAPI_CTRL pointer */
+	struct GMTAPI_CTRL *API = gmt_get_api_ptr (V_API);	/* Cast from void to GMTAPI_CTRL pointer */
 
 	/*----------------------- Standard module initialization and parsing ----------------------*/
 
 	if (API == NULL) return (GMT_NOT_A_SESSION);
-	if (mode == GMT_MODULE_PURPOSE) return (GMT_x2sys_report_usage (API, GMT_MODULE_PURPOSE));	/* Return the purpose of program */
+	if (mode == GMT_MODULE_PURPOSE) return (usage (API, GMT_MODULE_PURPOSE));	/* Return the purpose of program */
 	options = GMT_Create_Options (API, mode, args);	if (API->error) return (API->error);	/* Set or get option list */
 
-	if (!options || options->option == GMT_OPT_USAGE) bailout (GMT_x2sys_report_usage (API, GMT_USAGE));	/* Return the usage message */
-	if (options->option == GMT_OPT_SYNOPSIS) bailout (GMT_x2sys_report_usage (API, GMT_SYNOPSIS));	/* Return the synopsis */
+	if (!options || options->option == GMT_OPT_USAGE) bailout (usage (API, GMT_USAGE));	/* Return the usage message */
+	if (options->option == GMT_OPT_SYNOPSIS) bailout (usage (API, GMT_SYNOPSIS));	/* Return the synopsis */
 
 	/* Parse the command-line arguments */
 
-	GMT = GMT_begin_module (API, THIS_MODULE_LIB, THIS_MODULE_NAME, &GMT_cpy); /* Save current state */
+	GMT = gmt_begin_module (API, THIS_MODULE_LIB, THIS_MODULE_NAME, &GMT_cpy); /* Save current state */
 	if (GMT_Parse_Common (API, GMT_PROG_OPTIONS, options)) Return (API->error);
-	Ctrl = New_x2sys_report_Ctrl (GMT);	/* Allocate and initialize a new control structure */
-	if ((error = GMT_x2sys_report_parse (GMT, Ctrl, options)) != 0) Return (error);
+	Ctrl = New_Ctrl (GMT);	/* Allocate and initialize a new control structure */
+	if ((error = parse (GMT, Ctrl, options)) != 0) Return (error);
 	
 	/*---------------------------- This is the x2sys_report main code ----------------------------*/
 
@@ -272,14 +272,15 @@ int GMT_x2sys_report (void *V_API, int mode, void *args)
 	if (Ctrl->C.col) x2sys_err_fail (GMT, x2sys_pick_fields (GMT, Ctrl->C.col, s), "-C");
 	if (s->n_out_columns != 1) {
 		GMT_Report (API, GMT_MSG_NORMAL, "Error: -C must specify a single column name\n");
-		Return (EXIT_FAILURE);
+		x2sys_end (GMT, s);
+		Return (GMT_RUNTIME_ERROR);
 	}
 	
 	/* Select internal, external, or both */
 	
-	if (Ctrl->Q.active) {
-		if (Ctrl->Q.mode == 1) internal = false;
-		if (Ctrl->Q.mode == 2) external = false;
+	if (Ctrl->Q.active) {	/* Follow user options */
+		internal = (Ctrl->Q.mode == XREPORT_EXTERNAL) ? false : true;
+		external = (Ctrl->Q.mode == XREPORT_INTERNAL) ? false : true;
 	}
 	coe_kind = 0;
 	if (internal) coe_kind |= 1;
@@ -294,11 +295,11 @@ int GMT_x2sys_report (void *V_API, int mode, void *args)
 
 	if (np == 0 && nx == 0) {	/* End here since nothing was allocated */
 		x2sys_end (GMT, s);
-		Return (GMT_OK);
+		Return (GMT_NOERROR);
 	}
 	
-	R = GMT_memory (GMT, NULL, n_tracks, struct COE_REPORT);
-	trk_name = GMT_memory (GMT, NULL, n_tracks, char *);
+	R = gmt_M_memory (GMT, NULL, n_tracks, struct COE_REPORT);
+	trk_name = gmt_M_memory (GMT, NULL, n_tracks, char *);
 	
 	for (p = 0; p < np; p++) {	/* Get track name list */
 		for (k = 0; k < 2; k++) trk_name[P[p].id[k]] = P[p].trk[k];
@@ -316,7 +317,7 @@ int GMT_x2sys_report (void *V_API, int mode, void *args)
 				corr[1] = MGD77_Correction_Rec (GMT, CORR[P[p].id[1]][COE_Z].term, P[p].COE[i].data[1], NULL);
 			}
 			COE = (P[p].COE[i].data[0][COE_Z] - corr[0]) - (P[p].COE[i].data[1][COE_Z] - corr[1]);
-			if (GMT_is_dnan(COE)) continue;
+			if (gmt_M_is_dnan(COE)) continue;
 			sum += COE;	sum2 += COE * COE;	n++;
 			Tsum += COE;	Tsum2 += COE * COE;	Tnx++;
 		}
@@ -343,13 +344,15 @@ int GMT_x2sys_report (void *V_API, int mode, void *args)
 
 	/* Time to issue output */
 
-	if (GMT_Init_IO (API, GMT_IS_TEXTSET, GMT_IS_NONE, GMT_OUT, GMT_ADD_DEFAULT, 0, options) != GMT_OK) {	/* Establishes data output */
+	if (GMT_Init_IO (API, GMT_IS_TEXTSET, GMT_IS_NONE, GMT_OUT, GMT_ADD_DEFAULT, 0, options) != GMT_NOERROR) {	/* Establishes data output */
+		gmt_M_free (GMT, R);
 		Return (API->error);
 	}
-	if (GMT_Begin_IO (API, GMT_IS_TEXTSET, GMT_OUT, GMT_HEADER_ON) != GMT_OK) {
+	if (GMT_Begin_IO (API, GMT_IS_TEXTSET, GMT_OUT, GMT_HEADER_ON) != GMT_NOERROR) {
+		gmt_M_free (GMT, R);
 		Return (API->error);	/* Enables data output and sets access mode */
 	}
-	GMT_set_tableheader (GMT, GMT_OUT, true);	/* Turn on -ho explicitly */
+	gmt_set_tableheader (GMT, GMT_OUT, true);	/* Turn on -ho explicitly */
 	
 	sprintf (record, " Tag: %s %s", Ctrl->T.TAG, Ctrl->C.col);
 	GMT_Put_Record (API, GMT_WRITE_TABLE_HEADER, record);
@@ -370,22 +373,24 @@ int GMT_x2sys_report (void *V_API, int mode, void *args)
 	Tmean = (Tnx) ? Tsum / Tnx : GMT->session.d_NaN;
 	Tstdev = (Tnx > 1) ? sqrt ((Tnx * Tsum2 - Tsum * Tsum) / (Tnx * (Tnx - 1.0))) : GMT->session.d_NaN;
 	Trms = (Tnx) ? sqrt (Tsum2 / Tnx) : GMT->session.d_NaN;
-	sprintf (fmt, "TOTAL%%s%%" PRIu64 "%%s%s%%s%s%%s%s%%s1", GMT->current.setting.format_float_out,GMT->current.setting.format_float_out,
-		GMT->current.setting.format_float_out);
+	sprintf (fmt, "TOTAL%%s%%" PRIu64 "%%s%s%%s%s%%s%s%%s1",
+	         GMT->current.setting.format_float_out,GMT->current.setting.format_float_out,
+	         GMT->current.setting.format_float_out);
 	sprintf (record, fmt, c, Tnx, c, Tmean, c, Tstdev, c, Trms, c);
 	GMT_Put_Record (API, GMT_WRITE_TEXT, record);
-	sprintf (fmt, "%%s%%s%%" PRIu64 "%%s%s%%s%s%%s%s%%s%s\n", GMT->current.setting.format_float_out,GMT->current.setting.format_float_out,
-		GMT->current.setting.format_float_out, GMT->current.setting.format_float_out);
+	sprintf (fmt, "%%s%%s%%" PRIu64 "%%s%s%%s%s%%s%s%%s%s\n",
+	         GMT->current.setting.format_float_out,GMT->current.setting.format_float_out,
+	         GMT->current.setting.format_float_out, GMT->current.setting.format_float_out);
 	for (k = 0; k < n_tracks; k++) {	/* For each track that generated crossovers */
 		if (R[k].nx <= Ctrl->N.min) continue;			/* Not enough COEs */
-		if (!GMT_is_dnan (R[k].W)) R[k].W *= scale;
+		if (!gmt_M_is_dnan (R[k].W)) R[k].W *= scale;
 		R[k].mean = (R[k].nx) ? R[k].sum / R[k].nx : GMT->session.d_NaN;
 		R[k].stdev = (R[k].nx > 1) ? sqrt ((R[k].nx * R[k].sum2 - R[k].sum * R[k].sum) / (R[k].nx * (R[k].nx - 1.0))) : GMT->session.d_NaN;
 		R[k].rms = (R[k].nx) ? sqrt (R[k].sum2 / R[k].nx) : GMT->session.d_NaN;
 		sprintf (record, fmt, trk_name[k], c, R[k].nx, c, R[k].mean, c, R[k].stdev, c, R[k].rms, c, R[k].W);
 		GMT_Put_Record (API, GMT_WRITE_TEXT, record);
 	}
-	if (GMT_End_IO (API, GMT_OUT, 0) != GMT_OK) {	/* Disables further data output */
+	if (GMT_End_IO (API, GMT_OUT, 0) != GMT_NOERROR) {	/* Disables further data output */
 		Return (API->error);
 	}
 	
@@ -396,9 +401,9 @@ int GMT_x2sys_report (void *V_API, int mode, void *args)
 		FILE *fp = NULL;
 		struct COE_ADJLIST *adj = NULL;
 
-		GMT_set_cartesian (GMT, GMT_OUT);	/* Since we will write (dist, COE) pairs */
+		gmt_set_cartesian (GMT, GMT_OUT);	/* Since we will write (dist, COE) pairs */
 		
-		adj = GMT_memory (GMT, NULL, n_tracks, struct COE_ADJLIST);
+		adj = gmt_M_memory (GMT, NULL, n_tracks, struct COE_ADJLIST);
 		for (p = 0; p < np; p++) {	/* For each pair of tracks that generated crossovers */
 			for (i = n = 0; i < P[p].nx; i++) {	/* For each COE between this pair */
 				for (k = 0; k < 2; k++) {
@@ -406,12 +411,12 @@ int GMT_x2sys_report (void *V_API, int mode, void *args)
 					if (Ctrl->L.active) z[k] -= MGD77_Correction_Rec (GMT, CORR[P[p].id[k]][COE_Z].term, P[p].COE[i].data[k], NULL);
 				}
 				z_ij = (z[0] * R[P[p].id[0]].W + z[1] * R[P[p].id[1]].W) / (R[P[p].id[0]].W + R[P[p].id[1]].W);	/* Desired z-value at crossover */
-				if (GMT_is_dnan(z_ij)) continue;
+				if (gmt_M_is_dnan(z_ij)) continue;
 				for (k = 0; k < 2; k++) {
 					if (R[P[p].id[k]].nx <= Ctrl->N.min) continue;	/* This track will not have enough total COE to be used in the end */
 					if (adj[P[p].id[k]].n >= adj[P[p].id[k]].n_alloc) {	/* So first time both are zero and we allocate first */
 						if (adj[P[p].id[k]].n_alloc) adj[P[p].id[k]].n_alloc <<= 1; else adj[P[p].id[k]].n_alloc = GMT_SMALL_CHUNK;
-						adj[P[p].id[k]].K = GMT_memory (GMT, adj[P[p].id[k]].K, adj[P[p].id[k]].n_alloc, struct COE_ADJUST);
+						adj[P[p].id[k]].K = gmt_M_memory (GMT, adj[P[p].id[k]].K, adj[P[p].id[k]].n_alloc, struct COE_ADJUST);
 					}
 					adj[P[p].id[k]].K[adj[P[p].id[k]].n].d = P[p].COE[i].data[k][COE_D];	/* Distance along current track at COE */
 					adj[P[p].id[k]].K[adj[P[p].id[k]].n].c = z_ij - z[k];			/* Observed difference at COE to be adjusted */
@@ -430,9 +435,18 @@ int GMT_x2sys_report (void *V_API, int mode, void *args)
 			
 			qsort(adj[k].K, adj[k].n, sizeof(struct COE_ADJUST), comp_structs);
 			sprintf (file, "%s/%s/%s.%s.adj", X2SYS_HOME, Ctrl->T.TAG, trk_name[k], Ctrl->C.col);
-			if ((fp = GMT_fopen (GMT, file, "w")) == NULL) {
+			if ((fp = gmt_fopen (GMT, file, "w")) == NULL) {
 				GMT_Report (API, GMT_MSG_NORMAL, "Unable to create file %s!\n", file);
-				Return (EXIT_FAILURE);
+				/* Free memory before exiting */
+				for (p = k; p < n_tracks; p++)	/* Free everything then bail */
+					gmt_M_free (GMT, adj[k].K);
+				gmt_M_free(GMT, adj);
+				x2sys_free_coe_dbase (GMT, P, np);
+				gmt_M_free (GMT, trk_name);
+				gmt_M_free (GMT, R);
+				if (Ctrl->L.active) MGD77_Free_Correction (GMT, CORR, (unsigned int)n_tracks);
+				x2sys_end (GMT, s);
+				Return (GMT_RUNTIME_ERROR);
 			}
 			n1 = adj[k].n - 1;
 			out[1] = 0.0;
@@ -447,20 +461,20 @@ int GMT_x2sys_report (void *V_API, int mode, void *args)
 					n_out = 0;
 				}
 			}
-			GMT_fclose (GMT, fp);
-			GMT_free (GMT, adj[k].K);
+			gmt_fclose (GMT, fp);
+			gmt_M_free (GMT, adj[k].K);
 		}
-		GMT_free (GMT, adj);
+		gmt_M_free (GMT, adj);
 	}
 	
 	/* Done, free up data base array, etc */
 	
 	x2sys_free_coe_dbase (GMT, P, np);
-	GMT_free (GMT, trk_name);
-	GMT_free (GMT, R);
+	gmt_M_free (GMT, trk_name);
+	gmt_M_free (GMT, R);
 
 	if (Ctrl->L.active) MGD77_Free_Correction (GMT, CORR, (unsigned int)n_tracks);
 	x2sys_end (GMT, s);
 
-	Return (GMT_OK);
+	Return (GMT_NOERROR);
 }
